
DROP TABLE IF EXISTS va_admin_privileges;
CREATE TABLE va_admin_privileges (
  `privilege_id` INT(11) NOT NULL AUTO_INCREMENT,
  `privilege_name` VARCHAR(64) NOT NULL
  ,PRIMARY KEY (privilege_id)
);


DROP TABLE IF EXISTS va_admin_privileges_settings;
CREATE TABLE va_admin_privileges_settings (
  `privilege_id` INT(11) NOT NULL default '0',
  `block_name` VARCHAR(64) NOT NULL,
  `permission` INT(11)
  ,PRIMARY KEY (privilege_id,block_name)
);


DROP TABLE IF EXISTS va_admins;
CREATE TABLE va_admins (
  `admin_id` INT(11) NOT NULL AUTO_INCREMENT,
  `admin_name` VARCHAR(255) NOT NULL,
  `privilege_id` INT(11) NOT NULL default '0',
  `email` VARCHAR(255) NOT NULL,
  `login` VARCHAR(64) NOT NULL,
  `password` VARCHAR(32) NOT NULL
  ,KEY login (login)
  ,KEY password (password)
  ,PRIMARY KEY (admin_id)
);


DROP TABLE IF EXISTS va_categories;
CREATE TABLE va_categories (
  `category_id` INT(11) NOT NULL AUTO_INCREMENT,
  `parent_category_id` INT(11) NOT NULL default '0',
  `category_path` VARCHAR(255) NOT NULL,
  `category_name` VARCHAR(255) NOT NULL,
  `category_order` INT(11) NOT NULL default '1',
  `is_showing` INT(11) default '0',
  `short_description` TEXT,
  `full_description` TEXT,
  `image` VARCHAR(255)
  ,KEY category_path (category_path)
  ,KEY parent_category_id (parent_category_id)
  ,PRIMARY KEY (category_id)
);


DROP TABLE IF EXISTS va_cc_expiry_years;
CREATE TABLE va_cc_expiry_years (
  `expiry_year` INT(11) NOT NULL default '0'
  ,PRIMARY KEY (expiry_year)
);


DROP TABLE IF EXISTS va_cc_start_years;
CREATE TABLE va_cc_start_years (
  `start_year` INT(11) NOT NULL default '0'
  ,PRIMARY KEY (start_year)
);


DROP TABLE IF EXISTS va_change_types;
CREATE TABLE va_change_types (
  `type_id` INT(11) NOT NULL AUTO_INCREMENT,
  `type_name` VARCHAR(255) NOT NULL
  ,PRIMARY KEY (type_id)
);


DROP TABLE IF EXISTS va_countries;
CREATE TABLE va_countries (
  `country_code` VARCHAR(2) NOT NULL,
  `country_order` INT(11) default '1',
  `country_name` VARCHAR(64) NOT NULL
  ,PRIMARY KEY (country_code)
);


DROP TABLE IF EXISTS va_credit_cards;
CREATE TABLE va_credit_cards (
  `credit_card_id` INT(11) NOT NULL AUTO_INCREMENT,
  `credit_card_name` VARCHAR(64) NOT NULL
  ,PRIMARY KEY (credit_card_id)
);


DROP TABLE IF EXISTS va_custom_blocks;
CREATE TABLE va_custom_blocks (
  `block_id` INT(11) NOT NULL AUTO_INCREMENT,
  `block_title` VARCHAR(255),
  `block_desc` TEXT
  ,PRIMARY KEY (block_id)
);


DROP TABLE IF EXISTS va_events;
CREATE TABLE va_events (
  `event_id` INT(11) NOT NULL AUTO_INCREMENT,
  `event_date` DATETIME NOT NULL,
  `event_title` VARCHAR(255) NOT NULL,
  `is_html` INT(11) NOT NULL default '1',
  `is_showing` INT(11) NOT NULL default '1',
  `show_on_index` INT(11) NOT NULL default '0',
  `preview_text` TEXT,
  `event_body` TEXT
  ,PRIMARY KEY (event_id)
);


DROP TABLE IF EXISTS va_faq;
CREATE TABLE va_faq (
  `faq_id` INT(11) NOT NULL AUTO_INCREMENT,
  `faq_group_id` INT(11) NOT NULL default '0',
  `faq_order` INT(11) NOT NULL default '1',
  `question` TEXT NOT NULL,
  `answer` TEXT NOT NULL
  ,PRIMARY KEY (faq_id)
);


DROP TABLE IF EXISTS va_forum;
CREATE TABLE va_forum (
  `thread_id` INT(11) NOT NULL AUTO_INCREMENT,
  `user_id` INT(11) NOT NULL default '0',
  `user_name` VARCHAR(64) NOT NULL,
  `user_email` VARCHAR(128) NOT NULL,
  `remote_address` VARCHAR(32),
  `topic` VARCHAR(255) NOT NULL,
  `description` TEXT NOT NULL,
  `email_notification` INT(11),
  `views` INT(11),
  `replies` INT(11),
  `date_added` DATETIME NOT NULL,
  `date_modified` DATETIME NOT NULL
  ,PRIMARY KEY (thread_id)
);


DROP TABLE IF EXISTS va_forum_messages;
CREATE TABLE va_forum_messages (
  `message_id` INT(11) NOT NULL AUTO_INCREMENT,
  `thread_id` INT(11) NOT NULL default '0',
  `admin_id` INT(11),
  `user_name` VARCHAR(64) NOT NULL,
  `user_email` VARCHAR(128) NOT NULL,
  `remote_address` VARCHAR(32),
  `message_text` TEXT NOT NULL,
  `date_added` DATETIME NOT NULL
  ,PRIMARY KEY (message_id)
);


DROP TABLE IF EXISTS va_global_settings;
CREATE TABLE va_global_settings (
  `setting_type` VARCHAR(32) NOT NULL,
  `setting_name` VARCHAR(64) NOT NULL,
  `setting_value` TEXT
  ,PRIMARY KEY (setting_type,setting_name)
);


DROP TABLE IF EXISTS va_header_links;
CREATE TABLE va_header_links (
  `menu_id` INT(11) NOT NULL AUTO_INCREMENT,
  `layout_id` INT(11) NOT NULL default '0',
  `menu_title` VARCHAR(255),
  `menu_url` VARCHAR(255),
  `menu_image` VARCHAR(255),
  `menu_image_active` VARCHAR(255),
  `menu_order` INT(11),
  `show_non_logged` INT(11),
  `show_logged` INT(11)
  ,PRIMARY KEY (menu_id)
);


DROP TABLE IF EXISTS va_issue_numbers;
CREATE TABLE va_issue_numbers (
  `issue_number` INT(11) NOT NULL default '0'
  ,PRIMARY KEY (issue_number)
);


DROP TABLE IF EXISTS va_item_types;
CREATE TABLE va_item_types (
  `item_type_id` INT(11) NOT NULL AUTO_INCREMENT,
  `item_type_name` VARCHAR(50)
  ,PRIMARY KEY (item_type_id)
);


DROP TABLE IF EXISTS va_items;
CREATE TABLE va_items (
  `item_id` INT(11) NOT NULL AUTO_INCREMENT,
  `item_name` VARCHAR(255) NOT NULL,
  `item_order` INT(11) NOT NULL default '1',
  `item_type_id` INT(11) NOT NULL default '0',
  `manufacturer_id` INT(11),
  `manufacturer_code` VARCHAR(255),
  `features` TEXT,
  `short_description` TEXT,
  `full_desc_type` INT(11),
  `full_description` TEXT,
  `is_special_offer` INT(11) NOT NULL default '0',
  `special_offer` TEXT,
  `notes` TEXT,
  `small_image` VARCHAR(255),
  `big_image` VARCHAR(255),
  `specification` VARCHAR(255),
  `buying_price` FLOAT(10,2) default '0',
  `price` FLOAT(10,2) NOT NULL default '0',
  `weight` FLOAT(10,4),
  `stock_level` INT(11),
  `use_stock_level` INT(11) NOT NULL default '1',
  `hide_out_of_stock` INT(11) NOT NULL default '1',
  `shipping_in_stock` INT(11),
  `shipping_out_stock` INT(11) default '0',
  `shipping_rule_id` INT(11),
  `shipping_cost` FLOAT(10,2),
  `is_sales` INT(11),
  `sales_price` FLOAT(10,2),
  `discount_percent` FLOAT(10,2),
  `downloadable` INT(11),
  `download_period` INT(11),
  `download_path` TEXT,
  `is_showing` INT(11) NOT NULL default '1',
  `buy_link` VARCHAR(255),
  `votes` INT(11),
  `points` INT(11),
  `rating` FLOAT(10,4)
  ,KEY is_showing (is_showing)
  ,KEY item_name (item_name)
  ,KEY price (price)
  ,PRIMARY KEY (item_id)
);


DROP TABLE IF EXISTS va_items_categories;
CREATE TABLE va_items_categories (
  `item_id` INT(11) NOT NULL default '0',
  `category_id` INT(11) NOT NULL default '0'
  ,KEY category_id (category_id)
  ,KEY item_id (item_id)
);


DROP TABLE IF EXISTS va_items_downloads;
CREATE TABLE va_items_downloads (
  `download_id` INT(11) NOT NULL AUTO_INCREMENT,
  `order_id` INT(11) NOT NULL default '0',
  `user_id` INT(11) NOT NULL default '0',
  `order_item_id` INT(11) NOT NULL default '0',
  `item_id` INT(11) NOT NULL default '0',
  `download_notes` VARCHAR(255),
  `download_path` VARCHAR(255),
  `activated` INT(11),
  `max_downloads` INT(11),
  `download_added` DATETIME NOT NULL,
  `download_expiry` DATETIME NOT NULL
  ,KEY item_id (item_id)
  ,KEY order_id (order_id)
  ,KEY order_item_id (order_item_id)
  ,PRIMARY KEY (download_id)
  ,KEY user_id (user_id)
);


DROP TABLE IF EXISTS va_items_downloads_statistic;
CREATE TABLE va_items_downloads_statistic (
  `download_id` INT(11) NOT NULL default '0',
  `order_item_id` INT(11) NOT NULL default '0',
  `remote_address` VARCHAR(32) NOT NULL,
  `downloaded_date` DATETIME NOT NULL
  ,KEY download_id (download_id)
  ,KEY downloaded_date (downloaded_date)
  ,KEY order_item_id (order_item_id)
  ,KEY remote_address (remote_address)
);


DROP TABLE IF EXISTS va_items_properties;
CREATE TABLE va_items_properties (
  `property_id` INT(11) NOT NULL AUTO_INCREMENT,
  `item_id` INT(11) NOT NULL default '0',
  `property_name` VARCHAR(255) NOT NULL,
  `property_description` TEXT,
  `control_type` VARCHAR(16) NOT NULL,
  `control_style` VARCHAR(255),
  `required` INT(11),
  `use_on_checkout` INT(11) default '0',
  `start_html` TEXT,
  `middle_html` TEXT,
  `end_html` TEXT
  ,KEY item_id (item_id)
  ,PRIMARY KEY (property_id)
);


DROP TABLE IF EXISTS va_items_properties_values;
CREATE TABLE va_items_properties_values (
  `item_property_id` INT(11) NOT NULL AUTO_INCREMENT,
  `property_id` INT(11) NOT NULL default '0',
  `property_value` VARCHAR(255) NOT NULL,
  `additional_price` FLOAT(10,2),
  `additional_weight` FLOAT(10,4),
  `hide_value` INT(11) NOT NULL default '0',
  `is_default_value` INT(11) default '0'
  ,KEY hide_value (hide_value)
  ,PRIMARY KEY (item_property_id)
  ,KEY property_id (property_id)
);


DROP TABLE IF EXISTS va_layouts;
CREATE TABLE va_layouts (
  `layout_id` INT(11) NOT NULL AUTO_INCREMENT,
  `layout_name` VARCHAR(64) NOT NULL,
  `templates_dir` VARCHAR(255) NOT NULL,
  `admin_templates_dir` VARCHAR(255) NOT NULL
  ,PRIMARY KEY (layout_id)
);


DROP TABLE IF EXISTS va_manufacturers;
CREATE TABLE va_manufacturers (
  `manufacturer_id` INT(11) NOT NULL AUTO_INCREMENT,
  `manufacturer_name` VARCHAR(255) NOT NULL,
  `affiliate_code` VARCHAR(255)
  ,PRIMARY KEY (manufacturer_id)
);


DROP TABLE IF EXISTS va_news;
CREATE TABLE va_news (
  `news_id` INT(11) NOT NULL AUTO_INCREMENT,
  `news_date` DATETIME NOT NULL,
  `news_title` VARCHAR(255) NOT NULL,
  `author` VARCHAR(255),
  `is_html` INT(11) NOT NULL default '1',
  `is_showing` INT(11) NOT NULL default '1',
  `show_on_index` INT(11) NOT NULL default '0',
  `preview_text` TEXT,
  `news_body` TEXT
  ,PRIMARY KEY (news_id)
);


DROP TABLE IF EXISTS va_order_statuses;
CREATE TABLE va_order_statuses (
  `status_id` INT(11) NOT NULL AUTO_INCREMENT,
  `status_name` VARCHAR(64) NOT NULL,
  `download_activation` INT(11)
  ,PRIMARY KEY (status_id)
);


DROP TABLE IF EXISTS va_orders;
CREATE TABLE va_orders (
  `order_id` INT(11) NOT NULL AUTO_INCREMENT,
  `user_id` INT(11) NOT NULL default '0',
  `affiliate_code` VARCHAR(64) NOT NULL,
  `order_status` INT(11) NOT NULL default '1',
  `total_buying` FLOAT(10,2) NOT NULL default '0',
  `goods_total` FLOAT(10,2) NOT NULL default '0',
  `total_quantity` INT(11) NOT NULL default '0',
  `weight_total` INT(11) default '0',
  `total_discount` FLOAT(10,2) default '0',
  `shipping_type_id` INT(11) default '0',
  `shipping_type_desc` VARCHAR(255),
  `shipping_cost` FLOAT(10,2),
  `tax_name` VARCHAR(255),
  `tax_percent` FLOAT(10,2),
  `tax_total` FLOAT(10,2) default '0',
  `order_total` FLOAT(10,2) NOT NULL default '0',
  `name` VARCHAR(128) NOT NULL,
  `first_name` VARCHAR(64) NOT NULL,
  `last_name` VARCHAR(64) NOT NULL,
  `company_name` VARCHAR(128),
  `email` VARCHAR(128) NOT NULL,
  `address1` VARCHAR(255),
  `address2` VARCHAR(255),
  `city` VARCHAR(128),
  `province` VARCHAR(128),
  `state_code` VARCHAR(2),
  `zip` VARCHAR(16),
  `country_code` VARCHAR(2),
  `phone` VARCHAR(32),
  `daytime_phone` VARCHAR(32),
  `evening_phone` VARCHAR(32),
  `cell_phone` VARCHAR(32),
  `fax` VARCHAR(32),
  `delivery_name` VARCHAR(128),
  `delivery_first_name` VARCHAR(64),
  `delivery_last_name` VARCHAR(64),
  `delivery_company_name` VARCHAR(128),
  `delivery_email` VARCHAR(128),
  `delivery_address1` VARCHAR(255),
  `delivery_address2` VARCHAR(255),
  `delivery_city` VARCHAR(128),
  `delivery_province` VARCHAR(128),
  `delivery_state_code` VARCHAR(2),
  `delivery_zip` VARCHAR(16),
  `delivery_country_code` VARCHAR(2),
  `delivery_phone` VARCHAR(32),
  `delivery_daytime_phone` VARCHAR(32),
  `delivery_evening_phone` VARCHAR(32),
  `delivery_cell_phone` VARCHAR(32),
  `delivery_fax` VARCHAR(32),
  `cc_name` VARCHAR(90),
  `cc_number` VARCHAR(32),
  `cc_start_date` DATETIME,
  `cc_expiry_date` DATETIME,
  `cc_type` INT(11),
  `cc_issue_number` INT(11),
  `cc_security_code` VARCHAR(32),
  `pay_without_cc` TEXT,
  `order_placed_date` DATETIME NOT NULL,
  `modified_date` DATETIME
  ,KEY affiliate_code (affiliate_code)
  ,KEY email (email)
  ,KEY first_name (first_name)
  ,KEY goods_total (goods_total)
  ,KEY last_name (last_name)
  ,KEY name (name)
  ,KEY order_placed_date (order_placed_date)
  ,KEY order_status (order_status)
  ,PRIMARY KEY (order_id)
  ,KEY shipping_type_id (shipping_type_id)
  ,KEY total_buying (total_buying)
  ,KEY user_id (user_id)
);


DROP TABLE IF EXISTS va_orders_items;
CREATE TABLE va_orders_items (
  `order_item_id` INT(11) NOT NULL AUTO_INCREMENT,
  `order_id` INT(11) NOT NULL default '0',
  `item_id` INT(11) NOT NULL default '0',
  `item_type_id` INT(11) NOT NULL default '0',
  `item_status` INT(11) NOT NULL default '1',
  `item_name` VARCHAR(255) NOT NULL,
  `item_properties` VARCHAR(255),
  `buying_price` FLOAT(10,2) default '0',
  `price` FLOAT(10,2) NOT NULL default '0',
  `weight` FLOAT(10,4) default '0',
  `quantity` INT(11),
  `downloadable` INT(11) default '0'
  ,KEY item_id (item_id)
  ,KEY item_status (item_status)
  ,KEY item_type (item_type_id)
  ,KEY order_id (order_id)
  ,KEY price (price)
  ,PRIMARY KEY (order_item_id)
);


DROP TABLE IF EXISTS va_orders_items_properties;
CREATE TABLE va_orders_items_properties (
  `item_property_id` INT(11) NOT NULL AUTO_INCREMENT,
  `order_id` INT(11) NOT NULL default '0',
  `order_item_id` INT(11) NOT NULL default '0',
  `property_id` INT(11) NOT NULL default '0',
  `property_name` VARCHAR(255) NOT NULL,
  `property_value` VARCHAR(255),
  `additional_price` FLOAT(10,2) default '0',
  `additional_weight` FLOAT(10,4) default '0'
  ,KEY order_id (order_id)
  ,KEY order_item_id (order_item_id)
  ,PRIMARY KEY (item_property_id)
  ,KEY property_id (property_id)
);


DROP TABLE IF EXISTS va_page_settings;
CREATE TABLE va_page_settings (
  `layout_id` INT(11) NOT NULL default '0',
  `page_name` VARCHAR(32) NOT NULL,
  `setting_name` VARCHAR(64) NOT NULL,
  `setting_order` INT(11),
  `setting_value` TEXT
  ,PRIMARY KEY (layout_id,page_name,setting_name)
);


DROP TABLE IF EXISTS va_pages;
CREATE TABLE va_pages (
  `page_id` INT(11) NOT NULL AUTO_INCREMENT,
  `page_code` VARCHAR(16) NOT NULL,
  `page_title` VARCHAR(255) NOT NULL,
  `page_url` VARCHAR(255),
  `page_order` INT(11) NOT NULL default '1',
  `is_showing` INT(11) NOT NULL default '1',
  `link_in_footer` INT(11) NOT NULL default '0',
  `is_html` INT(11),
  `page_type` INT(11),
  `page_path` VARCHAR(255),
  `page_body` TEXT
  ,KEY is_showing (is_showing)
  ,KEY link_in_footer (link_in_footer)
  ,KEY page_code (page_code)
  ,PRIMARY KEY (page_id)
);


DROP TABLE IF EXISTS va_payment_parameters;
CREATE TABLE va_payment_parameters (
  `parameter_id` INT(11) NOT NULL AUTO_INCREMENT,
  `payment_id` INT(11) NOT NULL default '0',
  `parameter_name` VARCHAR(255) NOT NULL,
  `parameter_type` VARCHAR(16) NOT NULL,
  `parameter_source` VARCHAR(255)
  ,PRIMARY KEY (parameter_id)
);


DROP TABLE IF EXISTS va_payment_systems;
CREATE TABLE va_payment_systems (
  `payment_id` INT(11) NOT NULL AUTO_INCREMENT,
  `payment_name` VARCHAR(255) NOT NULL,
  `payment_url` VARCHAR(255) NOT NULL,
  `submit_method` VARCHAR(4)
  ,PRIMARY KEY (payment_id)
);


DROP TABLE IF EXISTS va_polls;
CREATE TABLE va_polls (
  `poll_id` INT(11) NOT NULL AUTO_INCREMENT,
  `poll_type` INT(11) NOT NULL default '1',
  `question` TEXT NOT NULL,
  `is_active` INT(11) NOT NULL default '0',
  `date_added` DATETIME NOT NULL
  ,PRIMARY KEY (poll_id)
);


DROP TABLE IF EXISTS va_polls_options;
CREATE TABLE va_polls_options (
  `poll_option_id` INT(11) NOT NULL AUTO_INCREMENT,
  `poll_id` INT(11) NOT NULL default '0',
  `option_description` TEXT NOT NULL
  ,KEY poll_id (poll_id)
  ,PRIMARY KEY (poll_option_id)
);


DROP TABLE IF EXISTS va_polls_votes;
CREATE TABLE va_polls_votes (
  `poll_id` INT(11) NOT NULL default '0',
  `poll_option_id` INT(11) NOT NULL default '0',
  `remote_address` VARCHAR(32) NOT NULL,
  `date_added` DATETIME NOT NULL
  ,KEY poll_id (poll_id)
  ,KEY poll_option_id (poll_option_id)
  ,KEY remote_address (remote_address)
);


DROP TABLE IF EXISTS va_release_changes;
CREATE TABLE va_release_changes (
  `change_id` INT(11) NOT NULL AUTO_INCREMENT,
  `release_id` INT(11) NOT NULL default '0',
  `change_type_id` INT(11) NOT NULL default '0',
  `change_date` DATETIME NOT NULL,
  `change_desc` TEXT,
  `is_showing` INT(11) NOT NULL default '1'
  ,PRIMARY KEY (change_id)
  ,KEY release_id (release_id)
);


DROP TABLE IF EXISTS va_release_types;
CREATE TABLE va_release_types (
  `type_id` INT(11) NOT NULL AUTO_INCREMENT,
  `type_name` VARCHAR(255) NOT NULL
  ,PRIMARY KEY (type_id)
);


DROP TABLE IF EXISTS va_releases;
CREATE TABLE va_releases (
  `release_id` INT(11) NOT NULL AUTO_INCREMENT,
  `item_id` INT(11) NOT NULL default '0',
  `release_type_id` INT(11) NOT NULL default '0',
  `release_date` DATETIME NOT NULL,
  `release_title` VARCHAR(255) NOT NULL,
  `version` VARCHAR(32),
  `release_desc` TEXT,
  `download_type` INT(11) NOT NULL default '0',
  `path_to_file` VARCHAR(255),
  `is_showing` INT(11) NOT NULL default '1',
  `show_on_index` INT(11) NOT NULL default '0'
  ,KEY item_id (item_id)
  ,PRIMARY KEY (release_id)
);


DROP TABLE IF EXISTS va_reviews;
CREATE TABLE va_reviews (
  `review_id` INT(11) NOT NULL AUTO_INCREMENT,
  `item_id` INT(11) NOT NULL default '0',
  `recommended` INT(11) NOT NULL default '0',
  `approved` INT(11) NOT NULL default '0',
  `rating` INT(11),
  `summary` VARCHAR(255),
  `user_name` VARCHAR(255),
  `remote_address` VARCHAR(32) NOT NULL,
  `date_added` DATETIME NOT NULL,
  `comments` TEXT
  ,KEY approved (approved)
  ,KEY item_id (item_id)
  ,PRIMARY KEY (review_id)
  ,KEY recommended (recommended)
);


DROP TABLE IF EXISTS va_shipping_rules;
CREATE TABLE va_shipping_rules (
  `shipping_rule_id` INT(11) NOT NULL AUTO_INCREMENT,
  `shipping_rule_desc` VARCHAR(255) NOT NULL
  ,PRIMARY KEY (shipping_rule_id)
);


DROP TABLE IF EXISTS va_shipping_times;
CREATE TABLE va_shipping_times (
  `shipping_time_id` INT(11) NOT NULL AUTO_INCREMENT,
  `shipping_time_desc` VARCHAR(255) NOT NULL
  ,PRIMARY KEY (shipping_time_id)
);


DROP TABLE IF EXISTS va_shipping_types;
CREATE TABLE va_shipping_types (
  `shipping_type_id` INT(11) NOT NULL AUTO_INCREMENT,
  `shipping_type_desc` VARCHAR(255) NOT NULL,
  `min_goods_cost` FLOAT(10,2) default '0',
  `max_goods_cost` FLOAT(10,2) default '0',
  `min_weight` FLOAT(10,4) default '0',
  `max_weight` FLOAT(10,4) default '0',
  `cost_per_order` FLOAT(10,2) default '0',
  `cost_per_product` FLOAT(10,2) default '0',
  `cost_per_weight` FLOAT(10,2) default '0'
  ,PRIMARY KEY (shipping_type_id)
  ,KEY shipping_type_id (shipping_type_id)
);


DROP TABLE IF EXISTS va_shipping_types_countries;
CREATE TABLE va_shipping_types_countries (
  `shipping_type_id` INT(11) NOT NULL default '0',
  `country_code` VARCHAR(2) NOT NULL
  ,KEY country_code (country_code)
  ,KEY shippin_type_id (shipping_type_id)
);


DROP TABLE IF EXISTS va_states;
CREATE TABLE va_states (
  `state_code` VARCHAR(2) NOT NULL,
  `state_name` VARCHAR(64) NOT NULL
  ,PRIMARY KEY (state_code)
);


DROP TABLE IF EXISTS va_support;
CREATE TABLE va_support (
  `support_id` INT(11) NOT NULL AUTO_INCREMENT,
  `user_id` INT(11) NOT NULL default '0',
  `user_name` VARCHAR(64) NOT NULL,
  `user_email` VARCHAR(128) NOT NULL,
  `remote_address` VARCHAR(32),
  `identifier` VARCHAR(128),
  `environment` VARCHAR(255),
  `support_product_id` INT(11) NOT NULL default '0',
  `support_type_id` INT(11) NOT NULL default '0',
  `dep_id` INT(11) NOT NULL default '0',
  `summary` VARCHAR(255) NOT NULL,
  `description` TEXT,
  `support_status_id` INT(11),
  `support_priority_id` INT(11),
  `admin_id_assign_to` INT(11) NOT NULL default '0',
  `admin_id_assign_by` INT(11),
  `admin_id_added_by` INT(11),
  `date_added` DATETIME NOT NULL,
  `date_modified` DATETIME NOT NULL
  ,KEY admin_id_assign_to (admin_id_assign_to)
  ,KEY dep_id (dep_id)
  ,PRIMARY KEY (support_id)
  ,KEY summary (summary)
  ,KEY support_product_id (support_product_id)
  ,KEY support_type_id (support_type_id)
  ,KEY user_email (user_email)
  ,KEY user_id (user_id)
  ,KEY user_name (user_name)
);

DROP TABLE IF EXISTS va_support_messages;
CREATE TABLE va_support_messages (
  `message_id` INT(11) NOT NULL AUTO_INCREMENT,
  `support_id` INT(11) NOT NULL default '0',
  `internal` INT(11) NOT NULL default '0',
  `dep_id` INT(11) NOT NULL default '0',
  `support_status_id` INT(11) NOT NULL default '0',
  `admin_id_assign_by` INT(11),
  `admin_id_assign_to` INT(11),
  `subject` VARCHAR(255),
  `message_text` TEXT,
  `reply_to` VARCHAR(255),
  `reply_from` VARCHAR(255),
  `date_added` DATETIME NOT NULL,
  `date_viewed` DATETIME,
  `is_user_reply` INT(11) default '0',
  `is_html` INT(11) default '0'
  ,KEY dep_id (dep_id)
  ,PRIMARY KEY (message_id)
  ,KEY support_id (support_id)
);

DROP TABLE IF EXISTS va_support_departments;
CREATE TABLE va_support_departments (
  `dep_id` INT(11) NOT NULL AUTO_INCREMENT,
  `dep_name` VARCHAR(255),
  `dep_title` VARCHAR(255),
  `signature` TEXT,
  `incoming_account` TEXT,
  `outgoing_account` VARCHAR(50)
  ,KEY dep_id (dep_id)
  ,PRIMARY KEY (dep_id)
);


DROP TABLE IF EXISTS va_support_predefined;
CREATE TABLE va_support_predefined (
  `reply_id` INT(11) NOT NULL AUTO_INCREMENT,
  `subject` VARCHAR(255),
  `body` TEXT,
  `reply_type` VARCHAR(255)
  ,KEY email_id (reply_id)
  ,PRIMARY KEY (reply_id)
);


DROP TABLE IF EXISTS va_support_time_report;
CREATE TABLE va_support_time_report (
  `report_id` INT(11) NOT NULL AUTO_INCREMENT,
  `admin_id` INT(11) NOT NULL default '0',
  `support_id` INT(11) NOT NULL default '0',
  `started_date` DATETIME,
  `report_date` DATETIME,
  `spent_hours` INT(11) default '0'
  ,KEY admin_id (admin_id)
  ,PRIMARY KEY (report_id)
  ,KEY report_id (report_id)
  ,KEY support_id (support_id)
);


DROP TABLE IF EXISTS va_support_users_departments;
CREATE TABLE va_support_users_departments (
  `admin_id` INT(11) NOT NULL default '0',
  `dep_id` INT(11) NOT NULL default '0',
  `is_default_dep` INT(11) default '0'
  ,KEY admin_id (admin_id)
  ,KEY dep_id (dep_id)
  ,PRIMARY KEY (admin_id,dep_id)
);


DROP TABLE IF EXISTS va_support_attachments;
CREATE TABLE va_support_attachments (
  `attachment_id` INT(11) NOT NULL AUTO_INCREMENT,
  `support_id` INT(11) NOT NULL default '0',
  `file_name` VARCHAR(255),
  `date_added` DATETIME
  ,KEY attachment_id (attachment_id)
  ,PRIMARY KEY (attachment_id)
  ,KEY support_id (support_id)
);


DROP TABLE IF EXISTS va_support_priorities;
CREATE TABLE va_support_priorities (
  `priority_id` INT(11) NOT NULL AUTO_INCREMENT,
  `priority_name` VARCHAR(255) NOT NULL
  ,PRIMARY KEY (priority_id)
);


DROP TABLE IF EXISTS va_support_products;
CREATE TABLE va_support_products (
  `product_id` INT(11) NOT NULL AUTO_INCREMENT,
  `product_name` VARCHAR(255) NOT NULL,
  `show_for_user` INT(11)
  ,PRIMARY KEY (product_id)
);


DROP TABLE IF EXISTS va_support_statuses;
CREATE TABLE va_support_statuses (
  `status_id` INT(11) NOT NULL AUTO_INCREMENT,
  `status_name` VARCHAR(255) NOT NULL,
  `show_for_user` INT(11)
  ,PRIMARY KEY (status_id)
);


DROP TABLE IF EXISTS va_support_types;
CREATE TABLE va_support_types (
  `type_id` INT(11) NOT NULL AUTO_INCREMENT,
  `type_name` VARCHAR(255) NOT NULL,
  `show_for_user` INT(11)
  ,PRIMARY KEY (type_id)
);


DROP TABLE IF EXISTS va_tax_rates;
CREATE TABLE va_tax_rates (
  `tax_id` INT(11) NOT NULL AUTO_INCREMENT,
  `tax_name` VARCHAR(255) NOT NULL,
  `country_code` VARCHAR(2) NOT NULL,
  `tax_percent` FLOAT(10,2) NOT NULL default '0'
  ,PRIMARY KEY (tax_id)
);


DROP TABLE IF EXISTS va_users;
CREATE TABLE va_users (
  `user_id` INT(11) NOT NULL AUTO_INCREMENT,
  `login` VARCHAR(32) NOT NULL,
  `password` VARCHAR(32) NOT NULL,
  `security_question` VARCHAR(255) NOT NULL,
  `security_answer` VARCHAR(255) NOT NULL,
  `name` VARCHAR(128) NOT NULL,
  `first_name` VARCHAR(64) NOT NULL,
  `last_name` VARCHAR(64) NOT NULL,
  `company_name` VARCHAR(128),
  `email` VARCHAR(128) NOT NULL,
  `address1` VARCHAR(255),
  `address2` VARCHAR(255),
  `city` VARCHAR(128),
  `province` VARCHAR(128),
  `state_code` VARCHAR(2),
  `zip` VARCHAR(16),
  `country_code` VARCHAR(2),
  `phone` VARCHAR(32),
  `daytime_phone` VARCHAR(32),
  `evening_phone` VARCHAR(32),
  `cell_phone` VARCHAR(32),
  `fax` VARCHAR(32),
  `delivery_name` VARCHAR(128),
  `delivery_first_name` VARCHAR(64),
  `delivery_last_name` VARCHAR(64),
  `delivery_company_name` VARCHAR(128),
  `delivery_email` VARCHAR(128),
  `delivery_address1` VARCHAR(255),
  `delivery_address2` VARCHAR(255),
  `delivery_city` VARCHAR(128),
  `delivery_province` VARCHAR(128),
  `delivery_state_code` VARCHAR(2),
  `delivery_zip` VARCHAR(16),
  `delivery_country_code` VARCHAR(2),
  `delivery_phone` VARCHAR(32),
  `delivery_daytime_phone` VARCHAR(32),
  `delivery_evening_phone` VARCHAR(32),
  `delivery_cell_phone` VARCHAR(32),
  `delivery_fax` VARCHAR(32),
  `registration_date` DATETIME,
  `modified_date` DATETIME
  ,KEY email (email)
  ,KEY first_name (first_name)
  ,KEY last_name (last_name)
  ,KEY login (login)
  ,KEY name (name)
  ,KEY password (password)
  ,PRIMARY KEY (user_id)
);


INSERT INTO va_admin_privileges (`privilege_id`,`privilege_name`) VALUES (1 , 'Administrator' ) ;


INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'admin_users' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'events' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'faq' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'forum' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'layouts' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'news' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'payment_systems' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'products_categories' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'products_reviews' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'sales_orders' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'site_settings' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'site_users' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'static_tables' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'support' , 1 ) ;
INSERT INTO va_admin_privileges_settings (`privilege_id`,`block_name`,`permission`) VALUES (1 , 'web_pages' , 1 ) ;


INSERT INTO va_admins (`admin_id`,`admin_name`,`privilege_id`,`email`,`login`,`password`) VALUES (1 , 'Site Administrator' , 1 , 'admin@yoursite.com' , 'admin' , 'admin' ) ;


INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (1 , 0 , '0,' , 'Books' , 2 , 1 , '' , '' , 'images/categories/books.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (2 , 1 , '0,1,' , 'Arts & Photography' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (3 , 0 , '0,' , 'Toys & Games' , 3 , 1 , '' , '' , 'images/categories/games.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (4 , 3 , '0,3,' , 'Games' , 1 , 1 , '' , '' , 'images/categories/dvd.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (5 , 0 , '0,' , 'DVD' , 4 , 1 , '' , '' , 'images/categories/dvd.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (8 , 1 , '0,1,' , 'Travel' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (9 , 1 , '0,1,' , 'Mystery & Thrillers' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (10 , 1 , '0,1,' , 'Christian Books' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (11 , 1 , '0,1,' , 'Science Fiction & Fantasy' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (12 , 5 , '0,5,' , 'African American Cinema' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (13 , 0 , '0,' , 'Software' , 1 , 1 , '' , '' , 'images/categories/software.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (14 , 13 , '0,13,' , 'Web Development' , 3 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (15 , 5 , '0,5,' , 'Comedy' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (16 , 13 , '0,13,' , 'Graphics' , 2 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (17 , 0 , '0,' , 'Electronics' , 6 , 1 , '' , '' , 'images/categories/electronics.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (18 , 17 , '0,17,' , 'MP3 Players' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (19 , 13 , '0,13,' , 'Games' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (21 , 0 , '0,' , 'Camera & Photo' , 7 , 1 , '' , '' , 'images/categories/cameras.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (22 , 21 , '0,21,' , 'Binoculars' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (24 , 0 , '0,' , 'Music' , 8 , 1 , '' , '' , 'images/categories/music.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (25 , 24 , '0,24,' , 'Hard Rock & Metal' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (26 , 24 , '0,24,' , 'Folk' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (27 , 24 , '0,24,' , 'Children\'s' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (28 , 24 , '0,24,' , 'New Age' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (29 , 3 , '0,3,' , 'Bikes, Scooters & More...' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (30 , 24 , '0,24,' , 'Classical' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (31 , 0 , '0,' , 'Health & Beauty' , 9 , 1 , '' , '' , 'images/categories/beauty.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (32 , 0 , '0,' , 'Tools & Hardware' , 10 , 1 , '' , '' , 'images/categories/hardware.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (33 , 32 , '0,32,' , 'Accessories' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (34 , 3 , '0,3,' , 'Stuffed Animals' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (35 , 0 , '0,' , 'Computers' , 11 , 1 , '' , '' , 'images/categories/computers.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (36 , 35 , '0,35,' , 'Notebooks' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (37 , 35 , '0,35,' , 'Desktops' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (38 , 21 , '0,21,' , 'Accessories' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (39 , 21 , '0,21,' , 'Camcorders' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (41 , 35 , '0,35,' , 'Monitors' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (43 , 0 , '0,' , 'Cell Phones & Service' , 5 , 1 , '' , '' , 'images/categories/cellphones.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (44 , 43 , '0,43,' , 'Phones' , 1 , 1 , '' , '' , '' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (47 , 0 , '0,' , 'Amazon\'s affiliates' , 12 , 1 , 'This category shows you how to create an affiliate program with Amazon.com' , 'This category shows you how to create an affiliate program with Amazon.com' , 'images/categories/books.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (48 , 47 , '0,47,' , 'Books' , 1 , 1 , 'Buy books with Amazon.com' , NULL , 'images/categories/books.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (49 , 48 , '0,47,48,' , 'Science Fiction & Fantasy' , 1 , 1 , NULL , NULL , 'images/categories/computers.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (50 , 48 , '0,47,48,' , 'Christian Books' , 2 , 1 , NULL , NULL , 'images/categories/house.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (51 , 48 , '0,47,48,' , 'Mystery & Thrillers' , 3 , 1 , NULL , NULL , 'images/categories/theatre.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (52 , 48 , '0,47,48,' , 'Travel' , 4 , 1 , NULL , NULL , 'images/categories/travel.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (53 , 48 , '0,47,48,' , 'Arts & Photography  ' , 5 , 1 , NULL , NULL , 'images/categories/cameras.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (54 , 47 , '0,47,' , 'DVD' , 2 , 1 , 'Buy DVD\'s with Amazon.com' , NULL , 'images/categories/dvd.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (55 , 54 , '0,47,54,' , 'Comedy' , 1 , 1 , NULL , NULL , 'images/categories/dvd.gif' ) ;
INSERT INTO va_categories (`category_id`,`parent_category_id`,`category_path`,`category_name`,`category_order`,`is_showing`,`short_description`,`full_description`,`image`) VALUES (56 , 54 , '0,47,54,' , 'African American Cinema' , 2 , 1 , NULL , NULL , 'images/categories/dvd.gif' ) ;


INSERT INTO va_cc_expiry_years (`expiry_year`) VALUES (2005 ) ;
INSERT INTO va_cc_expiry_years (`expiry_year`) VALUES (2006 ) ;
INSERT INTO va_cc_expiry_years (`expiry_year`) VALUES (2007 ) ;
INSERT INTO va_cc_expiry_years (`expiry_year`) VALUES (2008 ) ;
INSERT INTO va_cc_expiry_years (`expiry_year`) VALUES (2009 ) ;
INSERT INTO va_cc_expiry_years (`expiry_year`) VALUES (2010 ) ;


INSERT INTO va_cc_start_years (`start_year`) VALUES (1999 ) ;
INSERT INTO va_cc_start_years (`start_year`) VALUES (2000 ) ;
INSERT INTO va_cc_start_years (`start_year`) VALUES (2001 ) ;
INSERT INTO va_cc_start_years (`start_year`) VALUES (2002 ) ;
INSERT INTO va_cc_start_years (`start_year`) VALUES (2003 ) ;
INSERT INTO va_cc_start_years (`start_year`) VALUES (2004 ) ;
INSERT INTO va_cc_start_years (`start_year`) VALUES (2005 ) ;


INSERT INTO va_change_types (`type_id`,`type_name`) VALUES (1 , 'Bug' ) ;
INSERT INTO va_change_types (`type_id`,`type_name`) VALUES (2 , 'New Feature' ) ;


INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AD' , 3 , 'Andorra' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AE' , 3 , 'United Arab Emirates' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AF' , 3 , 'Afghanistan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AG' , 3 , 'Antigua and Barbuda' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AI' , 3 , 'Anguilla' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AL' , 3 , 'Albania' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AM' , 3 , 'Armenia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AN' , 2 , 'Netherlands Antilles' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AO' , 3 , 'Angola' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AQ' , 3 , 'Antarctica' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AR' , 3 , 'Argentina' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AS' , 3 , 'American Samoa' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AT' , 2 , 'Austria EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AU' , 3 , 'Australia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AW' , 3 , 'Aruba' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('AZ' , 3 , 'Azerbaijan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BA' , 3 , 'Bosnia and Herzegowina' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BB' , 3 , 'Barbados' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BD' , 3 , 'Bangladesh' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BE' , 2 , 'Belgium EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BF' , 3 , 'Burkina Faso' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BG' , 3 , 'Bulgaria' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BH' , 3 , 'Bahrain' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BI' , 3 , 'Burundi' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BJ' , 3 , 'Benin' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BM' , 3 , 'Bermuda' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BN' , 3 , 'Brunei Darussalam' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BO' , 3 , 'Bolivia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BR' , 3 , 'Brazil' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BS' , 3 , 'Bahamas' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BT' , 3 , 'Bhutan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BV' , 3 , 'Bouvet Island' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BW' , 3 , 'Botswana' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BY' , 3 , 'Belarus' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('BZ' , 3 , 'Belize' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CA' , 3 , 'Canada' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CC' , 3 , 'Cocos (Keeling) Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CF' , 3 , 'Central African Republic' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CG' , 3 , 'Congo' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CH' , 3 , 'Switzerland' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CI' , 3 , 'Cote D\'Ivoire' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CK' , 3 , 'Cook Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CL' , 3 , 'Chile' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CM' , 3 , 'Cameroon' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CN' , 3 , 'China' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CO' , 3 , 'Colombia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CR' , 3 , 'Costa Rica' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CU' , 3 , 'Cuba' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CV' , 3 , 'Cape Verde' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CX' , 3 , 'Christmas Island' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CY' , 2 , 'Cyprus EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('CZ' , 2 , 'Czech Republic EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('DE' , 2 , 'Germany EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('DJ' , 3 , 'Djibouti' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('DK' , 2 , 'Denmark EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('DM' , 3 , 'Dominica' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('DO' , 3 , 'Dominican Republic' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('DZ' , 3 , 'Algeria' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('EC' , 3 , 'Ecuador' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('EE' , 2 , 'Estonia EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('EG' , 3 , 'Egypt' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('EH' , 3 , 'Western Sahara' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ER' , 3 , 'Eritrea' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ES' , 2 , 'Spain EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ET' , 3 , 'Ethiopia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('FI' , 2 , 'Finland EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('FJ' , 3 , 'Fiji' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('FK' , 3 , 'Falkland Islands (Malvinas)' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('FM' , 3 , 'Micronesia, Federated States of' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('FO' , 3 , 'Faroe Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('FR' , 2 , 'France EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('FX' , 3 , 'France, Metropolitan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GA' , 3 , 'Gabon' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GB' , 1 , 'United Kingdom' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GD' , 3 , 'Grenada' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GE' , 3 , 'Georgia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GF' , 3 , 'French Guiana' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GH' , 3 , 'Ghana' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GI' , 3 , 'Gibraltar' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GL' , 3 , 'Greenland' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GM' , 3 , 'Gambia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GN' , 3 , 'Guinea' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GP' , 3 , 'Guadeloupe' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GQ' , 3 , 'Equatorial Guinea' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GR' , 2 , 'Greece EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GT' , 3 , 'Guatemala' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GU' , 3 , 'Guam' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GW' , 3 , 'Guinea-Bissau' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('GY' , 3 , 'Guyana' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('HK' , 3 , 'Hong Kong' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('HM' , 3 , 'Heard and Mc Donald Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('HN' , 3 , 'Honduras' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('HR' , 3 , 'Croatia (local name: Hrvatska)' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('HT' , 3 , 'Haiti' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('HU' , 2 , 'Hungary EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ID' , 3 , 'Indonesia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IE' , 2 , 'Ireland EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IL' , 3 , 'Israel' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IN' , 3 , 'India' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IO' , 3 , 'British Indian Ocean Territory' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IQ' , 3 , 'Iraq' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IR' , 3 , 'Iran (Islamic Republic of)' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IS' , 3 , 'Iceland' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('IT' , 2 , 'Italy EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('JM' , 3 , 'Jamaica' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('JO' , 3 , 'Jordan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('JP' , 3 , 'Japan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KE' , 3 , 'Kenya' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KG' , 3 , 'Kyrgyzstan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KH' , 3 , 'Cambodia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KI' , 3 , 'Kiribati' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KM' , 3 , 'Comoros' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KN' , 3 , 'Saint Kitts and Nevis' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KP' , 3 , 'Korea, Democratic People\'s Republic of' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KR' , 3 , 'Korea, Republic of' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KW' , 3 , 'Kuwait' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KY' , 3 , 'Cayman Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('KZ' , 3 , 'Kazakhstan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LA' , 3 , 'Lao People\'s Democratic Republic' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LB' , 3 , 'Lebanon' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LC' , 3 , 'Saint Lucia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LI' , 3 , 'Liechtenstein' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LK' , 3 , 'Sri Lanka' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LR' , 3 , 'Liberia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LS' , 3 , 'Lesotho' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LT' , 2 , 'Lithuania EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LU' , 2 , 'Luxembourg EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LV' , 2 , 'Latvia EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('LY' , 3 , 'Libyan Arab Jamahiriya' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MA' , 3 , 'Morocco' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MC' , 2 , 'Monaco' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MD' , 3 , 'Moldova, Republic of' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MG' , 3 , 'Madagascar' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MH' , 3 , 'Marshall Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MK' , 3 , 'Macedonia, the former Yugoslav Republic of' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ML' , 3 , 'Mali' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MM' , 3 , 'Myanmar' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MN' , 3 , 'Mongolia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MO' , 3 , 'Macau' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MP' , 3 , 'Northern Mariana Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MQ' , 3 , 'Martinique' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MR' , 3 , 'Mauritania' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MS' , 3 , 'Montserrat' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MT' , 2 , 'Malta EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MU' , 3 , 'Mauritius' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MV' , 3 , 'Maldives' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MW' , 3 , 'Malawi' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MX' , 3 , 'Mexico' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MY' , 3 , 'Malaysia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('MZ' , 3 , 'Mozambique' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NA' , 3 , 'Namibia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NC' , 3 , 'New Caledonia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NE' , 3 , 'Niger' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NF' , 3 , 'Norfolk Island' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NG' , 3 , 'Nigeria' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NI' , 3 , 'Nicaragua' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NL' , 2 , 'Netherlands EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NO' , 3 , 'Norway' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NP' , 3 , 'Nepal' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NR' , 3 , 'Nauru' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NU' , 3 , 'Niue' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('NZ' , 3 , 'New Zealand' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('OM' , 3 , 'Oman' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PA' , 3 , 'Panama' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PE' , 3 , 'Peru' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PF' , 3 , 'French Polynesia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PG' , 3 , 'Papua New Guinea' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PH' , 3 , 'Philippines' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PK' , 3 , 'Pakistan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PL' , 2 , 'Poland EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PM' , 3 , 'St. Pierre and Miquelon' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PN' , 3 , 'Pitcairn' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PR' , 3 , 'Puerto Rico' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PT' , 2 , 'Portugal EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PW' , 3 , 'Palau' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('PY' , 3 , 'Paraguay' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('QA' , 3 , 'Qatar' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('RE' , 3 , 'Reunion' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('RO' , 3 , 'Romania' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('RU' , 3 , 'Russian Federation' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('RW' , 3 , 'Rwanda' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SA' , 3 , 'Saudi Arabia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SB' , 3 , 'Solomon Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SC' , 3 , 'Seychelles' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SD' , 3 , 'Sudan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SE' , 2 , 'Sweden EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SG' , 3 , 'Singapore' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SH' , 3 , 'St. Helena' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SI' , 2 , 'Slovenia EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SJ' , 3 , 'Svalbard and Jan Mayen Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SK' , 2 , 'Slovakia (Slovak Republic) EU' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SL' , 3 , 'Sierra Leone' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SM' , 3 , 'San Marino' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SN' , 3 , 'Senegal' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SO' , 3 , 'Somalia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SR' , 3 , 'Suriname' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ST' , 3 , 'Sao Tome and Principe' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SV' , 3 , 'El Salvador' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SY' , 3 , 'Syrian Arab Republic' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('SZ' , 3 , 'Swaziland' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TC' , 3 , 'Turks and Caicos Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TD' , 3 , 'Chad' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TF' , 3 , 'French Southern Territories' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TG' , 3 , 'Togo' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TH' , 3 , 'Thailand' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TJ' , 3 , 'Tajikistan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TK' , 3 , 'Tokelau' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TM' , 3 , 'Turkmenistan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TN' , 3 , 'Tunisia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TO' , 3 , 'Tonga' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TP' , 3 , 'East Timor' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TR' , 3 , 'Turkey' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TT' , 3 , 'Trinidad and Tobago' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TV' , 3 , 'Tuvalu' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TW' , 3 , 'Taiwan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('TZ' , 3 , 'Tanzania, United Republic of' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('UA' , 3 , 'Ukraine' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('UG' , 3 , 'Uganda' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('UM' , 3 , 'United States Minor Outlying Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('US' , 1 , 'United States' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('UY' , 3 , 'Uruguay' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('UZ' , 3 , 'Uzbekistan' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('VA' , 3 , 'Vatican City State (Holy See)' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('VC' , 3 , 'Saint Vincent and the Grenadines' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('VE' , 3 , 'Venezuela' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('VG' , 3 , 'Virgin Islands (British)' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('VI' , 3 , 'Virgin Islands (U.S.)' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('VN' , 3 , 'Vietnam' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('VU' , 3 , 'Vanuatu' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('WF' , 3 , 'Wallis And Futuna Islands' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('WS' , 3 , 'Samoa' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('YE' , 3 , 'Yemen' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('YT' , 3 , 'Mayotte' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('YU' , 3 , 'Yugoslavia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ZA' , 3 , 'South Africa' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ZM' , 3 , 'Zambia' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ZR' , 3 , 'Zaire' ) ;
INSERT INTO va_countries (`country_code`,`country_order`,`country_name`) VALUES ('ZW' , 3 , 'Zimbabwe' ) ;


INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (1 , 'VISA' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (2 , 'VISA Electron' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (3 , 'Mastercard' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (4 , 'American Express' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (5 , 'Switch' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (6 , 'Solo' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (7 , 'JCB' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (8 , 'Delta' ) ;
INSERT INTO va_credit_cards (`credit_card_id`,`credit_card_name`) VALUES (9 , 'Eurocard' ) ;


INSERT INTO va_custom_blocks (`block_id`,`block_title`,`block_desc`) VALUES (2 , 'Custom Block' , 'Feel free to add any text here' ) ;










INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}\r\n\r\nPay Without Credit Card Info:\r\n{pay_without_cc}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'admin_subject' , 'Credit Card Information for Oder No: {order_id}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'pay_without_cc_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_cc_start_date' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('credit_card_info' , 'show_pay_without_cc' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'admin_message' , 'Topic descrition:\r\n{topic_description}\r\n\r\nMessage:\r\n{message}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'admin_subject' , 'New post at forum :: {topic}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'intro_text' , 'Have you ever wondered whether the problem you are having is one that someone else has experienced? Would you like to share your expertise with new users?\r\n<br><br>\r\nWhy don\'t you become a Forum user and become a part of the community. \r\n' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'user_message' , 'Topic descrition:\r\n{topic_description}\r\n\r\nMessage:\r\n{message}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'user_notification' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('forum' , 'user_subject' , 'New post at your topic :: {topic}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'admin_email' , 'admin@yoursite.com' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'approve_review' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'change_quantity' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'country_code' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'currency_position' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'currency_sign' , '$' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'html_below_footer' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'html_on_index' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'layout_id' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'min_rating' , '4' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'min_votes' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'payment_id' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'quantity_control' , 'LISTBOX' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'reviews_availability' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'reviews_per_page' , '10' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'site_url' , 'http://www.yoursite.com/' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('global' , 'weight_measure' , 'lb' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'admin_message' , 'Customer Information\r\n--------------------\r\n  Customer Name: {name}\r\nCustomer E-mail: {email}\r\nCC Last 4 Digit: {cc_number_last}\r\n\r\nShopping Cart Info\r\n------------------\r\nTotal Items: {total_quantity}\r\n     Amount: {goods_total}\r\n\r\n' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'admin_subject' , 'Order #{order_id} was placed.' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'user_message' , '{name} thank you for placing order.\r\n\r\nRegistered users can get information about placed orders at {site_url}user_home.php' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_confirmation' , 'user_subject' , 'Your order was placed!' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_final' , 'final_message' , '<div class="bigtitle">Thank You for Purchase!</div>\r\n\r\n<p align="justify">\r\nThank you for your order. You\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_final' , 'links_cc' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_final' , 'links_from' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_final' , 'links_message' , 'To download product click on link below\r\n{links}\r\n\r\nThanks for purchase,\r\nSupport Team.\r\n' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_final' , 'links_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_final' , 'links_subject' , 'Links for your Order # {order_id}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_final' , 'max_downloads' , '3' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'address1_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'address2_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'admin_message' , '{basket}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'admin_subject' , 'New order #{order_id} submitted' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'city_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'company_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'country_code_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'daytime_phone_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_address1_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_address2_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_city_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_company_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_country_code_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_daytime_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_email_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_evening_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_fax_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_name_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_province_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_state_code_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'delivery_zip_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'email_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'evening_phone_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'fax_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'first_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'last_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'name_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'province_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_address1' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_address2' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_city' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_company_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_country_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_daytime_phone' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_address1' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_address2' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_city' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_company_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_country_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_daytime_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_email' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_evening_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_fax' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_first_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_last_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_name' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_province' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_state_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_delivery_zip' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_email' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_evening_phone' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_fax' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_first_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_last_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_name' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_province' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_state_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'show_zip' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'state_code_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'user_message' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'user_notification' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'user_subject' , '{name} your contact information was saved.' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('order_info' , 'zip_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'admin_message' , 'Request Description:\r\n{description}\r\n\r\nReply message:\r\n{message_text}\r\n\r\n{site_url}admin/admin_support_reply.php?support_id={support_id}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'admin_subject' , 'Support Request :: {summary}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'intro_text' , 'Dont hesitate to contact us if you have any questions or problems. Our Support Team try help you with your request.' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'user_message' , '{message_text}\r\n\r\nUse following URL to reply\r\n{support_url}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'user_notification' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('support' , 'user_subject' , 'Support Request :: {summary}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'address1_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'address2_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'admin_message' , 'Name: {name}\r\nDate: {registration_date}' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'admin_subject' , 'New user was registered' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'city_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'company_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'country_code_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'daytime_phone_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_address1_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_address2_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_city_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_company_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_country_code_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_daytime_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_email_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_evening_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_fax_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_name_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_province_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_state_code_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'delivery_zip_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'email_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'evening_phone_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'fax_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'first_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'intro_text_new' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'intro_text_registered' , NULL ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'last_name_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'name_required' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'phone_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'province_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_address1' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_address2' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_city' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_company_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_country_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_daytime_phone' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_address1' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_address2' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_city' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_company_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_country_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_daytime_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_email' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_evening_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_fax' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_first_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_last_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_name' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_province' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_state_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_delivery_zip' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_email' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_evening_phone' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_fax' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_first_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_last_name' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_name' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_phone' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_province' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_state_code' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'show_zip' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'state_code_required' , '0' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'user_message' , 'Your login is <b>{login}</b> and password is <b>{password}</b><br>\r\n<br><br>\r\nYou can visit our site at any time at following URL: <a target="_blank" href="{site_url}">{site_url}</a>' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'user_message_type' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'user_subject' , 'Dear {name}, you was successfully registered' ) ;
INSERT INTO va_global_settings (`setting_type`,`setting_name`,`setting_value`) VALUES ('user_profile' , 'zip_required' , '1' ) ;


INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (1 , 2 , 'Main' , 'index.php' , 'images/curved/menu-main.gif' , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (2 , 2 , 'Products' , 'products.php' , 'images/curved/menu-products.gif' , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (3 , 2 , 'Basket' , 'basket.php' , 'images/curved/menu-basket.gif' , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (4 , 2 , 'Profile' , 'user_profile.php' , 'images/curved/menu-registration.gif' , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (5 , 2 , 'Administration' , 'admin/admin.php' , 'images/curved/menu-admin.gif' , NULL , 5 , 1 , 0 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (6 , 2 , 'Events' , 'events.php' , 'images/curved/menu-events.gif' , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (7 , 2 , NULL , 'index.php' , 'images/curved/logo_os.gif' , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (8 , 2 , 'News' , 'news.php' , 'images/curved/menu-news.gif' , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (9 , 2 , 'User Home' , 'user_home.php' , 'images/curved/menu-user_home.gif' , NULL , 9 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (10 , 2 , 'Support' , 'support.php' , 'images/curved/menu-support.gif' , NULL , 10 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (11 , 2 , 'Forum' , 'forum.php' , 'images/curved/menu-forum.gif' , NULL , 11 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (12 , 2 , 'Help' , 'page.php?page=help' , 'images/curved/menu-help.gif' , NULL , 12 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (13 , 2 , 'About Us' , 'page.php?page=about' , 'images/curved/menu-about.gif' , NULL , 13 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (21 , 1 , 'Home' , 'index.php' , 'images/default/menu-home.gif' , 'images/default/menu-home-a.gif' , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (22 , 1 , 'Products' , 'products.php' , 'images/default/menu-products.gif' , 'images/default/menu-products-a.gif' , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (23 , 1 , 'Basket' , 'basket.php' , 'images/default/menu-basket.gif' , 'images/default/menu-basket-a.gif' , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (24 , 1 , 'Sign In' , 'user_login.php' , 'images/default/menu-signin.gif' , 'images/default/menu-signin-a.gif' , 4 , 1 , 0 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (25 , 1 , 'Account' , 'user_home.php' , 'images/default/menu-account.gif' , 'images/default/menu-account-a.gif' , 5 , 0 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (26 , 1 , 'News' , 'news.php' , 'images/default/menu-news.gif' , 'images/default/menu-news.gif' , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (27 , 1 , 'Support' , 'support.php' , 'images/default/menu-support.gif' , 'images/default/menu-support-a.gif' , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (28 , 1 , 'Forum' , 'forum.php' , 'images/default/menu-forum.gif' , 'images/default/menu-forum-a.gif' , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (29 , 1 , 'Events' , 'events.php' , 'images/default/menu-events.gif' , 'images/default/menu-events-a.gif' , 9 , 0 , 0 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (30 , 1 , 'FAQ' , 'faq.php' , 'images/default/menu-faq.gif' , 'images/default/menu-faq-a.gif' , 10 , 0 , 0 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (31 , 1 , 'Help' , 'page.php?page=help' , 'images/default/menu-help.gif' , 'images/default/menu-help-a.gif' , 11 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (32 , 1 , 'About' , 'page.php?page=about' , 'images/default/menu-about.gif' , 'images/default/menu-about-a.gif' , 12 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (33 , 3 , 'Home' , 'index.php' , 'images/silver/menu-home.gif' , 'images/silver/menu-home-a.gif' , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (34 , 3 , 'Products' , 'products.php' , 'images/silver/menu-products.gif' , 'images/silver/menu-products-a.gif' , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (35 , 3 , 'Basket' , 'basket.php' , 'images/silver/menu-basket.gif' , 'images/silver/menu-basket-a.gif' , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (36 , 3 , 'Sign In' , 'user_login.php' , 'images/silver/menu-signin.gif' , 'images/silver/menu-signin-a.gif' , 4 , 1 , 0 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (37 , 3 , 'Sign Out' , 'user_login.php?operation=logout' , 'images/silver/menu-signout.gif' , 'images/silver/menu-signout.gif' , 5 , 0 , 1 ) ;
INSERT INTO va_header_links (`menu_id`,`layout_id`,`menu_title`,`menu_url`,`menu_image`,`menu_image_active`,`menu_order`,`show_non_logged`,`show_logged`) VALUES (38 , 3 , 'About Us' , 'page.php?page=about' , 'images/silver/menu-about.gif' , 'images/silver/menu-about-a.gif' , 6 , 1 , 1 ) ;


INSERT INTO va_issue_numbers (`issue_number`) VALUES (1 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (2 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (3 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (4 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (5 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (6 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (7 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (8 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (9 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (10 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (11 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (12 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (13 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (14 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (15 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (16 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (17 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (18 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (19 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (20 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (21 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (22 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (23 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (24 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (25 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (26 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (27 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (28 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (29 ) ;
INSERT INTO va_issue_numbers (`issue_number`) VALUES (30 ) ;


INSERT INTO va_item_types (`item_type_id`,`item_type_name`) VALUES (1 , 'Product' ) ;
INSERT INTO va_item_types (`item_type_id`,`item_type_name`) VALUES (2 , 'Accessory' ) ;


INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (4 , 'Manhattan Unfurled' , 1 , 1 , 2 , '0375504915' , NULL , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New... ' , 0 , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New Yorks shoreline profilefrom Queens, Brooklyn, the Bronx, and New Jersey (which he reached by motorcycle)  and make two continuous and continuously enchanting pen-and-ink drawing of Manhattans skyline. \r\n\r\nManhattan Unfurled is published in an elegant slipcase, and the drawings fold out, accordion-style, with the West on one side and the East on the other. An introduction by distinguished New Yorker architecture critic Paul Goldberger, who first wrote bout Matteos project in The New Yorkers Talk of the Town, will accompany the drawing in a separate pamphlet. This book is both a wonderful New York City memento, perfect for gift giving, and an entirely unique work of art.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0375504915.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0375504915.01.MZZZZZZZ.jpg' , NULL , NULL , 29.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 20.96 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (5 , 'The Artist\'s Way Morning Pages Journal : A Companion Volume to the Artist\'s Way' , 1 , 1 , 2 , '0874778867' , NULL , NULL , 0 , 'The idea behind Julia Cameron\'s The Artist\'s Way is that by writing three pages, longhand and stream-of consciousness, first thing in the morning, you can overcome the obstacles that stop you from becoming your most creative self. This works partly because it forces you to create something (even if it is just a long list of gripes) every single day. It doesn\'t take much time. You\'re not even supposed to think. But the act itself gets you past all that self-defeating fretting about why you think you aren\'t a creative person. Cameron sees her morning pages as "a form of meditation," as "spiritual windshield wipers."\r\nWhile Cameron touts the morning pages as a way of life, she suggests you start out doing them as part of a "twelve-week program to recover your creativity." If you would like to keep your first twelve weeks of morning pages together in one tidy place, The Artist\'s Way Morning Pages Journal is a fine tool for doing so. Each nearly blank page features an inspiring quotation from The Artist\'s Way: "Leap, and the net will appear," says one; "Creativity lies not in the done but in doing," reminds another. We should mention that many of these little inspirations include references to God, which may be troublesome even for spiritual atheists. --Jane Steinberg \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0874778867.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0874778867.01.MZZZZZZZ.gif' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 11.96 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (6 , 'Patience & Fortitude : A Roving Chronicle of Book People, Book Places, and Book Culture' , 1 , 1 , 2 , '0060196955' , NULL , NULL , 0 , 'A sequel of sorts to Basbanes\'s earlier A Gentle Madness (on the manic nature of bookselling and book-collecting), this copious volume takes its title from the formidable lions guarding the entrance to the main branch of the New York Public Library in Manhattan. Opening with the great libraries of the past, from Alexandria to Pergamum and Glastonbury, Basbanes, former literary editor of the Worcester Sunday Telegram, segues into such venerable active libraries as those at the Vatican, Wolfenbottel and the universities of Durham, Leiden and Oxford. He visits with shrewd, sometimes eccentric book dealers who happily recount tales of bygone bibliophiles, and illustrates a variety of collections, from illuminated medieval manuscripts to volumes more valuable for who owned them than for binding or content. "I absolutely insist on keeping the same crummy look," a bookshop owner tells him proudly. "Every time I make the place too neat, business goes down." But a pathos pervades the book, for despite the huge increase in readers and book buyers, one dealer observes "a radical dismantling of high culture well under way" since the 1930s. The collector in 1939 who bought a rare book about Native American languages "by selling bottles of his own blood" has no latter-day parallel. Basbanes closes with tales of crusty benefactors like Andrew Carnegie, and interviews with librarians faced with the dilemma of too many old books that no one now wants to read. Basbanes\'s fund of stories will delight readers who value books for more than just a good story, have a yen for second-hand books plucked from dusty shops or look to book catalogs for suspense and excitement. 32 pages of b&w photos not seen by PW. Agents, Glen Hartley and Lynn T. Chu. (Oct.)Forecast: This will undoubtedly garner much attention in the book pages, as did its predecessor, aided by a six-city author tour, a 15-city NPR campaign and print features.\r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060196955.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0060196955.01.MZZZZZZZ.jpg' , NULL , NULL , 35 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 24.5 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (7 , 'Rock Star' , 1 , 1 , 2 , 'B00005TPMA' , NULL , 'Watch Mark Wahlberg and Jennifer Aniston live the highs and lows of a rock  & roll fantasy come true in Rock Star.  Black leather pants recommended.\r\n' , 0 , 'This movie is a must for your collection, especially if you\'re fan of BIG HAIR ROCK. I grew up with the type of music this film is based on. I thought Mark Wahlberg did an amazing job of capturing the essence of a Heavy Metal  frontman. He had the perfect swagger and look. Even if you aren\'t a huge fan of Metal, I\'m sure at one time you\'ve fantasized about being a rock star or some type of entertainer, right? I\'m sure you\'ll be able to relate to the story of a guy who sings for a tribute band of his heroes, eventually getting the call to front the ACTUAL band. Jennifer Aniston and the cast of real life rockers like guitarist Zakk Wylde and Third Eye Blind\'s Stephan Jenkins are all great too. Oh and by the way... the soundtrack CD is also excellent, with original music from the film\'s  band, Steel Dragon and classics from KISS, Bon Jovi and others. For a fun film  ride I enthusiastically recommend ROCK STAR! Enjoy!!!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.25TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005TPMA.01.MZZZZZZZ.jpg' , NULL , NULL , 19.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.95 , 25 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (8 , 'Extreme Beauty: The Body Transformed' , 1 , 1 , 2 , '0300091176' , NULL , NULL , 0 , 'From Publishers Weekly \r\nHigh-heeled shoes, push-up bras, Elizabethan ruffs and Japanese platform clogs are just a few examples of clothing that has pushed and pulled the human form into new shapes in the last few centuries. With color photos and illustrations, Extreme Beauty: The Body Transformed, which accompanies a Metropolitan Museum of Art exhibit of the same name, traces the role of fashion in manipulating the body to fit physical ideals. Harold Koda, curator of the Met\'s Costume Institute, focuses on extreme exaggerations of human form like the European 19th-century bustle, tiny corseted waists or the enormous-hipped dresses of the 18th-century French court, but also shows how today\'s designers quote and send up these iconic shapes. \r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0300091176.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0300091176.01.MZZZZZZZ.jpg' , NULL , NULL , 40 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 28 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (9 , 'Anthony Blunt: His Lives' , 1 , 1 , 2 , '0374105316' , NULL , NULL , 0 , 'From Publishers Weekly \r\nThis engaging and important biography examines the many masks of the infamous Anthony Blunt (1907-1983), the Cambridge art historian turned spy who worked simultaneously for British Intelligence and the Soviet Union during WWII. Why did he betray his country? Carter provides an exhaustive psychological study of Blunt\'s early life. His brutalizing public school (where he was unhappy and unpopular), Carter argues, "inadvertently fostered a questioning and subversive attitude and a profound distrust of authority." When the Depression hit England in the 1930s and the specter of fascism threatened Europe, communism became fashionable among left-leaning intellectuals like Blunt and his Cambridge friend Guy Burgess. Blunt\'s homosexuality, like Burgess\'s, also appears to have alienated him from the establishment. During WWII, Blunt was assigned to British intelligence, giving him easy access to military secrets, which he smuggled to the Soviets. After his Cambridge spy friends Burgess, Donald MacLean and Kim Philby defected to the Soviet Union after the war, British Intelligence began investigating Blunt. In 1964, he was granted immunity in exchange for his confession and full cooperation. British intelligence worked hard to keep "the Blunt affair" a secret. He wasn\'t publicly exposed until 1979, when Margaret Thatcher denounced him. The biggest challenge any Blunt biographer faces is Blunt himself, a man of almost legendary emotional detachment. Blunt revealed little about his personal life, yet Carter has managed to bring readers as close to this enigmatic man as humanly possible. Thoroughly researched and carefully crafted, this is sure to be the definitive biography. 16 pages of photos not seen by PW. (Jan.)Forecast: Blunt\'s story isn\'t quite the sensation here that it is in England; devotees of spy tales and contemporary British history will read this.\r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0374105316.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0374105316.01.MZZZZZZZ.jpg' , NULL , NULL , 30 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 21 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (10 , 'Awakening the Virgin' , 1 , 1 , 2 , '1555834566' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1555834566.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/1555834566.01.MZZZZZZZ.jpg' , NULL , NULL , 13.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.16 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (11 , 'Beaches' , 1 , 1 , 2 , '0811826503' , NULL , NULL , 0 , 'The authors of The Beach: The History of Paradise on Earth, the best-selling history of everyone\'s favorite place, are back with a breathtaking visual companion. From moody, craggy coastlines to serene swathes of turquoise water and white sand, Beaches is an astounding photographic survey of the ineffable allure of paradise on earth. This spectacular collection of images from renowned photographers, including Robert Misrach, Joel Meyerowitz, and Art Wolff, stirs the spirit, capturing the mutable beauty of sand, sea, and sky. Throughout, concise and poetic pieces of historic and scientific lore unveil little-known facts and curiosities. With an astonishing range of vision, Beaches evokes the idiosyncratic beauty of the world\'s most stunning coastlines. \r\n\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0811826503.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0811826503.01.MZZZZZZZ.jpg' , NULL , NULL , 24.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (12 , 'Beaches of Maui County (A Kolowalu Book)' , 1 , 1 , 2 , '0824812468' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0824812468.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0824812468.01.MZZZZZZZ.jpg' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.96 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (13 , 'Exploring Southern California Beaches (FalconGuide)' , 1 , 1 , 2 , '1560446323' , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 1 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes ...' , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , 18.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 30 , 0 , NULL , NULL , 1 , '' , 2 , 10 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (14 , 'Go Fish (1994) DVD ~ Guinevere Turner' , 1 , 1 , 2 , 'B00005BKZK' , NULL , NULL , 0 , 'Go Fish won acclaim in its initial release in 1994, probably because of its irreverence in gazing at the lives of a group of young lesbians in Chicago. The film was directed and cowritten by Rose Troche, who went on to make Bedrooms and Hallways with the help of Guinevere Turner, her then-partner and star of this film. (Turner later appeared in several films and collaborated with director Mary Harron to bring the nearly unadaptable Bret Easton Ellis novel American Psycho to the big screen.)  Go Fish is an audience film in that it needs a crowd to make its in-joke mentality pulse. In fact, it\'s hard to believe the film transcended its target demographic despite the fact that in its heart of hearts it\'s an old-fashioned love story. It feels amateurish upon solo home viewing, though retaining an iota of charm for its low-budget clunkiness and funkiness. While it basically tells the story of a young lesbian (played by Turner) looking for Ms. Right, and conforms to a standard scenario in that love is always found where it\'s least expected, it benefits mostly from Troche\'s ability to wring some wit out of "dyke drama" and, with her insider\'s point of view, poke gentle fun at it with a relatively sharp stick.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BKZK.01.10TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005BKZK.01.MZZZZZZZ.jpg' , NULL , NULL , 19.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 17.98 , 10 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (15 , 'Urbania' , 1 , 1 , 2 , 'B0000584ZI' , NULL , NULL , 0 , 'Jon Shear\'s film, one of the overlooked gems of 2000, simmers under a tense, disturbing air of inevitability. Charlie (Dan Futterman) wanders the nighttime streets of the city, a mournful lost soul determinedly pursuing a mysterious stranger whom he is convinced holds the key to his redemption. He encounters chatty bartenders, pompous pickups, and dying friends (including a biting Alan Cumming), and before long you are treated to that rare, great surprise of realizing that you have no idea where any of it is headed. Some of Shear and Daniel Reitz\'s play-based dialogue is stagy, but the mercurial Futterman, both subtly sympathetic and unstable, is superlative. The film surrounds him with loopy urban legends (the poodle in the microwave, the AIDS-infected one-night-stand, etc.), then cunningly lifts the veil on such stories to reveal the fear motivating them. Uncertainty and isolation create the need for fantastic terrors. Shear hauntingly suggests here how much more horrifying and heartbreaking real life can be.\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B0000584ZI.01.14TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B0000584ZI.01.MZZZZZZZ.jpg' , NULL , NULL , 24.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 21.49 , 14 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (16 , 'The Millionaires' , 1 , 1 , 2 , '0446527297' , NULL , NULL , 0 , 'What would you steal if you couldn\'t get caught? That\'s the tag line of Brad Meltzer\'s new thriller, which pits an ambitious young money manager against a corporate villain, whose intricate financial shenanigans accidentally put a huge chunk of dough right in front of a man who desperately needs it. Of course Oliver Caruso\'s conscience troubles him, but that doesn\'t keep him from letting his somewhat looser and less ethical brother convince him this is too good an opportunity to pass up. Meltzer\'s in interesting territory here, but in order to buy his premise, you have to believe that it\'s OK to steal if you have a good enough reason. This makes his protagonist, who narrates the novel, hard to root for and less than sympathetic. Despite this hollow ring, the book is nicely plotted and should please the author\'s enthusiastic fan club. --Jane Adams ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0446527297.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0446527297.01.MZZZZZZZ.jpg' , NULL , NULL , 25.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.57 , 40 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (17 , 'Blackwater Sound' , 1 , 1 , 2 , '0312203845' , NULL , NULL , 0 , 'A powerful Florida family, its high-tech fortune dwindling, is haunted by an elusive, enormous blue marlin that claimed the life of its eldest son, who was meant to restore the family\'s prominence. But the Braswells are tormented by even darker secrets, such as incest and treason, that drive this dark, atmospheric thriller to an explosive conclusion, which might have been pulled straight from recent headlines. James Hall pits Thorn, his series protagonist, against the Braswells and their deadly plans. Although an existentially morose antihero is a convention of the mystery genre, Hall manages to transcend it with a fascinating plot and a powerful narrative, resulting in a suspenseful and resonant novel that shows off his well-developed talents for character development, place, and pacing. The author of 11 previous mysteries (including Mean High Tide and Rough Draft), Hall gets better with every book, and this one continues the trend. --Jane Adams ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0312203845.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0312203845.01.MZZZZZZZ.jpg' , NULL , NULL , 24.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (18 , 'To Trust a Stranger' , 1 , 1 , 2 , '0671786539' , NULL , NULL , 0 , 'The usual ingredients bubble and boil in Robards\'s latest romantic suspense thriller. Julie Carlson, once a poor girl from the wrong side of the tracks but now the beautiful owner of a successful boutique in Charleston, S.C., seems to have it all. As the novel begins, however, a hit man circles her suburban mansion: Julie\'s rich husband, Sid, has hired thugs to kill her. Unaware of the danger she is in but convinced that Sid is cheating on her, Julie slips out of the house just in time and follows her husband to the red-light district, where she serendipitously and literally runs into private detective Mac McQuarry, dressed up in drag to spy on a client\'s husband. Julie isn\'t sure whether she should trust a man in a dress, but she has no one else to turn to, and soon she and Mac are working together to get the goods on Julie\'s crooked husband. As it happens, Mac holds a personal grudge against Sid, a prominent builder in Charleston, because Sid was involved in the disappearance of Mac\'s half-brother 15 years before, and then got Mac kicked off the police force when Mac tried to prove it. Robards\'s fans will enjoy the machinations before Julie and Mac get together, though cliches clutter every page ("The truth hit him like a hammer over the head: He had a galloping case of the hots for his newest client, who was not incidentally his oldest enemy\'s wife"). Of course, true love solves past mysteries, while hot kisses get as much play as life-threatening confrontations. A bodice ripper at heart, the novel is the equivalent of a box of junk candy. \r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0671786539.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0671786539.01.MZZZZZZZ.jpg' , NULL , NULL , 25 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.5 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (19 , 'Hearse of a Different Color' , 1 , 1 , 2 , '0786889632' , NULL , NULL , 0 , 'Tim Cockey\'s debut novel, The Hearse You Came In On, introduced readers to Hitchcock Sewell, the undertaker-turned-reluctant-sleuth, whose mordant irony and blissfully skewed perspective on the humdrum brought a remarkable vigor to a profession not usually known for its liveliness. The good news for Hitch fans is that Cockey\'s follow-up effort dishes up another heaping helping of sardonic wit: \r\nThe planet was one big marble of wretchedness. And I wasn\'t exactly being lifted aloft by bluebirds either. I was wheeling down the Baltimore- Washington Parkway in my unexciting car on the fourth record-breaking freezing cold day in a row, tuning in to what seemed to be the preexisting fact that I was going to be tracking down a cold-blooded murderer.\r\nSaid murderer has deposited a corpse on Hitch\'s doorstep--in the middle of a wake, no less. The unscheduled body is one Helen Waggoner, a single mother with a double life as a waitress and porn star. Hitch\'s girlfriend sees the unceremonious delivery as a scoop in the making. Bonnie Nash is a less-than- accurate TV weather woman who\'s got a bad case of occupational shame ("I\'m a pair of breasts that tells you what the weather is going to be tomorrow. Maybe."). She figures that solving a murder ought to earn her a network promotion. But it\'s not that easy. When Helen\'s sister also turns to Hitch for some moral and investigative support, the undertaker finds himself digging through the family closets and unearthing some distinctly unsavory skeletons. It turns out that a taste for the (ahem) silver screen is a Waggoner tradition, and that the sisters have a long--and not particularly affectionate--history. It\'s up to Hitch to put the pieces of the puzzle together before a hired killer with a peculiar signature takes him apart.\r\nCockey has a rare gift for sending up the hallowed conventions of mystery fiction with effortlessly wry turns of phrases: "I looked about to assess the scene. I\'m six-three, so I have a decent vantage point for assessing." His plot skills have sharpened since his last outing, and the narrative moves along briskly to a conclusion both tidy and ironic. Appropriately enough, though, in this Hearse, the ride is even more fun than the destination. --Kelly Flynn --This text refers to the Paperback edition. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0786889632.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0786889632.01.MZZZZZZZ.jpg' , NULL , NULL , 7.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 7.99 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (20 , 'Ellen DeGeneres - The Beginning (2000)' , 1 , 1 , 2 , 'B000053VAP' , NULL , NULL , 0 , 'This post-coming-out performance fully acknowledges Ellen DeGeneres\'s\r\n                      status as America\'s most famous lesbian, but it is nevertheless imbued with\r\n                      a sense of fun. For instance, rather than describe the experience of\r\n                      closet-exiting on her self-titled situation comedy in the late 1990s, she\r\n                      performs an amusing "interpretive dance." She uses her trademark\r\n                      goofiness to ruminate on the necessity of directions on shampoo bottles,\r\n                      ant road rage, and the possible nightmarish consequences of buying cheese.\r\n                      While the performance is not orientation-specific, the comedienne spends a\r\n                      fair amount of time on sex-related issues, including jokes about blow-up\r\n                      dolls and people who videotape their relations. She does venture into the\r\n                      political with an appeal for same-sex marriage and a monologue on meeting\r\n                      God, who turns out to be a middle-aged black woman. None of this fazes\r\n                      her clearly supportive audience at New York\'s Beacon Theatre who get to ask\r\n                      her questions at the end ? la Carol Burnett. The best moment of the\r\n                      65-minute performance for HBO comes at the end, when DeGeneres\r\n                      accidentally exhibits some gender confusion with a young audience member,\r\n                      who then pays her moving tribute as a role model. --Kimberly Heinrichs\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000053VAP.01.13TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B000053VAP.01.MZZZZZZZ.jpg' , NULL , NULL , 14.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 12.99 , 13 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (21 , 'But I\'m A Cheerleader (1999)' , 1 , 1 , 2 , 'B00004X13Q' , NULL , NULL , 0 , 'A promising comedy that goes awry all too early, But I\'m a Cheerleader\r\n                  concerns a misunderstood high school kid (Natasha Lyonne) whose parents\r\n                  send her to a harsh, homosexual-rehabilitation camp despite a lack of evidence\r\n                  that she\'s gay. Ruled with an iron fist by a fascist counselor (Cathy Moriarty), the\r\n                  clinic only drives Lyonne\'s character toward an attraction to a rebellious tomboy\r\n                  (Clea DuVall), though screenwriter Brian Wayne Peterson and director Jamie\r\n                  Babbit are curiously intent on keeping the two apart and depriving the audience\r\n                  of other comic possibilities. Meanwhile, hoary clich?s abound: prancing boys,\r\n                  butch gays, lipstick lesbians. Despite a fine cast full of young talent, and cameo\r\n                  appearances by Julie Delpy and RuPaul Charles, this attempt to skewer a\r\n                  present-day trend in "curing" homosexuals of their sexual preferences is\r\n                  flattened by stereotypes and unimaginative thinking. --Tom Keogh' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004X13Q.01.14TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00004X13Q.01.MZZZZZZZ.jpg' , NULL , NULL , 24.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 21.49 , 14 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (22 , 'Under Cover The Key To Living In God\'s Provision And Protection' , 1 , 1 , 2 , '0785269916' , NULL , NULL , 0 , 'This well loved writer effectively uses his personal mistakes to illustrate riveting truths about repentance and forgiveness. As he focuses on the true authority of God, he is careful to explain by example the important difference between submission and obedience. \r\nThe same struggle with divine authority is also represented through the lives of John the Baptist, the Apostle Paul, and other biblical figures. An especially helpful book for Christians who want to develop a serious pursuit of God. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0785269916.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0785269916.01.MZZZZZZZ.jpg' , NULL , NULL , 14.99 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.99 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (23 , 'Chuck & Buck (2000)' , 1 , 1 , 2 , 'B000051S5M' , NULL , NULL , 0 , 'Despite all Sundance and critical fanfare to the contrary, this intriguing indie hit is\r\n                  hardly an easily digested little winner. Miguel Arteta\'s film is more than a bit\r\n                  unsettling, and scene after scene plays with intense discomfort. After the death of\r\n                  his mother, strangely juvenile 27-year-old Buck (Mike White) heads off to L.A. with\r\n                  the oblivious, obsessive intent of working his way back into the life of childhood pal\r\n                  Chuck (Chris Weitz), with whom he\'d sexually experimented as a boy. Chuck\'s\r\n                  engaged now, which only serves to increase Buck\'s determination ("When it\'s just\r\n                  you and me here, it\'s like I\'m OK," he says. "And all this other stuff makes me feel\r\n                  dead."). Arteta and screenwriter White (who\'s quite good as Buck) stretch\r\n                  credibility more than once--Buck\'s troubling emotional state is sketchy, to say the\r\n                  least--and some of their humor is too smirkingly ironic for its own good, but the\r\n                  film\'s edgy sadness keeps poking at you. Whatever its flaws, there\'s something\r\n                  compelling here about the fear of growing up and the more unnerving dread of\r\n                  being found out. --Steve Wiecking' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000051S5M.01.10TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B000051S5M.01.MZZZZZZZ.jpg' , NULL , NULL , 14.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.48 , 10 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (24 , 'The Church of Irresistible Influence' , 1 , 1 , 2 , '0310239567' , NULL , NULL , 0 , 'An inspiring description and story showing how a church can become an irresistible influence on its neighborhood, community, and world by building bridges over troubled waters to a dying culture through showing the love of God in action. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0310239567.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0310239567.01.MZZZZZZZ.jpg' , NULL , NULL , 19.99 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 13.99 , 30 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (25 , 'God : A Biography' , 1 , 1 , 2 , '0679743685' , NULL , NULL , 0 , 'Is it possible to approach God not as an object of religious reverence, but as the protagonist of the world\'s greatest book -- as a character who possesses all the depths, contradictions, and ambiguities of a Hamlet? How does he depend on the other characters, and how does his relationship with them show his development? Miles provides a learned, original exegesis that will send readers back to the Bible in curious amazement. Winner of the 1996 Pulitzer Prize for biography. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0679743685.01.TZZZZZZZ.gif' , 'http://images.amazon.com/images/P/0679743685.01.MZZZZZZZ.gif' , NULL , NULL , 15 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (26 , 'Beefcake (1999)' , 1 , 1 , 2 , 'B0000541AD' , NULL , NULL , 0 , 'Canadian filmmaker Thom Fitzgerald made his name on the gay film scene with his\r\n                  dramatic fantasia The Hanging Garden, but with Beefcake he captures a more\r\n                  lightheartedly dreamy tone: The film takes its lead from Valentine Hooven\'s\r\n                  lip-smackingly compulsive coffee table tome of the same name. We\'re offered a\r\n                  teasing, pseudo-history of mid-century pop male photography, featuring quaint\r\n                  muscle-mag shots and nude "studies" of, among others, a hungrily seductive\r\n                  young Joe Dallesandro (before he made his name in underground Andy Warhol\r\n                  flicks like Flesh). Dallesandro\'s here to talk, along with other "models" who mostly\r\n                  supply commentary on Bob Mizer, the enterprising founder of the Athletic Model\r\n                  Guild. Fitzgerald blends the real-life documentary material into his fictional\r\n                  confection concerning a sexy bumpkin who falls into Mizer\'s AMG set-up (it\r\n                  produced America\'s first closeted gay erotica publication, passing itself off as an\r\n                  innocently obsessive guide to health and fitness). The campy original story--the\r\n                  hero\'s Valley of the Dolls-inspired name is Neil O\'Hara--is a bit dumb, actually,\r\n                  mostly because it\'s not even half as interesting as the real deal. Lots of innocently\r\n                  nude frolicking doesn\'t hurt, though, and the film engages when it manages to be\r\n                  as naively sweet and erotic as Mizer\'s bygone magazines. --Steve Wiecking ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B0000541AD.01.14TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B0000541AD.01.MZZZZZZZ.jpg' , NULL , NULL , 34.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 29.99 , 14 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (27 , 'The Pleasures of God : Meditations on God\'s Delight in Being God' , 1 , 1 , 2 , '1576736652' , NULL , NULL , 0 , 'Beginning where the foundational truth of Desiring God left off, that "God is most glorified in us when we are most satisfied in Him," this expanded rerelease of another classic by John Piper will further explore a life-changing essential "We will be most satisfied in God when we know why God himself is most satisfied in God." Fully understanding the joy of God will draw the reader into an encounter with His overflowing, self-replenishing, all-encompassing grace(the source of living water that all Christians desire to drink.) The Pleasures of God will again put God at the center of Creation and leave the reader very satisfied in Him. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1576736652.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/1576736652.01.MZZZZZZZ.jpg' , NULL , NULL , 14.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.99 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (28 , 'The Lord of the Rings (Collector\'s Edition)' , 1 , 1 , 2 , '0395193958' , NULL , NULL , 0 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , 1 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , NULL , 'http://images.amazon.com/images/P/0395193958.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0395193958.01.MZZZZZZZ.jpg' , NULL , NULL , 75 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 52.5 , 30 , 0 , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (29 , 'The Lord of the Rings (Boxed Set)' , 4 , 1 , 2 , '0395489326' , NULL , NULL , 0 , 'The three volumes that make up Tolkien\'s epic classic The Lord of the Rings are here presented in their standard cloth editions including large format fold-out maps and an extensive appendices. Set contains The Fellowship of the Ring, The Two Towers, and The Return of the King, with jackets and a box designed by celebrated illustrator Alan Lee. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0395489326.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0395489326.01.MZZZZZZZ.jpg' , NULL , NULL , 65 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 45.5 , 30 , NULL , NULL , NULL , 0 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (30 , 'The Silmarillion' , 3 , 1 , 2 , '0345325818' , NULL , NULL , 0 , 'The Silmarillion is J.R.R. Tolkien\'s tragic, operatic history of the First Age of Middle-Earth, essential background material for serious readers of the classic Lord of the Rings saga. Tolkien\'s work sets the standard for fantasy, and this audio version of the "Bible of Middle-Earth" does The Silmarillion justice. Martin Shaw\'s reading is grave and resonant, conveying all the powerful events and emotions that shaped elven and human history long before Bilbo, Frodo, Gandalf and all the rest embarked on their quests. Beginning with the Music of the Ainur, The Silmarillion tells a tale of the Elder Days, when Elves and Men became estranged by the Dark Lord Morgoth\'s lust for the Silmarils, pure and powerful magic jewels. Even the love between a human warrior and the daughter of the Elven king cannot defeat Morgoth, but the War of Wrath finally brings down the Dark Lord. Peace reigns until the evil Sauron recovers the Rings of Power and sets the stage for the events told in the Lord of the Rings. This is epic fantasy at its finest, thrillingly read and gloriously unabridged. (Running time: 14 hours, 6 CDs) --This text refers to the Audio CD edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345325818.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0345325818.01.MZZZZZZZ.jpg' , NULL , NULL , 6.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 6.99 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (31 , 'Osmosis Jones (2001)' , 1 , 1 , 2 , 'B00005QAQH' , NULL , NULL , 0 , 'After the stiff attempts at realism in many recent features, it\'s a treat to see broad\r\n                  cartoon-style animation on the big screen in Osmosis Jones, a spoof of cop movies\r\n                  set inside the human body. The title character (voice by Chris Rock) is a\r\n                  street-smart white blood cell, working for Frank\'s immune system. He and Drix\r\n                  (David Hyde Pierce), an over-the-counter cold capsule, are reluctant partners\r\n                  fighting what appears to be a minor infection. Osmosis discovers Frank has really\r\n                  contracted a fatal virus, Thrax (Laurence Fishburne): he battles a corrupt body\r\n                  politic led by a venal mayor (William Shatner) to save Frank\'s life and win the\r\n                  affection of the mayor\'s aide, Leah (Brandy Norwood). Rock\'s motor-mouth\r\n                  delivery can get annoying, but it contrasts nicely with straight arrow Drix (imagine\r\n                  a fussy Buzz Lightyear). Excellent drawing and a powerful vocal performance make\r\n                  Thrax a genuinely frightening villain.\r\n\r\n                  Osmosis Jones is about two-thirds animation and one-third live action, which is\r\n                  why two-thirds of the film is entertaining and funny, and one-third is not. The life\r\n                  Osmosis and Drix save belongs to Frank, a slob played in live-action sequences by\r\n                  Bill Murray, who\'s undercut rather than supported by Chris Elliott and Molly\r\n                  Shannon. Shamelessly over-the-top performances make the human characters\r\n                  seem flatter than the two-dimensional cartoons. The live action was shot by the\r\n                  Farrelly brothers and features lots of gross-out gags about zits, flatulence, vomit,\r\n                  snot, etc. The audience endures these leaden segments, waiting to get back to the\r\n                  animation--and the real comedy. Suitable for ages 9 and up: profanity, violence,\r\n                  bodily function jokes. --Charles Solomon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QAQH.01.14TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005QAQH.01.MZZZZZZZ.jpg' , NULL , NULL , 24.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 21.49 , 14 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (32 , 'Dark Journey (Star Wars: The New Jedi Order, Book 10)' , 2 , 1 , 2 , '0345428692' , NULL , NULL , 0 , 'About the Author \r\nA former music and history teacher, Elaine Cunningham has written more than a dozen fantasy novels and many short stories. She is best known for the Songs & Swords books, particularly Elfshadow, a mystery in a fantasy setting. She lives with her family in a coastal New England town.\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345428692.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0345428692.01.MZZZZZZZ.jpg' , NULL , NULL , 6.99 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 6.99 , NULL , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (33 , 'The John Singleton Collection (Boyz N the Hood, Poetic Justice, Higher Learning)' , 1 , 1 , 2 , 'B00005JD5K' , NULL , NULL , 0 , 'Poetic Justice: BOYZ N THE HOOD writer-director Singleton suffers the\r\n                  sophomore jinx in this ambitious but fatally pretentious saga of a melancholy\r\n                  South Central L. A. beautician (Jackson), who has retreated from the world after\r\n                  her boyfriend\'s murder; mailman Shakur attempts to break through to her, with\r\n                  predictable results. Implausibly, the poetry this otherwise ordinary woman\r\n                  composes actually is the work of Maya Angelou (who appears onscreen as Aunt\r\n                  June). Jackson is OK in her screen debut.\r\n                  Higher Learning: Provocative drama of life at a big university where problems\r\n                  tend to break down along racial and sexual lines. Epps plays a young black\r\n                  athlete searching for direction and, sometimes blindly, raging at injustice.\r\n                  Fishburne is a political science professor who tries to help him see the world as\r\n                  it is. Credible, well-acted film goes awry when writer-director Singleton steers it\r\n                  toward melodrama, and foregoes student relations to focus on a group of\r\n                  extremist skinheads.\r\n                  Boyz N the Hood: Sober, thoughtful look at life in the black section of South\r\n                  Central L. A. A divorced father strives to raise his son with values--and steer him\r\n                  away from the ignorance and aimlessness that has led to an epidemic of\r\n                  senseless violence in the neighborhood. Impressive debut for 23-year-old\r\n                  writer-director Singleton; longish, and not always on-the-money, but overall quite\r\n                  potent and effective. Singleton has a bit part as a mailman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005JD5K.01.25TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005JD5K.01.MZZZZZZZ.jpg' , NULL , NULL , 44.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 33.71 , 25 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (34 , 'Amazing Grace (1974)' , 1 , 1 , 2 , 'B00005R5W2' , NULL , NULL , 0 , 'A few laughs in Philadelphia-made comedy about an elderly busybody who disrupts\r\n                  corrupt Baltimore politics. Mabley\'s only starring film; cameos by Butterfly\r\n                  McQueen, unrecognizable Stepin Fetchit.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W2.01.10TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R5W2.01.MZZZZZZZ.jpg' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (35 , 'HomeSite 5.0' , 1 , 1 , 2 , 'B00005U2FY' , NULL , 'Ever popular with professional Web developers, HomeSite 5.0 offers advanced hand-coding features, productivity enhancing wizards, and a customizable user interface to efficiently build, deploy, and manage your entire Web site. HomeSite 5.0 also includes XHTML support and new Folder Deployment settings. Check out the full or upgrade version today.\r\n' , 0 , 'Developers can create professional Web sites fast with the code editing features of Macromedia HomeSite 5. The software delivers advanced hand coding features, productivity-enhancing wizards, and a customizable user interface to efficiently build, deploy, and manage your entire Web site. Effortlessly validate, reuse, navigate, and format your code with integrated coding tools. The wizards quickly create pages, tables, frames, and JavaScript elements for you.\r\nWith XHTML support, based on the W3C specifications for XHTML 1.0, developers can build pages with the latest Web technologies. The extensibility of XHTML provides the flexibility to incorporate new Web communication and presentation ideas as they emerge. Developers can use the new Secondary Files tab to browse local and remote files simultaneously and to drag and drop files between the two Files tabs, efficiently incorporating documents and images. \r\n\r\nThe new Folder Deployment settings enable developers to determine the deployment method for individual folders and files within a project. These new settings make deployment much more accessible to the novice user while maintaining the sophistication of the feature for the high-end user. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U2FY.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005U2FY.01.MZZZZZZZ.jpg' , NULL , NULL , 99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (36 , 'J.D.\'s Revenge (1976)' , 1 , 1 , 2 , 'B00005R5W1' , NULL , NULL , 0 , 'It\'s been branded with the "blaxploitation" label, but there is little that\'s exploitive in\r\n                  J.D.\'s Revenge, a film of well-drawn, articulate characters dragged into a\r\n                  supernatural showdown. Glynn Turman (Cooley High) is especially fine as the\r\n                  sensitive and quiet Ike, a determined student moonlighting as a cab driver, so\r\n                  wound up he\'s on the verge of cracking. Enter (literally) the ghost of J.D., a\r\n                  violent, vengeful gangster murdered in the opening moments. He could be Ike\'s\r\n                  own Mr. Hyde, a dapper, flamboyant ladykiller with a fiery temper and a straight\r\n                  razor who slowly smothers Ike\'s easygoing personality. Driven by flashes of\r\n                  memory, he sets his vengeful sights on fire-and-brimstone preacher Reverend\r\n                  Bliss (Louis Gossett Jr.), whose dark past is intricately tied up with J.D.\'s\r\n                  murder. Director Arthur Marks (Detroit 9000) sidesteps the usual spooky clich?s\r\n                  to stir up a modern New Orleans gumbo of ghost story, gangster tale, and\r\n                  character drama. J.D. is both devilish sadist and avenging angel, while the\r\n                  tortured Ike awakens from J.D.\'s violent rampages with a hole in his memory but\r\n                  a sick feeling from his imagined complicity in the crimes. The story gets wrapped\r\n                  up a little too neatly in the end, but the dark character shadings and the evocative\r\n                  mystery at the center of Ike\'s possession makes J.D.\'s Revenge an\r\n                  unexpectedly compelling supernatural thriller. --Sean Axmaker' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W1.01.10TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R5W1.01.MZZZZZZZ.jpg' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (37 , 'Homestead Professional - 3 Month Subscription' , 1 , 1 , 2 , 'B00005U1US' , NULL , 'Product Description\r\nHomestead Professional\'s three-month subscription includes everything you need to build, host, and maintain a professional Web site. This drag-and-drop Web site software makes it easy to create a professional online presence. The Homestead... ' , 0 , 'Homestead Professional\'s three-month subscription includes everything you need to build, host, and maintain a professional Web site. This drag-and-drop Web site software makes it easy to create a professional online presence. The Homestead Professional package offers a three-month subscription to site hosting, 75 MB of storage space, unlimited pages, and 15 GB of traffic per month. It also sets you up with your own domain name along with two matching e-mail accounts.\r\nComprehensive e-commerce tools, interactive elements, site design wizards, and a gallery loaded with more than a million images makes designing your Web site fun and professionally rewarding. The easy-to-use e-commerce tools help you set up and market your products and services online. Interactive hit counters, guestbooks, Web polls, chat rooms, and forms let you monitor traffic, while statistics and reporting tools aid in building customer profiles and tracking marketing efforts. Throughout, Homestead\'s extensive online help is there to guide you through the design process. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U1US.01.33TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005U1US.01.MZZZZZZZ.jpg' , NULL , NULL , 89.97 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 59.97 , 33 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (38 , 'Adobe After Effects 5.5 Standard Upgrade from 5.0 ST-ST' , 1 , 1 , 2 , 'B00005UMC8' , NULL , 'Adobe After Effects 5.5 delivers a comprehensive set of tools to efficiently produce motion graphics and visual effects for film, video, multimedia, and the Web. The Standard version provides core compositing, animation, and effects tools. After... ' , 0 , 'Adobe After Effects 5.5 delivers a comprehensive set of tools to efficiently produce motion graphics and visual effects for film, video, multimedia, and the Web. The Standard version provides core compositing, animation, and effects tools. After Effects offers a high level of integration with Adobe Premiere, Adobe Photoshop, and Adobe Illustrator to produce professional results. New features include controls to manipulate lighting in 3-D compositions, easier application of effects, and versatile import and output options. And now get native support for Mac OS X. \r\nAfter Effects 5.5 features increased control over lighting properties, allowing users to cast colored shadows or simulate the effects of stained glass. Create spotlights that cast light in the shape of stars or logos. After Effects 5.5 also includes eight new effects, giving you more than 90 effects to use alone or in combination to produce looks that are tailored for any project. And now you can apply effects more efficiently and organize them however you like with the new effects palette. Just drag and drop effects from the palette and arrange them using customized folders or list them alphabetically.\r\n\r\nAfter Effects 5.5 offers more import and output options. Create RealMedia streaming or Web download files that support RealVideo, RealAudio, and RealVideo with audio. Get support for work in 16-bit-per-channel formats such as Maya IFF, QuickTime, RPF, and SGI files. Import Macromedia Flash files and MPEG-1 files to use in your compositions. Cross-media delivery of high-quality digital content with After Effects has never been easier or more flexible.\r\n' , 0 , NULL , 'This is an upgrade version for owners of After Effects 5.0 Standard. \r\n' , 'http://images.amazon.com/images/P/B00005UMC8.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UMC8.01.MZZZZZZZ.jpg' , NULL , NULL , 99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (39 , 'The Curse of the Jade Scorpion (2001)' , 1 , 1 , 2 , 'B00003CY6A' , NULL , NULL , 0 , 'With The Curse of the Jade Scorpion, Woody Allen pays another visit to his\r\n                  idealized past, and his retro blend of humor and nostalgia will surely satisfy the\r\n                  filmmaker\'s most loyal fans. Like The Purple Rose of Cairo, Radio Days, and\r\n                  Sweet and Lowdown, The Curse of the Jade Scorpion is physically impeccable:\r\n                  its period-perfect costumes and sets capture 1940 New York with splendid\r\n                  authenticity and are further enhanced by the burnished glow of Zhao Fei\'s\r\n                  cinematography. And like those earlier films, Jade Scorpion mines comedic gold\r\n                  from its timeframe, molding it into a plot laced with expert zingers that could only\r\n                  spring from a rich awareness of comedic tradition. Add an appealing roster of\r\n                  costars (including Elizabeth Berkley and Charlize Theron) and you\'ve got vintage\r\n                  Woody that perks right along.\r\n\r\n                  The movie\'s also as trivial as it is engaging; hack off 30 minutes and it might have\r\n                  had the delirious precision of early Marx Brothers classics. Instead, Allen\'s goofy\r\n                  conceit--enemies falling in love by hypnotic suggestion--is stretched to absurdity\r\n                  when efficiency expert Betty Ann "Fitz" Fitzgerald (Helen Hunt) is hypnotically\r\n                  attracted to seasoned insurance investigator C.W. Briggs (Allen), despite their\r\n                  office enmity. Plus, a jewel-heist caper masterminded by the nightclub hypnotist\r\n                  (David Ogden Stiers) casts them both as suspects! Woody harvests a bumper\r\n                  crop of old-fashioned laughs from this predicament, and despite their\r\n                  conspicuous age difference and occasional awkward delivery, Hunt and Allen\r\n                  exchange volleys of dialogue like a seasoned comedy team. Dan Aykroyd is also\r\n                  good in a stodgy supporting role, but Jade Scorpion remains a mixed blessing--a\r\n                  welcomed throwback to comedy\'s yesteryear, from a master funnyman who\'s\r\n                  struggling to maintain relevance in the present. --Jeff Shannon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00003CY6A.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00003CY6A.01.MZZZZZZZ.jpg' , NULL , NULL , 32.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 26.49 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (40 , 'Microsoft Visual Studio .NET Professional Upgrade' , 1 , 1 , 2 , 'B00005RV50' , NULL , 'Visual Studio .NET Professional enables developers to build the next generation of Internet applications with XML Web services, database applications with XML, and RAD for the .NET Server. \r\nIt enables developers to build solutions for the broadest... ' , 0 , 'Visual Studio .NET Professional enables developers to build the next generation of Internet applications with XML Web services, database applications with XML, and RAD for the .NET Server. It enables developers to build solutions for the broadest range of clients--from Web applications to Windows to thin-client devices to smart devices. The RAD capabilities provide a shared IDE and a choice of programming languages, including Visual Basic, C++, C#, and Java. Visual Studio .NET Professional is RAD for the programmable Web.\r\nIn XML, Visual Studio .NET developers can build data-driven applications using built-in ADO.NET tools that target a variety of databases, including SQL Server, Oracle, or any other XML source. With support for XML, ADO.NET enables developers to share data across computing platforms. Additionally, Visual Studio .NET includes the Microsoft Data Engine (MSDE), a SQL Server-compatible database that provides programmers with a viable development database and natively supports XML.\r\n\r\nVisual Studio .NET allows programmers to create and deploy critical server-based programming. With Visual Studio .NET, developers can visually compose middle-tier components using the Visual Component Designer (VCD). The VCD enables developers to drag and drop nonvisual objects such as message queues, timers, and event logs to a design surface, automatically discovering all necessary server-based resources and configuring required components. \r\n\r\n' , 0 , NULL , 'This is an upgrade version. Any owner of Visual Studio 97 or Visual Studio 6.0 and later--except for standard versions--is eligible for the upgrade. ' , 'http://images.amazon.com/images/P/B00005RV50.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005RV50.01.MZZZZZZZ.jpg' , NULL , NULL , 549 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 544.99 , 1 , NULL , NULL , NULL , 1 , '' , 0 , 0 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (41 , 'Groundhog Day (Special Edition) (1993)' , 1 , 1 , 2 , 'B00005U8EM' , NULL , NULL , 0 , 'Bill Murray does warmth in his most consistently effective post-Stripes comedy,\r\n                  a romantic fantasy about a wacky weatherman forced to relive one strange day\r\n                  over and over again, until he gets it right. Snowed in during a road-trip expedition\r\n                  to watch the famous groundhog encounter his shadow, Murray falls into a time\r\n                  warp that is never explained but pays off so richly that it doesn\'t need to be. The\r\n                  elaborate loop-the-loop plot structure cooked up by screenwriter Danny Rubin is\r\n                  crystal-clear every step of the way, but it\'s Murray\'s world-class reactive timing\r\n                  that makes the jokes explode, and we end up looking forward to each new\r\n                  variation. He squeezes all the available juice out of every scene. Without forcing\r\n                  the issue, he makes us understand why this fly-away personality responds so\r\n                  intensely to the radiant sanity of the TV producer played by Andie MacDowell.\r\n                  The blissfully clueless Chris Elliott (Cabin Boy) is Murray\'s nudnik cameraman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005U8EM.01.MZZZZZZZ.jpg' , NULL , NULL , 24.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.71 , 25 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (42 , 'Nothing in Common(1986)' , 1 , 1 , 2 , 'B00005UQ6M' , NULL , NULL , 0 , 'Interminably long, highly uneven comedy-drama about a perpetual adolescent\r\n                  who\'s forced to deal with his aging, unloving father when his mom leaves him flat.\r\n                  Some poignant, relevant conclusions about love and responsibility (and some\r\n                  funny shots at the advertising business) are undermined by overlength and\r\n                  meandering nature of film. Hanks is excellent; Gleason is abrasive (in his last film\r\n                  appearance). Later a TV series. Super 35.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UQ6M.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UQ6M.01.MZZZZZZZ.jpg' , NULL , NULL , 19.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.96 , 25 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (43 , 'Adobe Indesign 2.0 Promo Upgrade' , 1 , 1 , 2 , 'B00005T7C7' , NULL , 'Inspire your creativity and simplify elaborate design tasks with the latest version of Adobe\'s popular page-layout software. InDesign 2.0 offers object transparency, long-document management options, one-step table creation, XML import and export, and improved performance' , 0 , 'Adobe InDesign 2.0 page-layout software has the tools to inspire your creativity and simplify elaborate design tasks. Version 2.0 offers object transparency, long-document management options, one-step table creation, XML import and export, improved performance, and more. InDesign 2.0 delivers tight integration with other Adobe graphics applications, easy-to-use tools that reduce elaborate design tasks to a few steps, and built-in support for publishing pages anywhere--in print, on the Web, to Adobe PDF, as e-books, and more. \r\nCapture inspiration with the ability to apply drop shadows, feathering, and other editable transparency settings to any object. Use Overprint Preview for proofing spot-color effects and overprint settings. Flexible table creation tools let you turn tab-delimited text into tables in one step. Plus, get faster performance when opening, saving, and closing documents and placing high-resolution images. \r\n\r\nInDesign\'s integration with other Adobe products allows you to work more efficiently. You can directly export Adobe PDF files in Acrobat 4.0 or Acrobat 5.0 format. You\'ll have the ability to place native Photoshop and Illustrator files with the transparency preserved. InDesign 2.0 also features support for importing and exporting well-formed XML and easier tracking, management, and retrieval of InDesign documents through Adobe\'s new XML-based metadata framework. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005T7C7.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005T7C7.01.MZZZZZZZ.jpg' , NULL , NULL , 99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99 , NULL , 0 , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (44 , 'AutoCAD LT 2002' , 1 , 1 , 1 , 'B00005M0UB' , NULL , 'Product Description\r\nAutoCAD LT 2002 is design and drawing software featuring new timesaving drawing tools. Minimize the number of steps you need to take, freeing you and your team to explore more design options. Save time with true associative dimensioning. When you... ' , 0 , 'AutoCAD LT 2002 is design and drawing software featuring new timesaving drawing tools. Minimize the number of steps you need to take, freeing you and your team to explore more design options. Save time with true associative dimensioning. When you change the geometry of any drawing, the dimensions immediately change. Work smarter and faster with new layer, text, and attribute tools, such as text scaling, the enhanced attribute editor, block attribute manager, layer translator, and an extended spell checker. Robust standards-management tools make checking and adhering to drafting standards easy, whether you work from corporate or ANSI, ISO, DIN, or JIS standards. \r\nTake your designs further by sharing and accessing design data for a more productive team. Get your design information where it\'s needed--quickly, easily, and accurately. With AutoCAD LT 2002, you\'ll enjoy 100 percent drawing file compatibility. The AutoCAD DWG format remains unchanged from AutoCAD 2000 and AutoCAD 2000i, protecting your investment in AutoCAD 2000/2000i files already in production. You can even translate your DWG files into lightweight, read-only DWF files for maximum intranet or Internet viewing and newly updated high-fidelity plotting. \r\n\r\nSave time and money with eTransmit, which bundles all your drawing files and delivers them at Net speed. Now eTransmit even builds the appropriate design standards right in. You don\'t need to be a Web expert to post your content on an intranet or any dedicated central location. Advanced Publish to Web makes it even easier to build pages and follow your corporate look and feel. Store your files online with My Files at Autodesk Point A--Autodesk\'s portal for design professionals--or on any FTP or HTTP server. Plus, with simple i-drop publishing, it\'s easy to use and reuse design content--from archived libraries to specs from a manufacturer\'s site, and more. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005M0UB.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005M0UB.01.MZZZZZZZ.jpg' , NULL , NULL , 659 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 659 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (45 , 'Corel Graphics Suite 10 Upgrade' , 1 , 1 , 2 , 'B00005OLZP' , NULL , 'Specifically designed for professional Mac users, this sophisticated graphics suite includes drawing tools, image editing features, and vector animation software. Containing CorelDRAW 10, Corel Photo-Paint 10, Corel R.A.V.E., and Canto Cumulus 5.0, Corel Graphics Suite 10 also includes built-in PDF output, professional color management, and industry-standard import and export filters. Check out the full or upgrade version today.\r\n\r\n' , 0 , 'Corel Graphics Suite 10 Upgrade works with all previous versions of CorelDRAW and Corel Photo-Paint to bring sophisticated graphics applications, including drawing tools, image editing features, and vector animation software, to your desktop. \r\nDesigned for professional Mac users in the graphic design, business, and educational communities, Corel Graphics Suite 10 features CorelDRAW 10, Corel Photo-Paint 10, Corel R.A.V.E., and Canto Cumulus 5.0. Interactive tools, context-sensitive toolbars, and Live Effects software put you in control of the design process. Advanced features, such as Web Image Optimizer and Web publishing, add flair to your sites. Built-in PDF output, professional color management, and industry-standard import and export filters ensure desired results. \r\n\r\nCorel Graphics Suite 10 Upgrade runs natively under Mac OS X and Mac OS 8.6 to 9.2. User manuals are included. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005OLZP.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005OLZP.01.MZZZZZZZ.jpg' , NULL , NULL , 249.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 234.99 , 6 , 0 , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (46 , 'Picture Publisher 10 Digital Camera' , 1 , 1 , 2 , 'B00005Q5IN' , NULL , 'Picture Publisher, Digital Camera Edition was created specifically for small businesses and individuals that have made digital cameras an integral part of their business. It is flexible and powerful, yet does not require the user to spend hours... ' , 0 , 'Picture Publisher, Digital Camera Edition was created specifically for small businesses and individuals that have made digital cameras an integral part of their business. It is flexible and powerful, yet does not require the user to spend hours learning complicated software. Create high-impact graphics for print, presentations, and the Web using intuitive one-click macros and a task-oriented visual toolbar to make common tasks easy to accomplish. \r\nPicture Publisher, Digital Camera Edition provides a wide array of features that allow users to manage, correct, enhance, create, and publish digital photos. Easily input photos directly from a digital camera; effectively correct and enhance photos through a batch process; use drawing, painting, and text tools to create new images or enhance existing photos; and choose from multiple publish options including printing and HTML slide shows. \r\n\r\nThe task-oriented visual toolbar steps users through common tasks to make them easy to accomplish. One-click macros make common tasks like white balancing and color correction quick and easy. Full-screen previews make it easy to see the effects to images before making the actual change. Unlimited undos make it easy to take back that last change that wasn\'t quite right. You can then organize photos in albums that make sense, and even include the same picture in multiple albums. Manage them with ease by adding keywords for easy lookup later. Save time by working with a number of photos at once. Select the group to be worked with, then add common descriptions, keyword, names, or colors and correct them all at once. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005Q5IN.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005Q5IN.01.MZZZZZZZ.jpg' , NULL , NULL , 49 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 44.99 , 8 , 0 , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (47 , 'The Typing of the Dead' , 1 , 1 , 2 , 'B00005RV5M' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005RV5M.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005RV5M.01.MZZZZZZZ.jpg' , NULL , NULL , 19.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (48 , 'SONICBlue Rio 600 32MB Digital Audio Player' , 1 , 1 , 2 , 'B00004SPUN' , NULL , 'Get into the swing of digital audio with the Rio\r\n                                         600--now for only $49.99 after a $50 mail-in\r\n                                         rebate. This compact and lightweight portable\r\n                                         player features 32 MB of RAM and is PC and\r\n                                         Mac compatible. We have limited quantities, so\r\n                                         act fast.' , 0 , 'Diamond Multimedia\'s Rio line of MP3 players has always been\r\n                        topnotch--and the latest iteration, the Rio 600, proves no exception. The\r\n                        nifty-looking Rio 600 also offers detachable faceplates, allowing users to\r\n                        customize its appearance (although they are a bit pricey). \r\n\r\n                        But it\'s not the aesthetics of the Rio that we liked so much (although the\r\n                        ?ber-trendy, over-the-ear headphones make another nice touch). What\r\n                        really makes the Rio unique is just how simple it is to use. From\r\n                        installation to manipulation of the player interface or the Rio Audio\r\n                        Manager software, it\'s as easy as MP1-2-3. Intuitive on all counts, the\r\n                        Rio rarely forced us to consult the manual--whether we were in the\r\n                        middle of setup, switching songs on the road, or transferring MP3s. \r\n\r\n                        In addition to the nearly ubiquitous MP3 format, the Rio 600 also handles\r\n                        the new Windows Media Audio (WMA) format, and Diamond says it will\r\n                        be software upgradable to upcoming formats. One knock on the 600 is\r\n                        the fact that it ships with only 32 MB of flash memory. While this can\r\n                        handle over an hour of WMA-formatted material, it holds only around 30\r\n                        minutes of MP3 playback. To compensate, the Rio 600 will be\r\n                        upgradable to 372 MB of total memory, and Diamond offers a unique\r\n                        upgrade approach. They\'ll sell the memory enhancements as new backs\r\n                        to the player, providing different types of memory that users can choose\r\n                        from and, as Diamond puts it, "future-proofing" the player against\r\n                        diverse upcoming memory types. \r\n\r\n                        The USB-only interface proves to be another double-edged sword. On\r\n                        the one side, you need to be running Windows 98 or later to hook up the\r\n                        Rio to your PC. (For the Mac, you\'ll need a USB port and Mac OS 8.51\r\n                        or higher.) On the other, the transfer rate is like a hare compared to\r\n                        older tortoise players using parallel ports. It took only around 10 seconds\r\n                        to move a 4-minute MP3 song from our PC to the Rio. \r\n\r\n                        The Rio 600 is not a perfect player--32 MB just isn\'t enough for taking\r\n                        songs on the road and it lacks a belt clip--but the other players on the\r\n                        market aren\'t earning perfect marks either (yet). And with its unique\r\n                        format and memory upgrades, the Rio 600 is built to last.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004SPUN.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00004SPUN.01.MZZZZZZZ.jpg' , NULL , NULL , 99.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (49 , 'Survivor: The Interactive Game' , 2 , 1 , 2 , 'B00005ME4Z' , NULL , NULL , 0 , 'For the first time ever, the hit TV series Survivor has come to your PC. Play as any of the actual 32 Pulau Tiga and Australian Outback cast members or create your own character. Now you can put your skills to the test and see if you have what it takes to become the ultimate survivor.\r\nDetermine your role in the tribe by choosing from 10 essential survivor skills, such as field craft, fishing, and cooking. Form alliances and develop relationships with fellow tribe members, or choose to vote off competitors at the tribal council.\r\n\r\nLearn the ins and outs of self-preservation from the interactive Survivor bush guide while you compete in 24 reward and immunity challenges. Play through a full-, half-, or short-season game. And once you\'re up to the challenge, compete against friends via LAN or the Internet. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005ME4Z.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005ME4Z.01.MZZZZZZZ.jpg' , NULL , NULL , 14.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.99 , NULL , 0 , NULL , NULL , 1 , '' , 1 , 2 , 2 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (50 , 'Meade Travel View 10X50 Porro Prism Binocular (B120020B)' , 1 , 1 , 2 , 'B00005M2BT' , NULL , 'These full-sized binoculars feature fully-coated\r\n                                        lenses for razor sharp images. The 10x\r\n                                        magnification really brings your targets into\r\n                                        view, and the firm rubberized body provides\r\n                                        protection from bumps and drops.' , 0 , 'This Meade Travel View binocular sports a powerful 10x magnification,\r\n                         making it practical for almost any observational purpose. With a 50mm\r\n                         objective lens diameter you will be sure to get a clear and bright\r\n                         picture. It has a soft, rubberized cover for a firm grip and a central\r\n                         focusing system. Also included is a soft nylon carrying case and neck\r\n                         strap.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005M2BT.01.49TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005M2BT.01.MZZZZZZZ.jpg' , NULL , NULL , 79 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 39.99 , 49 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (51 , 'Animosity [EXPLICIT LYRICS]' , 1 , 1 , 2 , 'B00005R5ZG' , NULL , NULL , 0 , 'For the first time in the life of the band, Sevendust (TVT Records) have had time to write and create their songs at home, not in between tour dates as they have in the past. With this new, found freedom, the band wrote 13 mind blowing, beautifully-crafted hard rock classics. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5ZG.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R5ZG.01.MZZZZZZZ.jpg' , NULL , NULL , 17.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 22 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (52 , 'Sin After Sin [Expanded Edition] [ORIGINAL RECORDING REMASTERED] [EXTRA TRACKS]' , 1 , 1 , 2 , 'B00005R62O' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R62O.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R62O.01.MZZZZZZZ.jpg' , NULL , NULL , 11.98 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.98 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (53 , 'Every Six Seconds' , 1 , 1 , 2 , 'B00005ABO8' , NULL , NULL , 0 , 'Saliva\'s heavy rock--with a dash of rap--is at once current and timeless, unlike many of the bands spawned by Korn and Limp Bizkit. This Memphis-bred bunch\'s powerful, diverse debut features a dozen lyrically and musically focused tracks from a band clearly possessed of strong chops and smart heads. Rangy singer Josey Scott\'s passionate delivery works well when matched with the chunky riffing of "Musta Been Wrong," the soaring, layered song\'s intensity balanced by shredding guitar. Every Six Seconds has many such moments, with producer Bob Marlette\'s taut, techno-inflected touch lending "Lackluster" and "Faultline" a NIN vibe. "Hollywood" is a classic midtempo take on Tinseltown, while the CD\'s first single, "Your Disease," is simply a hit. "My Goodbyes," the ideal album closer, has a mystical musical quality befitting departed loved ones. Ultimately, Saliva\'s thoughtful, heartfelt, earthy intensity make Every Six Seconds an impressive entre from start to finish. --Katherine Turman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005ABO8.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005ABO8.01.MZZZZZZZ.jpg' , NULL , NULL , 18.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 14.99 , 21 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (54 , 'There Is No Eye: Music for Photographs' , 1 , 1 , 2 , 'B00005R5ZU' , NULL , NULL , 0 , 'There Is No Eye: Music for Photographs--Recordings of Musicians Photographed by John Cohen is a great mix CD of raw, ragged, and right American folk music. Though that\'s little surprise as, since the late 1950s, John Cohen has patched together an alchemical body of work as a filmmaker, photographer, self-taught ethnographer, music writer, art professor, and musician. The CD accompanies a book of Cohen\'s beautiful, black-and-white documentary photos. Cohen really knows his folk music; his 1968 interview with Harry Smith for the Sing Out! fanzine remains the Rosetta stone for the all-important Anthology of American Folk Music, and as one-third of the New Lost City Ramblers he helped bring the visceral pleasures of true traditional Americana to a larger audience during the folk revival. This collection is wide-ranging and largely unerring. From Beat jazz to gospel, Appalachian a cappella singing to a Peruvian string band--it\'s all here, with no slick O Brother arrangements or anything else to get in the way of the music as it would have been heard on front porches, small clubs, and backyards. About a third of the tracks are previously unreleased; Dylanologists will need this CD for a swell unreleased track by the young Bobby, a version of "Roll on John" from a 1961 WBAI radio broadcast. --Mike McGonigal ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5ZU.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R5ZU.01.MZZZZZZZ.jpg' , NULL , NULL , 16.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 18 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (56 , 'Proverbial Wisdom Board Game' , 1 , 1 , 2 , 'B00000IS2G' , NULL , NULL , 0 , 'Although it takes only two to tango, it takes at least four people to play\r\n                       Proverbial Wisdom (of course, the more the merrier). Teams try to make\r\n                       heads or tails of sketches drawn by the presiding Wisdom Master (every\r\n                       picture tells a story!). They must also identify common sayings drawn on\r\n                       game cards, and choose the meaning of proverbs from three given\r\n                       options. The first team to get all the way around the board and solve the\r\n                       final sketch clue wins. After a few rounds, you and your friends and family\r\n                       will be spouting bits of conventional wisdom and age-old sayings\r\n                       everywhere you go. This great game isn\'t easy, but as they say... practice\r\n                       makes perfect! --Rachel Radway ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000IS2G.01.17TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00000IS2G.01.DTLS.MZZZZZZZ.gif' , NULL , NULL , 29.99 , 4.09 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 24.99 , 17 , NULL , NULL , NULL , 1 , '' , 2 , 6 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (57 , 'Five Stories' , 1 , 1 , 2 , 'B00005R62D' , NULL , NULL , 0 , 'Part of Boston\'s vibrant (and crowded) singer-songwriter scene, Kris Delmhorst stands out thanks to a gorgeous, tender, evocative voice and a textured and varied musical palette. She opens with a funked-up reworking of "Cluck Old Hen," complete with Beck-like banjo, followed by the bittersweet "Damn Love Song," where only acoustic guitar, cello, and accordion color in the lines behind her. "Broken White Line" is graced with delicate strains of pedal steel and mandolin, while the ominous, languid "Just What I Meant," a highlight here, crawls along with occasional bursts of cello and baritone sax. And her wounded voice on the haunting chorus of "Gave It Away" sends shivers. While Delmhorst is at her most appealing when the musical settings are ambitious, her lyrics seem to benefit from a more restrained approach. Thus, songs like "Words Fail You" and "Yellow Brick Road"--with basic musical tracks and too-clever words--fall comparatively flat. But for the most part, this is a powerful sophomore effort, one where elements of traditional roots-based folk successfully mingle with modern singer-songwriter flourishes. --Marc Greilsamer ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R62D.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R62D.01.MZZZZZZZ.jpg' , NULL , NULL , 16.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 18 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (58 , 'One Thousand Pennies' , 1 , 1 , 2 , 'B00005UP2Z' , NULL , NULL , 0 , 'Canadian entertainer Norman Foote\'s songwriting talents come to the fore on his new CD, One Thousand Pennies. An outstanding collection of 13 new songs, each featuring exquisite arrangements. Once again Norman puts his theatrical and comedic talents to use as he weaves stories and paints musical imagery with character voices that young listeners can respond to immediately. The songs are playful, with clever lyrics and melodies combining a variety of musical styles. \r\nA Song Sampling from One Thousand Pennies: \r\n\r\nThe title song, "One Thousand Pennies" with its Celtic beat takes us to a child\'s thoughts of what he thinks he can buy with One Thousand Pennies. Maybe to him they are magic pennies and seem to be worth much more than money itself. Loose Tooth is a conversation between a father and his child. All fathers would love to pull out their child\'s loose tooth if their child would only let them. This song has a comedic twist to its ending with the child saying to his father "If you really want to pull out someone\'s tooth pull one out of your own". Graduation Day has another cool Latin American beat and paints a picture of a child on his graduation day. It also has a comedic surprise ending when we learn he has only graduated from kindergarten. Norman\'s sensibility on this song shows how he can relate to young listeners ."I\'m ready for grade one, I can tie my shoes. I don\'t need velcro". Snuggle Up is a sweet sing-along type of tune that reminds us all of how wonderful a snuggle can be! Lost Umbrellas and Odd Socks takes us on a fanciful and imaginative journey to the land of lost umbrellas. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UP2Z.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UP2Z.01.MZZZZZZZ.jpg' , NULL , NULL , 13.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (59 , 'The Simpson\'s Loser Takes All Game' , 1 , 1 , 2 , 'B00005LBAP' , NULL , NULL , 0 , 'Losers of the world, unite! In the Simpson\'s Loser Takes All Game, players\r\n                       travel around the board and ask themselves some of life\'s most important\r\n                       questions. "Can I flip my eyelids up?" "Have I ever photocopied a body\r\n                       part?" Here\'s the catch: another player has to predict what your answer\r\n                       will be. If your answers are different, you lose a Character card. And in\r\n                       this game, that\'s a good thing. If the two answers match, the other player\r\n                       gets to lose a Character card. The player with the least amount of points\r\n                       accumulated from Junk Food Tokens, Fake Money, and Character cards,\r\n                       is the loser--and wins the game. Homer would be so proud! ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005LBAP.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005LBAP.01.DTLS.MZZZZZZZ.jpg' , NULL , NULL , 14.99 , 2.2 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (60 , 'Free To Be ... You And Me (1972 Television Cast) [CAST RECORDING]' , 1 , 1 , 2 , 'B000002VDL' , NULL , NULL , 0 , 'There are thousands upon thousands of children\'s albums out there, but the one that quietly left its mark with more \'70s children than perhaps any other album was this disc. Free to Be...You and Me was a pet project of proud feminist Marlo Thomas (a.k.a. "That Girl"), and it was born--according to the liner notes--by the desire to provide her niece with music "to celebrate who she was and who she could be." Harry Belafonte sings "Parents Are People," ex-football great Rosie Grier offers an incredible, touching melody titled "It\'s All Right to Cry," and Diana Ross waxes future-positive on "When We Grow Up." A great hour of brain food for young--and not-so-young--children. --Denise Sheppard ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000002VDL.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B000002VDL.01.MZZZZZZZ.jpg' , NULL , NULL , 11.98 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.98 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (61 , 'Trivial Pursuit Genus 5 Game' , 1 , 1 , 2 , 'B00005BY4G' , NULL , NULL , 0 , 'e first edition of Trivial Pursuit (early 80s?) was a great game that\r\n                       contributed to the emergence of the whole social games genre. But as a\r\n                       young teenager, I knew nothing about JFK\'s cabinet members, the rat\r\n                       pack, or dead movie stars, and this made the game impossibly difficult\r\n                       (and unbearably long). Between then and now, the questions have been\r\n                       modernized AND we\'ve all gotten older and more experienced. Genus 5 is\r\n                       perfectly targeted at the 30ish crowd, and more playable than the original\r\n                       for those younger or older. The questions are fairly balanced and\r\n                       reasonable.\r\n\r\n                       As always, the metagame of Trivial Pursuit (the board part) is, well, trivial\r\n                       and adds little of interest to the game play. It\'s really just a framework for\r\n                       asking each other trivia questions and there is no significant strategy\r\n                       involved. The artwork is pretty uninspired as well.\r\n\r\n                       Overall, Trivial Pursuit Genus 5 Edition is a solid, more playable version of\r\n                       a classic game.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BY4G.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005BY4G.01.DTLS.MZZZZZZZ.jpg' , NULL , NULL , 29.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 29.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (62 , 'Playhouse Disney' , 1 , 1 , 2 , 'B00005NWKX' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005NWKX.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005NWKX.01.MZZZZZZZ.jpg' , NULL , NULL , 12.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12.33 , 5 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (63 , 'Candy Land 50th Anniversary Edition' , 1 , 1 , 2 , 'B00000JGQA' , NULL , NULL , 0 , 'This perennial favorite prereading game has gotten a makeover for its 50th\r\n                       anniversary. The basics are the same: players still move ahead according\r\n                       to the color of the card they draw; they still try to avoid getting stuck in the\r\n                       Molasses Swamp; and they still thrill when they draw the magical Queen\r\n                       Frostine card. It\'s the game\'s graphics that have been updated. A\r\n                       three-dimensional version of the Candy Castle beckons at the end of the\r\n                       trail; the playing pieces look remarkably like gingerbread-folk come to life;\r\n                       and even the color blocks on the cards have a tastefully decorative frame\r\n                       around them. The whole thing is packed in a collector\'s tin for safekeeping.\r\n                       --Lisa Whipple ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000JGQA.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00000JGQA.01.DTLS.MZZZZZZZ.gif' , NULL , NULL , 19.99 , 2.3 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (64 , 'No Nagging' , 1 , 1 , 2 , 'B00005QK1W' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QK1W.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005QK1W.01.MZZZZZZZ.jpg' , NULL , NULL , 17.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.99 , 11 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (65 , 'Standard Scrabble' , 1 , 1 , 2 , 'B00000IWDB' , NULL , NULL , 0 , 'After all these years, it\'s still hard to get a triple word score, the tiles are\r\n                       still made of wood, and there\'s only one "X" in the whole box. The game of\r\n                       Scrabble has sparked feuds and a near-cult following. All the fuss is over a\r\n                       spelling game that hasn\'t had an upgrade in 50 years. It takes a little luck\r\n                       and a lot of skill to make high-scoring words out of seven little letters,\r\n                       sometimes with an overabundance of vowels and letters that don\'t go\r\n                       together--sometimes there\'s Q without U. Two to four players battle it out\r\n                       on the board, and while some players might be proud of impressive words\r\n                       ("I spelled gestalt!"), skilled players know how to use the premium letter\r\n                       and word squares on the 225-square board to their best advantage. This\r\n                       crossword game has strict rules (no names, no slang) and comes with a\r\n                       warning label: "Choose a dictionary first to avoid any ugly word disputes."\r\n                       --Lynne Sampson \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000IWDB.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00000IWDB.01.DTLS.MZZZZZZZ.gif' , NULL , NULL , 11.99 , 1.5 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 11.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (66 , 'Music Inspired by Middle Earth featuring David Arkenstone' , 1 , 1 , 2 , 'B00005R5LV' , NULL , NULL , 0 , 'It\'s very hip to refer to Tolkien, given the success of Lord of the Rings on celluloid. But to be fair to David Arkenstone, he\'s always been inspired by the master fantasy author, so the release of this album just happens to be timely. A collaboration between composer-multi-instrumentalists David and Diane Arkenstone, the disc features many of David\'s trademarks as it incorporates influences as diverse as Aaron Copland, international sounds, and progressive rock. With both orchestral and ethnic instruments at their disposal, the composers and their Middle Earth Orchestra journey from grand symphonic peaks to delicate valleys, including the grand fanfare of "Field of Cormallen," the mysterious and ethereal atmosphere of "Palantir," and the lively, Renaissance-flavored dance of "Road to Rivendell." While this ode to Middle Earth is nothing groundbreaking within Arkenstone\'s extensive catalog, it\'s still an amiable, engaging album that will appeal to longtime listeners and intrigue many fantasy fans. --Bryan Reesman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5LV.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R5LV.01.MZZZZZZZ.jpg' , NULL , NULL , 16.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12.99 , 23 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (67 , 'The Soul Of Healing Meditations' , 1 , 1 , 2 , 'B00005TZSK' , NULL , NULL , 0 , 'Featuring the soothing narration of Deepak Chopra over the trancelike music of Adam Plack, The Soul of Healing Meditations serves as an introduction to meditation for neophytes and as a more advanced tool to help overcome a physical ailment and/or emotional toxicity. That may make it sound like a digital elixir, but as Chopra says in his liner notes: "We like to tell our patients (at the Chopra Center for Well Being) that the body is the best pharmacy in the world and is capable of making wonder drugs." His message here is that one can naturally prevail over serious life challenges by becoming more attuned to one\'s body--by relaxing and filtering out the external world, focusing on and influencing internal sensations and biorhythms, and banishing negative thoughts and focusing on the positive aspects of life. This CD is not meant as a cure-all for physical or emotional ills. Rather, it\'s a supplemental experience to other treatments or programs, and it shows how enlightening and empowering meditation can be when practiced properly. Its actual effects will depend upon the receptiveness of the listener. Plack\'s accompanying soundtrack ranges from delicate ambient tones to more active Indian music, appropriately serving the mood of each of the album\'s eight tracks. --Bryan Reesman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TZSK.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005TZSK.01.MZZZZZZZ.jpg' , NULL , NULL , 17.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 22 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (68 , 'Across an Ocean of Dreams' , 1 , 1 , 2 , 'B00005UF2F' , NULL , NULL , 0 , 'What does the ocean dream? Glimpse into the depths of jeweled waters and the fantasia within. Surrender to the siren call. Come! Be transported under the waves, flowing with 2002\'s delicate strings, guitar, flute, keyboard and distant voices of angels of the deep. 2002 - Favorites on Billboard\'s New Age Chart for the past five years! \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UF2F.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UF2F.01.MZZZZZZZ.jpg' , NULL , NULL , 17.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 14.99 , 17 , NULL , NULL , NULL , 1 , '' , 0 , 0 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (69 , 'My Life Belongs To You' , 1 , 1 , 2 , 'B00005TQ18' , NULL , NULL , 0 , 'It seems pretty clear that Ronan Tynan has no intention of resting on his laurels. Despite a stunning string of world-dominating, top-selling releases as a member of the much-loved Irish Tenors--not to mention his accomplishments as a champion athlete, an M.D., and a memoirist (see his recently published Halfway Home: My Life \'til Now)--the singer has now released his debut solo effort on Sony Classical. No matter which member of the Irish Tenors happens to be your favorite, My Life Belongs to You is a treat, affording as it does a chance to bask in the deeply expressive, mellifluous voice of Tynan. He has chosen his selections well and is equally poised and tender in classics from Mario Lanza ("Because You\'re Mine," "I\'ll Walk with God"), Broadway, and sacred music. What\'s especially wonderful is the opportunity to hear Tynan\'s emotionally gripping vocalism from so many angles. The mixing by Frank McNamara gives a lovely old-time feeling to the orchestral playing--a bit like a treasured old sepia photograph. A bonus track of Irving Berlin\'s "God Bless America" is included. --Sarah Chin \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TQ18.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005TQ18.01.MZZZZZZZ.jpg' , NULL , NULL , 13.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.29 , 5 , NULL , NULL , NULL , 1 , '' , 1 , 2 , 2 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (70 , 'Barbie Toddler Helmet Value Pack' , 1 , 1 , 2 , 'B000054A9P' , NULL , NULL , 0 , 'Little girls can cycle, scooter, skate, and skateboard in style with this\r\n                       colorful, flowered Barbie helmet set. Manufactured by Bell Sports, bicycle\r\n                       helmet specialists, this seven-vent helmet has adjustable straps and\r\n                       additional foam pads to fit a child between 1 and 4 years of age.\r\n                       Composed of a foam liner and covered with a tight plastic shell, the helmet\r\n                       complies with CPSC (Consumer Product Safety Commission) standards\r\n                       for this age group. In our nonscientific study, it endured several hard\r\n                       slams by an adult to the edge of a desk, without showing any damage.\r\n                       With the addition of a sturdy pair of pink glasses with flip-up sun lenses in\r\n                       flowered rims and an 8-ounce water bottle, this ensemble will be a big hit\r\n                       with Barbie fans. --Diane Tuman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000054A9P.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B000054A9P.01.MZZZZZZZ.jpg' , NULL , NULL , 19.99 , 1 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (71 , 'Cristal: Glass Music Through The Ages' , 1 , 1 , 2 , 'B00005UT2L' , NULL , NULL , 0 , 'The haunting, ethereal tone of the glass armonica, which was invented by Ben Franklin in 1761, was said to drive its players insane. On Cristal, Dennis James risks madness as he surveys three centuries of music composed for Franklin\'s armonica, and two other glass instruments called the seraphim and the cristal baschet. Most of the selections date from the armonica\'s first period of popularity, which started in the late 1700s and ended in the 1830s, and include compositions by Hasse, Apell, Scmittbauer, a composer who also made armonicas, and Mozart, who composed the Adagio and Rondo for armonica just weeks before he died. James is joined on the Mozart piece by the Emerson String Quartet, who also play on Garry Eister\'s Quintet for Glass and Strings, one of the few 20th century pieces written for armonica. Cristal was produced by Linda Rondstadt, who also sings a duet with Ruth Ann Swenson on a lovely arrangement of Faur\'s Pavane. Ronstadt wisely avoids trying to turn this into a pop crossover and instead lets the fragile beauty of the music speak for itself. --Michael Simmons ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2L.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UT2L.01.MZZZZZZZ.jpg' , NULL , NULL , 17.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.99 , 11 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (72 , 'Acrobat Sno Board' , 1 , 1 , 2 , 'B000050B39' , NULL , NULL , 0 , 'Sharp cut Edge- Twin tip freestyle design- sidecut for easy turning- New\r\n                       toe strap design for younger riders. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050B39.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B000050B39.01.MZZZZZZZ.jpg' , NULL , NULL , 19.99 , 2.55 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 15.99 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (73 , 'Verdi - Messa da Requiem / Gheorghiu  Barcellona  Alagna  Konstantinov  Berliner Philharmoniker  Abbado' , 1 , 1 , 2 , 'B00005MG6F' , NULL , NULL , 0 , 'Verdi\'s Requiem--certainly one of his most moving, eloquent masterpieces--was written in honor of the great Italian poet Alessandro Manzoni, whom he admired enormously both for his writings and his political outlook. Though its text is the Latin liturgy, it has been called Verdi\'s greatest opera because of its basically dramatic character, as well as his own ambivalent attitude toward organized religion. Thus, interpretations tend to emphasize its secular or its sacred aspect, though, naturally, the soloists are trained in the Verdi opera tradition.\r\nFor example, Toscanini\'s legendary performance, recorded live at Carnegie Hall in 1951, takes exactly the opposite approach to this version. Inwardly expressive, noble, devout, pleading, prayerful, yet with plenty of dramatic intensity, the Toscanini encompasses every human emotion and offers a synthesis of Verdi\'s vision of the earthly and the sublime. The performers on this recording, captured live on the 100th anniversary of Verdi\'s death, take the theatrical view. The soloists swoop and slide, sob and sigh, and overdramatize the fear and trembling. Tenor Roberto Alagna belts out his part in the best operatic style, the bass sounds rough, the alto\'s vibrato wobbles, but soprano Angela Gheorghiu soars radiantly. The choruses are good, the orchestra is wonderful, but the dynamic contrasts go from inaudible to ear-splitting. --Edith Eisler \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005MG6F.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005MG6F.01.MZZZZZZZ.jpg' , NULL , NULL , 16.9 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.49 , 9 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (74 , 'Avalanche Double Snow Tube' , 1 , 1 , 2 , 'B00005RV4D' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005RV4D.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005RV4D.01.MZZZZZZZ.jpg' , NULL , NULL , 24.99 , 5 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 24.99 , 0 , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (75 , 'Baby Sleigh' , 1 , 1 , 2 , 'B000050B0J' , NULL , NULL , 0 , 'I\'m sorry to say that I was very disapointed with the quality of this product.\r\n                       I had 2 concerns with the build quality of the sleigh, 1st the side rails were\r\n                       not mounted securely and were prone to wobbling which did not instill\r\n                       confidence in their safety factor. Secondly was with the mounting set-up\r\n                       for the runners of the sleigh, the surface that the runers mounted too was\r\n                       almost twice as wide as the actual runners themselves which caused the\r\n                       snow to build up under the sleigh creating a fair amount of drag, which\r\n                       could cause the sleigh to become unstable and tip over. I have since\r\n                       returned the sleigh and am currently looking for another that is built better.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050B0J.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B000050B0J.01.MZZZZZZZ.jpg' , NULL , NULL , 39.99 , 7.15 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 39.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 2 , 2 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (76 , '110 Hyper Sno Board' , 1 , 1 , 2 , 'B000050B0A' , NULL , NULL , 0 , 'Overall, this snowboard is very good. I definitely recommend it. The only\r\n                       thing that prevented it from getting five stars in the "fun" category is that\r\n                       the manner in which you adjust the straps is very cumbersome. I got this\r\n                       as a gift for my nephew, and he wanted to go outside and try it out\r\n                       immediately. But it took us a long time to get the foot straps the right size\r\n                       for him. They are made of two pieces of plastic, each with two rows of\r\n                       holes in them. You choose the hole that is the right size for the kid\'s foot,\r\n                       then you connect them with a screw and nut combination that is pretty\r\n                       awkward. I would say that it was worth it, however, since he and his\r\n                       brother argued over whose turn it was for until their father made them\r\n                       come inside. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050B0A.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B000050B0A.01.MZZZZZZZ.jpg' , NULL , NULL , 19.99 , 4.1 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (77 , '28" Clifford with Sound' , 1 , 1 , 2 , 'B00005BRS3' , NULL , NULL , 0 , 'Clifford the Big Red Dog comes to life for his fans in the form of this\r\n                       28-inch-long plush pooch. A soft, rich red coat and Clifford\'s other familiar\r\n                       features--big paws, happy eyes, and a kind smile--combine to welcome\r\n                       friends into his furry embrace. Clifford\'s curled tail, yellow bone collar, and\r\n                       patch of black yarn hair complete his well-loved look. But he does more\r\n                       than sit around as your child\'s big ol\' buddy. Clifford makes three\r\n                       distinctive barks when his left paw is pressed, thanks to a battery-powered\r\n                       chip inside his large, soft body. Each bark seems to impart something\r\n                       different and important: your child can use his or her imagination to figure\r\n                       out just what Clifford is trying to say... --Diane Beall ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BRS3.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005BRS3.01.MZZZZZZZ.jpg' , NULL , NULL , 39.99 , 3.2 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 29.99 , 25 , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (78 , 'Apple iBook Notebook (600-MHz PowerPC G3, 256 MB RAM, 20 GB hard drive)' , 1 , 1 , 2 , 'B00005V5YU' , NULL , 'The new Apple iBook Notebook sports the largest display ever at 14 inches. Other features include a 600 MHz PowerPC G3 processor, 256 MB of SDRAM, a 20 GB Ultra ATA hard drive, a combination CD-RW and DVD-ROM drive, and Mac OS X.' , 0 , 'Now there\'s even more to love about Apple\'s iBook notebook. Weighing in at an easily portable 5.99 pounds and featuring a 600 MHz PowerPC G3 processor, a 20 GB hard drive, and 256 MB of RAM (expandable to 640 MB)--plus AirPort wireless networking and FireWire, USB, and Ethernet ports--the iBook connects to hundreds of peripherals designed to fit your life.\r\nThis system features a brilliant 14.1-inch TFT XGA active-matrix display and razor-sharp 1,024 x 768 resolution. It\'s the perfect place for doing everything from working on spreadsheets to displaying your movies and digital pictures in millions of colors (incidentally, the iBook display scales down beautifully, again with millions of colors, for special games and applications optimized for 800 x 600 or 640 x 480 resolutions). It\'s a marvel that such a wide screen has been fitted into a notebook computer that measures just 12.7 inches wide, 10.2 inches deep, and 1.35 inches thick. Note also the fit and finish that has always been a big part of the appeal of the iBook, as well as the subtle design touches that make it the quintessential consumer portable.\r\n\r\nIncluded is a CD-ROM drive for playing games and music CDs, as well as the option to upgrade with a DVD-ROM for enjoying DVD movies. The 600 MHz iBook ships with a 20 GB Ultra ATA hard disk drive, or upgrade to an optional 30 GB hard drive for even more storage space. In addition, this system comes with the ATI Rage Mobility 128 graphics accelerator with 8 MB of SDRAM and AGP 2x support for gorgeous 3-D graphics.\r\n\r\nThe iBook also comes loaded with iPhoto, the cool new software application in the easy-to-use tradition of iTunes, iMovie, and iDVD. iPhoto makes it a snap to manage your digital pictures. You can present them in a full-screen slide show (accompanied by your favorite music), e-mail them to your family and friends, print them on your inkjet printer, order Kodak prints over the Internet, or have them made into custom-printed, linen-bound books.\r\n\r\nIn addition to handling digital photos with ease, the iBook lets you make your own movies--and show them anywhere. Capture digital video footage on your DV camcorder and turn it into engaging movies with the iMovie 2 software that comes pre-installed. iMovie lets you transfer video clips from your digital camcorder to your hard disk using the included FireWire port. Use iMovie to snip out the boring parts and enhance the best parts with cool effects, transitions, and titles. Then add a great soundtrack and you\'re done. Now watch your finished movies full-screen on your iBook or use the iMovie Export feature to select from a range of predefined QuickTime formats for creating and sharing movies. You can, for example, compress your movies so you can burn them onto a CD or post them on the Internet, or use the VGA video output port (for video mirroring on an external display) and an AV port to show your movies and presentations on a big-screen TV or projector (just add an optional Apple AV cable).\r\n\r\nFor those interested in audio as well as video applications, the iBook comes with iTunes 2, the software that lets you convert (or "rip") the songs on your music CDs to MP3 format, simply by clicking a button. iTunes compresses CD-quality audio files to about a tenth of their original size with very little loss in audible quality. These significantly smaller file sizes enable you to store thousands of songs on your iBook\'s hard disk drive. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V5YU.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005V5YU.01.MZZZZZZZ.jpg' , NULL , NULL , 1799 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 1799 , NULL , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (79 , 'Briarberry Friends: Lavender Berrybeth' , 1 , 1 , 2 , 'B00000IZWR' , NULL , NULL , 0 , 'She may look shy, but Berrybeth is no shrinking violet. She\'s one in a\r\n                       series of beautiful, collectable, fun teddy bears from the Briarberry Patch\r\n                       collection. Berrybeth has fur colored a hazy lavender hue, and she wears\r\n                       a light purple dress and bow. The tints of lavender and lilac bring out the\r\n                       blush in her cheeks and the brightness in her blue eyes. Read Berrybeth\'s\r\n                       story and collect all her Briarberry friends. The set is great for collectors\r\n                       of plush toys, or little girls who want a friendly companion. --Courtney\r\n                       Hudak ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000IZWR.01.TZZZZZZZ.gif' , 'http://images.amazon.com/images/P/B00000IZWR.01.MZZZZZZZ.gif' , NULL , NULL , 14.99 , 0.5 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 9.98 , 33 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (80 , 'Compaq Presario 2715US Notebook (1.13-MHz Pentium III, 512 MB RAM, 30 GB hard drive)' , 1 , 1 , 2 , 'B00005UT2X' , NULL , 'As a notebook for business or entertainment, Compaq\'s Presario 2715US offers a combination of solid features and price that is tough to beat. It boasts a 1.13 GHz Pentium III processor, 512 MB of RAM (expandable to 1,024 MB), a 15-inch,... \r\n Read more \r\n' , 0 , 'As a notebook for business or entertainment, Compaq\'s Presario 2715US offers a combination of solid features and price that is tough to beat. It boasts a 1.13 GHz Pentium III processor, 512 MB of RAM (expandable to 1,024 MB), a 15-inch, active-matrix, flat-panel screen, and both an 8x (write) CD-RW and 8x DVD-ROM drive. Also included are a 30 GB hard disk, a 56K modem, and a 10/100 Mbps Ethernet NIC. To round out this Presario\'s versatile package, the pre-installed operating system is Windows XP Home. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2X.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UT2X.01.MZZZZZZZ.jpg' , NULL , NULL , 2099 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 2099 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (81 , 'Jumbo Music Block' , 1 , 1 , 2 , 'B00005BHTK' , NULL , NULL , 0 , 'Jumbo Music Block is big on fun and big on learning! Designed to help\r\n                       children learn shapes, colors, and dressing skills, this giant foam block\r\n                       features fun music, surprise pockets, and interactive activities. Each side\r\n                       plays two children\'s songs - toe-tapping classics and jazzy new tunes\r\n                       entertain children while reinforcing shape learning and language skills. Each\r\n                       side of this huggable oversized block also features a colorful geometric\r\n                       shape and a secret surprise pocket. Zippers, snaps, and buttons develop\r\n                       fine motor skills and challenge children to uncover whimsical activities\r\n                       including a shiny peek-a-boo mirror, an ABC & 123 book, and a wiggly busy\r\n                       ball. Batteries sold separately. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BHTK.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005BHTK.01.MZZZZZZZ.jpg' , NULL , NULL , 59.99 , 6.2 , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 59.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (82 , 'IBM Thinkpad T23 Notebook (1.2-GHz Pentium III, 128 MB RAM, 48 GB hard drive)' , 1 , 1 , 2 , 'B00005TSMH' , NULL , '1.2 GHz Intel Pentium III, 128 MB SDRAM, 48 GB EIDE Hard Disk, 24x (read), 8x (write), 4x (rewrite) CD-RW, and Windows XP Professional, IBM Software Installer, IBM Access Connections ' , 0 , 'Highly portable and with plenty of processing speed, the ThinkPad T23 has a lot to offer those seeking a business-oriented notebook. Consider, for example, its 1.2 GHz Pentium III chip, 48 GB hard disk, and 128 MB of RAM (expandable to 1,024 MB). A large 14.1-inch, active-matrix screen and 24x (read), 8x (write), 4x (rewrite) CD-RW drive make this system adequate in the area of entertainment as well. The installed operating system is Windows XP Professional, which adds business-oriented security and networking features to Microsoft\'s Windows 2000 OS. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TSMH.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005TSMH.01.MZZZZZZZ.jpg' , NULL , NULL , 3599 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 3599 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (83 , 'Compaq Presario 5410US Desktop (1.3-GHz Celeron, 256 MB RAM, 40 GB hard drive)' , 1 , 1 , 2 , 'B00005UT2R' , NULL , '1.3 GHz Intel Celeron, 256 MB SDRAM, 40 GB Hard Disk, 8x (write) CD-RW, 16x DVD-ROM, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ... ' , 0 , 'Whether you\'re looking for a corporate, multimedia, or family desktop, Compaq\'s Presario 5410US is a solid choice. Just look at some of its features: an 8x (write) CD-RW and 16x DVD-ROM drive, a 1.3 GHz Celeron chip, and 256 MB of RAM (expandable to 512 MB). Its price is lower than average both for desktops as a whole and among similarly rated products, continuing Compaq\'s price-conscious tradition. The product also includes a 40 GB hard disk, integrated graphics, a 56K modem, and a 10/100 Mbps Ethernet NIC. In addition, the Presario 5410US features Windows XP Home as the pre-installed operating system. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2R.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UT2R.01.MZZZZZZZ.jpg' , NULL , NULL , 699 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 699 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (84 , 'Compaq Presario 5400US Desktop (1.2-GHz Celeron, 128 MB RAM, 20 GB hard drive) + Compaq MV540 15" Monitor' , 1 , 1 , 2 , 'B00005V7HD' , NULL , '1.2 GHz Intel Celeron, 128 MB SDRAM, 20 GB Hard Disk, 8x (write) CD-RW, This bundled system comes with a 15" Monitor, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ... ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V7HD.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005V7HD.01.MZZZZZZZ.jpg' , NULL , NULL , 868 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 868 , NULL , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (85 , 'Compaq Deskpro 4000 Desktop (266-MHz Pentium II, 32 MB RAM, 3.2 GB hard drive)' , 1 , 1 , 2 , 'B00005V600' , NULL , '266 MHz Intel Pentium II, 32 MB RAM,  3.2 GB Hard Disk, Included CD-ROM, and No Operating System ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V600.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005V600.01.MZZZZZZZ.jpg' , NULL , NULL , 115.95 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 115.95 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (86 , 'Apple iMac Desktop, graphite (600-MHz PowerPC G3, 256 MB RAM, 40 GB hard drive)' , 1 , 1 , 2 , 'B00005NK3C' , NULL , '600 MHz PowerPC G3, 256 MB SDRAM, 40 GB Hard Disk, 24x (read), 8x (write), 4x (rewrite) CD-RW, and Mac OS 9 and below, Mac OS X, QuickTime, iMovie 2, iTunes, AppleWorks, Microsoft Internet Explorer, Microsoft Outlook ... ' , 0 , 'If you like the all-in-one design of the iMac desktop but need more power than entry-level units offer, this enhanced model may be right for you. It includes a PowerPC G3 chip running at 600 MHz, 256 MB of RAM (expandable to a gigabyte), and a 40 GB hard disk drive. That\'s big enough to store thousands of MP3 music files, for example--and the included CD-RW drive makes it easy to burn your own CDs. A 56K modem and 100 Mbps networking are standard. The system\'s integrated case design, in a translucent gray that Apple calls "graphite," houses a 15-inch monitor with 13.8-inch viewable area. The system comes with both the classic Mac OS 9 and the slick new Mac OS X installed. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005NK3C.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005NK3C.01.MZZZZZZZ.jpg' , NULL , NULL , 994 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 994 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (87 , 'Apple Power Mac Desktop (1-GHz Dual Processor PowerPC G4, 512 MB RAM, 80 GB hard drive)' , 1 , 1 , 2 , 'B00005YXCD' , NULL , 'Dual 1 GHz PowerPC G4, 512 MB SDRAM, 80 GB Ultra ATA Hard Disk, 24x (read), 8x (write), 4x (rewrite) CD-RW, 6x (read), 2x (write) DVD-R, and Mac OS 9 and below, Mac OS X, QuickTime, iMovie 2, iPhoto, iTunes 2, Mac OS X Mail, iDVD 2, DVD Player, Microsoft ... ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005YXCD.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005YXCD.01.MZZZZZZZ.jpg' , NULL , NULL , 2999 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 2999 , NULL , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (88 , 'Compaq Presario 5420US Desktop (Athlon XP 1700+, 512 MB RAM, 80 GB hard drive)' , 1 , 1 , 2 , 'B00005UT2S' , NULL , '1.47 GHz AMD Athlon XP, 512 MB SDRAM, 80 GB Hard Disk, 16x (write) CD-RW, 16x DVD-ROM, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ...  \r\n' , 0 , 'It would be hard to go wrong with a system like the Compaq Presario 5420US. Equipped with a 1.7 GHz Athlon XP processor, an 80 GB hard disk drive, and 512 MB of RAM (expandable to 1,536 MB), it has all the basics covered--and then some. For ease of use, improved multimedia, and better support of peripherals, Compaq has installed Windows XP Home Edition. To enhance multimedia applications and Internet connectivity, this system includes a 16x (write) CD-RW and 16x DVD-ROM drive, integrated graphics, a 56K modem, and a 10/100 Mbps Ethernet NIC. All these features at a price lower than most comparably equipped desktops make this system a versatile addition to any home or office. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2S.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UT2S.01.MZZZZZZZ.jpg' , NULL , NULL , 899 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 899 , NULL , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (89 , 'Compaq Presario 5420US Desktop (Athlon XP 1700+, 512 MB RAM, 80 GB hard drive) + Compaq FS740 17" Monitor' , 1 , 1 , 2 , 'B00005V7J8' , NULL , '1.47 GHz AMD Athlon XP, 512 MB SDRAM, 80 GB Hard Disk, 16x (write) CD-RW, 16x DVD-ROM, This bundle comes with Compaq 17" Monitor, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ... ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V7J8.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005V7J8.01.MZZZZZZZ.jpg' , NULL , NULL , 1298 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 1298 , NULL , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (90 , 'Nikon WC-E63 Wide-Angle Converter Lens' , 1 , 1 , 2 , 'B000052187' , NULL , 'Capture sweeping vistas with Nikon\'s WC-E63\r\n                                         wide-angle lens created for their Coolpix digital\r\n                                         cameras. Quick installation and setup\r\n                                         combined with superb results have helped this\r\n                                         lens get five stars out of five in our customer\r\n                                         reviews. For quality wide-angle pictures at a\r\n                                         great price, look no further.' , 0 , 'Very sturdy, clean crisp lens. It comes with a nice velour bag, and two lens\r\n                     caps. It covers up 90% of the flash, so ambiant light (or external flash) is\r\n                     needed to take good pictures.\r\n\r\n                     You screw the lens on, set your 990 to "M", and through the menu, you select\r\n                     "Wide Angle", and you\'re good to go.\r\n\r\n                     No distortion is apparent on the pictures, which are the same excellent quality\r\n                     you\'re used to from the 990. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000052187.01.12TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B000052187.01.MZZZZZZZ.jpg' , NULL , NULL , 170 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 149.99 , 12 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (91 , 'Tiffen 55mm 6 Point Star Filter' , 1 , 1 , 2 , 'B00004ZCCP' , NULL , 'Add sparkle to your photos with this six-point\r\n                                         star filter from Tiffen. It\'s great for glamour\r\n                                         shots, water reflections, and candle-lit scenes.\r\n                                         You\'ll get stunning results for stylish pictures\r\n                                         every time.' , 0 , 'Photographs were beyond expectation...inspite of photographer\'s expertise!\r\n                     Clean, crisp stars fade gently, especially dramatic with water reflections and\r\n                     candles! ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004ZCCP.01.40TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00004ZCCP.01.MZZZZZZZ.jpg' , NULL , NULL , 41.5 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 24.99 , 40 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (92 , 'NEC MultiSync FP1370 Totally Flat 22" Monitor (PC/Mac)' , 1 , 1 , 2 , 'B00004Y6C8' , NULL , NULL , 0 , 'The NEC MultiSync FP1370 totally flat 22-inch monitor is ideal for users whose work demands high-end performance. This full-featured 22-inch (20-inch viewable) display is well suited for CAD/CAM, graphic design, desktop publishing, animation, document imaging, prepress, medical imaging, and Web design applications. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004Y6C8.01.11TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00004Y6C8.01.MZZZZZZZ.jpg' , NULL , NULL , 899.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 799.99 , 11 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (93 , 'Ceiva Internet-Enabled Photo Frame' , 1 , 1 , 2 , 'B00005B4BW' , NULL , 'Send your friends or relatives your favorite photos\r\n  with Ceiva\'s Internet-enabled photo frame. With a\r\n  built-in modem, the Ceiva automatically downloads\r\n  20 pictures a day from your account on the Ceiva\r\n  Web site (annual subscription required). Powerful\r\n  Web-based management tools give you complete\r\n  control over your Ceiva.' , 0 , 'Ceiva put the future in an unassuming black picture frame with this\r\n                     amazingly simple yet innovative product. This Internet-enabled frame makes\r\n                     it so easy to receive and display digital photos that even the most tech-shy\r\n                     relatives will love it. The traditional frame houses an LCD screen that displays\r\n                     up to 20 pictures in a single-view or slide-show format. Once a day, the\r\n                     frame dials in to Ceiva\'s Web site and downloads any new photos that have\r\n                     been sent to you (or that you\'ve uploaded). What\'s truly amazing is that it\r\n                     works flawlessly--it\'s a cutting-edge technology idea that\'s well executed. \r\n\r\n                     The frame itself is a handsome classic black with a black matte. It\'s about the\r\n                     size of a standard 8-by-10-inch frame, and the viewing area is about 5 by 7\r\n                     inches. The display resolution is 640 x 480 VGA, and the images are\r\n                     displayed as JPEGs. We were impressed with the picture quality, especially\r\n                     considering the display is passive matrix--colors were a bit washed out, but\r\n                     otherwise pictures were sharp, bright, and looked good. The viewing angle\r\n                     isn\'t great--you won\'t be able to see pictures well from the side--but overall,\r\n                     the screen worked very well, even in relatively bright light. \r\n\r\n                     You do the bulk of your setup online at Ceiva\'s Web site. Here, you can\r\n                     lock, delete, upload, or send photos, and you can adjust the rest of your\r\n                     settings, such as the slide-show interval or the time the Ceiva turns off the\r\n                     display every night. (The standard setting shuts it off from 12 a.m. to 4 a.m.)\r\n                     Within your account, you can choose who can send pictures to you (your\r\n                     "Buddy list"). Your buddies don\'t need to own Ceiva photo frames, but they\r\n                     have to get Ceiva accounts, which are free. In addition to photos, you and\r\n                     your friends can send and receive any kind of digital image, from\r\n                     hand-drawn cards to scanned art. Subscription channels even let you get\r\n                     comics, weather and traffic reports, and horoscopes on a daily basis.\r\n                     Ceiva\'s site also provides simple tools to add messages to your photos. \r\n\r\n                     The controls on the Ceiva are extremely easy to use--there is one button that\r\n                     adjusts brightness and another button to stop the slide show and dial-up on\r\n                     demand. If you want to download pictures immediately (for instance, right\r\n                     after your mother calls and tells you she just sent a new batch), you press\r\n                     and hold the settings button on the frame until it connects. \r\n\r\n                     You don\'t need an extra telephone line to use the Ceiva--the photo frame\r\n                     uses your existing line for just a few minutes every night. Ceiva provides a\r\n                     Y-connector in the box to make it easy for you to plug the frame into your\r\n                     phone jack without disconnecting your phone. The photo frame also doesn\'t\r\n                     require you to have an Internet connection to download photos, although a\r\n                     subscription is required to download photos. The subscription costs $59.95\r\n                     per year to maintain this service via a local connection. However, if you want\r\n                     to upload pictures, send them to other people\'s Ceivas, or modify certain\r\n                     frame settings, you\'ll need to use an Internet connection. \r\n\r\n                     Overall, our experience using the Ceiva was simply wonderful. It\'s intended to\r\n                     be simple to use, and it does a great job receiving and displaying photos. It\r\n                     strikes us as the perfect gift for your Mom and Dad, your grandparents, or\r\n                     any long-distance friend who is computer-shy. Not to mention that the Ceiva\r\n                     photo frame is just plain cool!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005B4BW.01.20TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005B4BW.01.MZZZZZZZ.jpg' , NULL , NULL , 250 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 199.99 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (94 , 'KDS VS-21E 21" Monitor' , 1 , 1 , 2 , 'B00001R3VE' , NULL , 'The VS-21e is designed for imaging and CAD/CAM/CAE professionals who want maximum performance for today\'s technology. A powerful tool for high-end graphics, production, scientific, and engineering design applications, its advanced features deliver sharp pictures, crisp colors, and precise lines with virtually no eyestrain. \r\n' , 0 , 'If you\'re tired of squinting at the small monitor in front of you, the KDS Visual Sensation 21e is the 21-inch solution to your tiny-display woes. Whether you\'re a high-end CAD user, graphics professional, or even a casual user, the KDS VS-21e offers an advanced and robust display at a slim price. This massive display provides 19.9 inches of display, perfect for those who are bogged down by the clutter of overlapping windows.\r\nThe display quality of the KDS VS-21e amazed us; the display has rich color and tight contrast and brightness controls. We found the DVD playback to be bright and colorful, as were screens using various graphics programs. Onscreen controls include RGB color temperature, pincushion controls, horizontal and vertical convergence adjustment, and positioning controls. Calibration controls are a cinch with a four-button touch pad and easily navigable onscreen display menu.\r\n\r\nTired of the flicker of low-refresh-rate monitors? The Visual Sensation supports a whopping 1,920 x 1,440 at 75 Hz. And even if you prefer lower resolutions, the VS-21e supports sky-scraping refresh rates. For graphics professionals, the VS-21e provides BNC connections for a top-quality image. The only flaw we noticed was a slight geometric distortion that couldn\'t be corrected, in the corners of the monitor. Even with this rather minor flaw, the KDS Visual Sensation 21e is the all-in-one solution for graphics professionals, businesses, and even everyday users. --Dan Simpson \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00001R3VE.01.16TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00001R3VE.01.MZZZZZZZ.jpg' , NULL , NULL , 549.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 463.94 , 16 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (95 , 'Sharp VL-WD450U 2.5" Viewfinder Screen Digital Camcorder with Built-in Digital Still Mode' , 1 , 1 , 2 , 'B00005BABT' , NULL , 'A powerful 26x optical zoom and digital\r\n                                         still-shot mode are the cornerstones of the\r\n                                         Sharp VL-WD450U. They make it easy to\r\n                                         capture every moment. March 31, 2002 save\r\n                                         $100 with a mail-in rebate.' , 0 , 'The Sharp VL-WD450U is a compact, relatively easy-to-use DV camcorder.\r\n                     Right out of the box, anyone who\'s used a camcorder before can put the\r\n                     camera to use. Primary functions are easily controlled by the right hand\r\n                     while gripping the camera. Recording is as simple as pressing the button\r\n                     located at your thumb, and the zoom is operated by means of a rocker\r\n                     switch under your forefinger. The zoom is variable, so the farther you press\r\n                     the rocker in a particular direction, the faster the zoom operates. In\r\n                     subjective tests, there seemed to be three different zoom speed levels. The\r\n                     surprisingly large 26x optical zoom lens (made by Canon) is paired with a\r\n                     digital image stabilization system. The image stabilization is relatively\r\n                     effective with slight hand-shake, but don\'t expect to walk around and have the\r\n                     stabilizer make up for your body movement. This system works by cropping\r\n                     the picture on the CCD and using the excess information as a buffer. Digital\r\n                     stabilization isn\'t as good a solution as an optically based system, but it\'s\r\n                     more compact and significantly less expensive. The digital image stabilization\r\n                     can be turned off through the menu system.\r\n\r\n                     The menu system is a bit confusing the first time you access it. If you\r\n                     haven\'t taken the time to read the manual, you\'ll probably have difficulty with\r\n                     the navigation. You move through the various menus using the VCR controls\r\n                     (rewind, fast-forward, play, etc.) located on the same side of the camera as\r\n                     the LCD monitor. This location is a little bizarre, as your hand partially blocks\r\n                     the LCD screen from view--don\'t expect to use the camcorder while moving\r\n                     around in the menus. After you get over the initial difficulty, the menus aren\'t\r\n                     too bad. A selection of icons along the left side represent the main\r\n                     categories. Each selection has various submenus that may or may not unfold\r\n                     into more menus.\r\n\r\n                     While the camcorder comes with the ability to shoot stills onto an included\r\n                     8-MB SmartMedia card, you can\'t shoot video and stills at the same time. To\r\n                     capture stills onto the memory card, you first have to flip a "media" switch\r\n                     that chooses between tape and card. While set to tape, you can shoot video\r\n                     and capture either six seconds of still footage, or a continuous still image\r\n                     onto the MiniDV cassette. Transfer of the still images from the SmartMedia\r\n                     card to a computer is troublesome. You\'ll need a PC with a serial port, and\r\n                     Macs aren\'t compatible with either the hardware or software. Sharp should\r\n                     have used a USB connection instead--it\'s speedier and more universal.\r\n\r\n                     In addition to the built-in mic, Sharp includes a unique zoom microphone that\r\n                     can be set to sync automatically with the lens. The mic adds to the overall\r\n                     size of the camera, but dramatically improves the quality of the sound on\r\n                     your recordings, greatly reducing background noise and making it easier to\r\n                     hear the subjects in your recordings. For added portability, the microphone\r\n                     can be removed, automatically activating the built-in microphone in the\r\n                     camera. \r\n\r\n                     Apparently, Sharp doesn\'t expect most moviemakers to use the camera for\r\n                     more than its most basic functions, and includes only a simple RCA cord in\r\n                     the package. The camera has an IEEE1394 connection for lossless digital\r\n                     transfer of your movies to your computer or another camcorder, and also\r\n                     has s-video output for connection to many newer televisions, especially\r\n                     higher-end models. If you want to use these features, however, you\'ll have to\r\n                     run to the store for another cable. \r\n\r\n                     All in all, the Sharp VL-WD450U is pretty good at what it does--shoot digital\r\n                     video onto MiniDV tapes. The Canon video lens is a great piece of glass, and\r\n                     probably one of the most--if not the most--important piece of equipment in\r\n                     the camcorder. Our only qualms come with the limited connectivity options\r\n                     for transferring still images, and the lack of video cables. Although it\'s\r\n                     common practice in the industry to skimp on the bundle, it\'s still a bitter pill to\r\n                     swallow when many other manufacturers do include IEEE1394 and s-video\r\n                     cables. --Michael Lewis' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BABT.01.37TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005BABT.01.MZZZZZZZ.jpg' , NULL , NULL , 949.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 599.99 , 37 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (96 , 'Envision 15" EN-5100 TFT LCD High Resolution Color Display' , 1 , 1 , 2 , 'B00005MNSR' , NULL , 'Envision\'s EN5100 brings size, value, and performance in LCD display technology to a new level. The EN5100\'s LCD technology means that the super-thin screen will take up very little desktop space. A 15-inch diagonal viewing size and 1,024 x 768 resolution guarantees a high-definition picture that won\'t have you straining your eyes. The onscreen display is easily accessible on the front panel and allows you to configure color temperature and display settings. The display is EPA Energy Star... ' , 0 , 'Envision\'s EN5100 brings size, value, and performance in LCD display technology to a new level. The EN5100\'s LCD technology means that the super-thin screen will take up very little desktop space. A 15-inch diagonal viewing size and 1,024 x 768 resolution guarantees a high-definition picture that won\'t have you straining your eyes. The onscreen display is easily accessible on the front panel and allows you to configure color temperature and display settings. The display is EPA Energy Star compliant and VESA, XGA, SVGA, and VGA compatible. It offers complete plug-and-play setup and operation, which means that it is ready to be hooked up to your computer right out of the box. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005MNSR.01.22TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005MNSR.01.MZZZZZZZ.jpg' , NULL , NULL , 459.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 359.99 , 22 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (97 , 'Samsung 15" 570V TFT LCD Monitor' , 1 , 1 , 2 , 'B00005NDUP' , NULL , 'The SyncMaster 570-volt TFT is Samsung\'s most affordable display solution for business and home users who want all the space-saving benefits of a flat-panel display. Not only does this monitor provide stunning color and razor-sharp images, it takes up a third of the desktop space of a traditional CRT monitor.\r\n\r\nThis Samsung monitor line delivers flat images that are easier on the eyes, and includes slimmer products that save valuable desk space. Samsung applies state-of-the-art display... \r\n' , 0 , 'The SyncMaster 570-volt TFT is Samsung\'s most affordable display solution for business and home users who want all the space-saving benefits of a flat-panel display. Not only does this monitor provide stunning color and razor-sharp images, it takes up a third of the desktop space of a traditional CRT monitor.\r\n\r\nThis Samsung monitor line delivers flat images that are easier on the eyes, and includes slimmer products that save valuable desk space. Samsung applies state-of-the-art display technology to create flat and slim products that are clearer, brighter, and more energy efficient. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005NDUP.01.36TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005NDUP.01.MZZZZZZZ.jpg' , NULL , NULL , 609 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 389.99 , 36 , NULL , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (98 , 'ViewSonic VP181 18" Flat Panel LCD Monitor' , 1 , 1 , 2 , 'B00004SYWC' , NULL , 'ViewSonic\'s VP181 ViewPanel is the first 18-inch multifunctional flat panel to incorporate digital, analog, and composite video inputs into an all-in-one display. With its thin 4-inch profile, the adjustable, ergonomically designed ViewSonic VP181 fits easily into confined spaces or can be wall mounted. Its TVT active-matrix display delivers 16.7 million colors. A 1,280 x 1,024 native resolution ( maximum resolution of 1,600 x 1,200) combined with 235 nits of brightness dispense crisp images.\r\n\r\n' , 0 , 'ViewSonic\'s VP181 ViewPanel is the first 18-inch multifunctional flat panel to incorporate digital, analog, and composite video inputs into an all-in-one display. With its thin 4-inch profile, the adjustable, ergonomically designed ViewSonic VP181 fits easily into confined spaces or can be wall mounted. Its TVT active-matrix display delivers 16.7 million colors. A 1,280 x 1,024 native resolution ( maximum resolution of 1,600 x 1,200) combined with 235 nits of brightness dispense crisp images.\r\n\r\nOn-demand audio, picture-in-picture capabilities, a variety of supported video formats, and analog and digital compatibility are some of the ViewSonic VP181\'s many features. It is capable of accepting multiple input signals. You can hook up additional USB peripherals, such as a scanner, camcorder, or DVD player to the USB ports on the base of the display. The ViewSonic VP181 allows composite video input from your DVD or VCR to run live while working real time on other applications. The USB inputs on the base and panel allow flexible configuration.\r\n\r\nA pair of built-in two-watt speakers produce stereo sound. There are a number of advanced image and sound options for customized viewing and audio. Software drivers are included that enable you to display in both landscape and portrait modes for full-page viewing.\r\n\r\nViewSonic backs the VP181 with a three-year limited warranty on parts and labor. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004SYWC.01.17TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00004SYWC.01.MZZZZZZZ.jpg' , NULL , NULL , 1935 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 1599.99 , 17 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (99 , 'Canon ZR30MC Digital Camcorder with Built-in Digital Still Mode' , 1 , 1 , 2 , 'B00005AUJB' , NULL , 'Canon\'s top ZR-series camcorder, the ZR30MC\r\n  comes equipped with a 10x optical zoom, a 2.5\r\n  inch LCD monitor, and a digital still mode that\r\n  records onto the bundled 8 MB memory card.' , 0 , 'Canon\'s sleek and compact ZR30 MC camcorder provides almost everything\r\n                     you need to shoot both beautiful footage and digital stills. Small enough to fit\r\n                     in your pocket, the ZR30 MC is equipped with a color LCD view screen and\r\n                     a color eyecup viewfinder, a digital image stabilization system to steady the\r\n                     jittery hand, and a digital zoom that magnifies up to 200 times.\r\n\r\n                     To help ensure that you get the quality footage you want, Canon has\r\n                     included a number of preset shooting modes. These modes will automatically\r\n                     adjust the settings of your camcorder for a variety of shooting situations.\r\n                     There is also an additional set of special effects available during both\r\n                     recording and playback that will help add a little flavor to your movies. These\r\n                     effects include black-and-white, sepia, and mosaic, among others.\r\n\r\n                     Also, using the ZR30 MC\'s photo mode, you can take over 700 still photos\r\n                     with an 80-minute MiniDV tape or store it onto the portable 8 MB\r\n                     MultiMediaCard. The ZR30 MC also comes with customizable light-up VCR\r\n                     buttons: choose from blue, turquoise, and green. You have your choice of\r\n                     four recording speeds, which allow you to record at up to three times the\r\n                     normal recording time on a standard MiniDV cassette. Additionally, with the\r\n                     advanced accessory shoe, you can easily add a shotgun microphone or\r\n                     video light. With the IEEE 1394 port you can connect the ZR30 MC to a\r\n                     DV-ready personal computer to edit video or e- mail photos. Included in the\r\n                     package are an A/V cable, power adapter, shoulder strap, and battery pack.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005AUJB.01.20TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005AUJB.01.MZZZZZZZ.jpg' , NULL , NULL , 999 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 799.99 , 20 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (100 , 'Canon Elura 20MC Digital Camcorder with SD Card' , 1 , 1 , 2 , 'B00005QEYE' , NULL , 'Canon\'s Elura 20MC is packed with numerous\r\n  great features designed to help you shoot\r\n  exemplary video footage. The camera is built\r\n  around a 10x optical zoom lens and progressive\r\n  scan CCD, and also includes analog inputs plus a\r\n  digital still mode with 640 x 480 resolution.' , 0 , 'The Elura 20MC joins a growing crowd of small, vertically oriented\r\n                     camcorders that pack an enormous number of features into their tiny cases.\r\n                     In this case, you get a 10x optical zoom, progressive scan CCD, analog\r\n                     inputs, and a 2.5-inch LCD monitor, among other things. \r\n\r\n                     Canon is known for their lenses, and the 10x optical zoom lens is a good\r\n                     one. The zoom can also be digitally enhanced to provide 40x magnification,\r\n                     but the 10x should be enough for most purposes. Additionally, the camcorder\r\n                     is equipped with an image stabilizer to help eliminate the shakes and jitters\r\n                     associated with handheld video shooting (at any zoom level). Also of note is\r\n                     the progressive scan CCD, which provides a full screen of video information\r\n                     for every frame, as opposed to the standard (interlaced) CCD, which\r\n                     provides a half a screen of information for every frame. This type of CCD is\r\n                     a good choice for those who need to analyze things in slow motion (like golf\r\n                     swings).\r\n\r\n                     The digital still mode records 640 x 480 stills onto an included 8 MB MMC\r\n                     card, although you can also use SD memory cards. While the images aren\'t\r\n                     the highest resolution, they\'re still great for pictures you want to post on the\r\n                     Web, or e-mail to friends and family. Also, the Elura has a feature Canon\r\n                     calls the Digital Motor Drive, which captures 30 full-frame images a second\r\n                     onto the included memory card. \r\n\r\n                     The Elura also features a great number of inputs and outputs, meant to\r\n                     satisfy even the most ardent gear-fanatic\'s lust. You get the standard IEEE\r\n                     1394 port, composite and S-video analog inputs for converting all your old\r\n                     footage to digital, and a mic input that allows you to use an external mic\r\n                     source (good for pro-sounding audio). \r\n\r\n                     The Elura 20MC is a great little camcorder that includes a lithium-ion battery,\r\n                     power adapter, battery charger, docking unit, S-video cable, stereo video\r\n                     cable, and 8 MB MMC card.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QEYE.01.28TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005QEYE.01.MZZZZZZZ.jpg' , NULL , NULL , 1799 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 1299.99 , 28 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (101 , 'Sceptre D50X 15" Non-Glare Flat Screen CRT Monitor' , 1 , 1 , 2 , 'B00004Y7E8' , NULL , 'With a maximum resolution of 1,024 x 768 at a 65 Hz refresh rate, and 0.28-millimeter dot pitch, the Sceptre D50X 15-inch nonglare flat-screen CRT (cathode-ray tube) monitor produces a high level of sharpness, resulting in more stable pictures with less flicker. Multistep dynamic focus (MSDF) provides clearer, crisper images at all points of the screen. The antireflective, antistatic screen coating helps diminish eyestrain. The D50X monitor also features two easy-to-use knobs, one for... ' , 0 , 'With a maximum resolution of 1,024 x 768 at a 65 Hz refresh rate, and 0.28-millimeter dot pitch, the Sceptre D50X 15-inch nonglare flat-screen CRT (cathode-ray tube) monitor produces a high level of sharpness, resulting in more stable pictures with less flicker. Multistep dynamic focus (MSDF) provides clearer, crisper images at all points of the screen. The antireflective, antistatic screen coating helps diminish eyestrain. The D50X monitor also features two easy-to-use knobs, one for selecting the function you wish to modify and the other for making actual adjustments. This provides you with more control over adjustments, and you avoid having to push buttons or cycle through a menu of choices. The optional USB technology allows for higher video throughput, and connectors can be daisy-chained to free up input/output ports. \r\n\r\nThe D50X is MRP II certified and is backed by a five-year limited warranty. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004Y7E8.01.26TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00004Y7E8.01.MZZZZZZZ.jpg' , NULL , NULL , 189 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 139.99 , 26 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (102 , 'Panasonic PV-DV401 Digital Camcorder with Built-in Digital Still Mode' , 1 , 1 , 2 , 'B00005A3LV' , NULL , 'The Panasonic PV-DV401 is the successor to last\r\n  year\'s popular PV-DV400 digital camcorder. In\r\n  addition to a bigger zoom lens--up to 20x--you also\r\n  get the ability to store still images on an MMC or\r\n  SD memory card.' , 0 , 'The Panasonic PV-DV401 is a no-frills camcorder that\'s ideal for anyone\r\n                     who wants a digital camcorder but doesn\'t need a lot of extras. While\r\n                     perfectly adequate for general use, the camera didn\'t overwhelm us with\r\n                     good design and fantastic footage. The PV-DV401 is great for a family, but\r\n                     not the camera of choice for digital-video hobbyists.\r\n\r\n                     Digital camcorders generally do very well in brightly lit environments, and the\r\n                     PV-DV401 was no exception. Low-light shooting wasn\'t too bad either; the\r\n                     picture was decent without being too grainy--a flaw of many digital\r\n                     camcorders. The lack of manual exposure control left much to be desired; in\r\n                     certain environments the auto exposure struggled between letting in too much\r\n                     light and letting in too little light. For nighttime shooting there is a nifty\r\n                     infrared mode where you shoot visible video in practically no light at all.\r\n                     Video playback was standard fare; however, at this price range it would be\r\n                     nice to include a remote control as a standard accessory. The large 3-inch\r\n                     LCD viewscreen is a big plus; it was very comfortable to look at during both\r\n                     recording and playback.\r\n\r\n                     The overall design of this camcorder seems uninspired. With so many\r\n                     manual functions, digital effects, and settings, Panasonic could have done\r\n                     much better by bringing them out as buttons on the camera rather than\r\n                     tucking them away in hard-to-navigate onscreen menus. The jog wheel at the\r\n                     top of the camera performs many different camera functions, but it began to\r\n                     get tedious to use because of its odd placement and design. We\r\n                     inadvertently pressed the nearby photo button several times while trying to\r\n                     access the jog wheel.\r\n\r\n                     Digital camcorders have been getting progressively better and cheaper the\r\n                     last few years. The PV-DV401 follows that trend, but has nothing to\r\n                     differentiate it from a crowded field. Simply put, it\'s just an average camera.\r\n                     --Bao Tran' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005A3LV.01.30TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005A3LV.01.MZZZZZZZ.jpg' , NULL , NULL , 699.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 699.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (103 , 'NEC AccuSync 50M 15" Multimedia Monitor (PC/Mac)' , 1 , 1 , 2 , 'B00004Y74D' , NULL , 'The NEC AccuSync 50M 15-inch monitor is specifically designed for small to medium businesses and home users who demand quality performance and a range of usage. This full-featured 15-inch (13.8-inch viewable) display is ideal for office automation including word processing, spreadsheets, and data entry. \r\n\r\nThe NEC AccuSync 50M\'s 1,280 x 1,024 maximum resolution at 66 Hz refresh rate, combined with its fine 0.28-millimeter dot pitch, ensure sharp, crisp images. For enhanced screen sharpness... \r\n' , 0 , 'The NEC AccuSync 50M 15-inch monitor is specifically designed for small to medium businesses and home users who demand quality performance and a range of usage. This full-featured 15-inch (13.8-inch viewable) display is ideal for office automation including word processing, spreadsheets, and data entry. \r\n\r\nThe NEC AccuSync 50M\'s 1,280 x 1,024 maximum resolution at 66 Hz refresh rate, combined with its fine 0.28-millimeter dot pitch, ensure sharp, crisp images. For enhanced screen sharpness and color intensity, the antistatic, antiglare screen treatment greatly reduces reflection while providing full use of the entire display area. The AccuSync 50M also includes two 2.2-inch full-range speakers in the base for multimedia applications. The audio base has a headphone jack for private listening. Additional value-added features include up-front controls, an invar shadow mask, and a multilayer screen coating with OptiClear viewing. The monitor is in compliance with EPA Energy Star and MPR-II regulations. It is backed by a three-year limited warranty. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004Y74D.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00004Y74D.01.MZZZZZZZ.jpg' , NULL , NULL , 179.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 169.99 , 6 , NULL , NULL , NULL , 1 , '' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (104 , 'Nokia 3360 Phone (AT&T)' , 1 , 1 , 2 , 'B00005QIQI' , NULL , 'For a limited time, get a $50 rebate\r\n                                                from AT&T when you purchase a\r\n                                                Nokia 3360 phone and activate\r\n                                                monthly service. Then, save an\r\n                                                additional $50 with our Amazon.com\r\n                                                gift certificate, which makes your\r\n                                                phone free! Is that a bargain, or\r\n                                                what?' , 0 , 'Fun, form, and function are what the Nokia 3360 is all about. Highlights include\r\n                   an oversized five-line screen, e-mail capability, PIM functions, text-messaging\r\n                   support, and a couple games. Snap-on faceplates let you customize the 3360 to\r\n                   your heart\'s content, and you can further personalize it with downloadable\r\n                   ringers. The NiMH battery is rated for up to 240 minutes of digital talk time and\r\n                   10.5 days of digital standby time. A charger and hands-free headset are\r\n                   included.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QIQI.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005QIQI.01.MZZZZZZZ.jpg' , NULL , NULL , 38.94 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 38.94 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (105 , 'Motorola T193 Phone (VoiceStream Wireless)' , 1 , 1 , 2 , '253275' , NULL , 'Grab the Motorola T193 for free\r\n             when you sign up for a\r\n             VoiceStream Wireless service\r\n             plan costing $29.99 or more!' , 0 , 'The Motorola T193 phone from VoiceStream Wireless is an attractive phone designed for high-speed\r\n Internet access. The phone is built on GPRS technology, a system which uses the wireless network\r\n only when you send and receive data, resulting in transmission speeds more than two times faster\r\n than...' , 0 , NULL , NULL , 'http://g-images.amazon.com/images/G/01/wireless/features/motorola-t193-f.gif' , 'http://images.amazon.com/images/P/B00005S022.01.TZZZZZZZ.jpg' , NULL , NULL , 99.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (106 , 'Nokia 5165 Prepaid Phone (AT&T)' , 1 , 1 , 2 , 'B00005BAUV' , NULL , 'Looking to buy a cell phone without\r\n       breaking the piggy bank? Choose a\r\n       Nokia 5165 phone with AT&T\'s Free2Go\r\n       prepaid service, and score a $50 rebate\r\n       from AT&T Wireless.' , 0 , 'This Nokia 5165 model, which works with AT&T\'s Wireless\'s prepaid service,\r\n                   has quickly caught on in popularity. Like its predecessor, the 5160i, the 5165 is\r\n                   a lightweight personal phone with impressive talk and standby times that\'s loaded\r\n                   with classic, simple-to-learn features. Its changeable faceplates, 30 different\r\n                   ringers (and room for five downloadable tones), and an expansive world of\r\n                   accessories add up to a fun general-purpose phone that\'s a perfect fit for\r\n                   prepaid use. And handy refill cards allow you to purchase additional airtime\r\n                   minutes whenever you need them. \r\n\r\n                   Weighing in at 6.2 ounces (including battery), the 5165 measures 5.2 inches\r\n                   high, 1.85 inches wide, and 1.2 inches deep. It\'s extremely rugged, and should\r\n                   stand up well to being thrown into bags and briefcases or occasionally dropped.\r\n                   And, its dual-band/trimode operation ensures you\'ll be able to receive cellular\r\n                   service anywhere it\'s available. The addition of predictive T9 text input, wireless\r\n                   business cards, and e-mail capabilities make it a viable business\r\n                   communications tool as well. \r\n\r\n                   Four buttons handle most menu navigation: a hefty "Navi" key in the middle, up\r\n                   and down arrow buttons that control volume during calls, and a key marked "C"\r\n                   for "clear". Menu navigation is very intuitive. A tap of the Navi key brings up the\r\n                   first of a series of graphical menu items. Hit Navi again for additional menu\r\n                   options, or tap the up or down arrow keys to select a different menu. Top-level\r\n                   menu choices are a phone book, messages (SMS and voice-mail alerts), call\r\n                   log, settings (for calls, phone, and security), system, games (Memory, Snake,\r\n                   and Logic), clock, tones, and keypad lock. The brightly backlit display works well\r\n                   with the control keys to simplify finding and making choices. In text mode, the\r\n                   phone provides five 16-character lines. \r\n\r\n                   The 5165 lets you choose from 30 preprogrammed ringer tones, and you can\r\n                   also download an additional five from AT&T Wireless\'s Web site. Although\r\n                   there\'s no internal vibration mode, an optional vibrating battery is available. You\r\n                   can store electronic business cards in your phone book. Any friend or\r\n                   associate can forward his or her name, number, and e-mail address to your\r\n                   phone, and you can automatically store the information with some deft menu\r\n                   navigation. \r\n\r\n                   One caveat regarding faceplates: In theory, all 5100-series faceplates should\r\n                   work with this phone, but in practice, only Nokia-brand faceplates seem to work.\r\n                   The problem is the keypad, the thin rubber pad inside the phone on which the\r\n                   actual keys are mounted. We tried several different faceplate models (both\r\n                   Nokia-branded and after-market models) and found the 5165\'s original keypad\r\n                   will not accommodate non-Nokia faceplates. \r\n\r\n                   The 5165 supports the usual array of call and messaging features, including\r\n                   caller ID, call waiting, call forwarding, and voice-mail. A call history stores the\r\n                   last 10 numbers dialed, the 10 most recently received calls, and the last 10\r\n                   missed calls. The phone supports two-way SMS text messaging, but isn\'t\r\n                   Web-enabled. \r\n\r\n                   The 5165 offers four basic security features: an initial security code, a keypad\r\n                   lock, call-restriction modes, and a lock code that can activate or deactivate\r\n                   memory and menu options. The lock-code feature lets you store numbers in a\r\n                   secret unlocked location, allowing you to make calls even if the phone is locked. \r\n\r\n                   The 5165\'s NiMH battery is rated to last up to 180 minutes of digital talk time and\r\n                   200 hours of digital standby time. In our testing, we achieved 180 minutes of\r\n                   digital talk time and over 225 hours of digital standby time. \r\n\r\n                   Overall, Nokia\'s 5165 is a noteworthy and reasonably priced prepaid phone.\r\n                   Choose your favorite faceplate color and ringer tone and start dialing!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BAUV.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005BAUV.01.MZZZZZZZ.jpg' , NULL , NULL , 99.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (107 , 'Nokia 8290 Phone (VoiceStream Wireless)' , 1 , 1 , 2 , 'B000050ZFG' , NULL , 'Did you know the Nokia 8290 is smaller and\r\n                                        lighter than its sister phone, the Nokia 8260? It\r\n                                        also boasts voice-activated dialing, excellent talk\r\n                                        and standby times, and text messaging support.\r\n                                        Don\'t forget about our instant-savings offer,\r\n                                        which takes $50 off the price.' , 0 , 'With the introduction of its striking 8290 digital phone, Nokia sets a new\r\n                   standard for eye-catching style and extreme portability. \r\n\r\n                   We were impressed with the 8290\'s robust construction and overall navigation.\r\n                   The phone, which is for GSM networks (like VoiceStream Wireless), also boasts\r\n                   a newly designed internal antenna, excellent talk and standby times, and a host\r\n                   of sophisticated functions including voice-activated dialing and SMS capabilities.\r\n                   The only real missing feature is Web-browsing support. \r\n\r\n                   Where did this tiny phone come from? Essentially, Nokia updated the\r\n                   electronics and boosted the antenna power of its high-end classic, the 8860; put\r\n                   the new design in a sleek, tiny package; and significantly lowered the price. The\r\n                   8290 also borrows the navigation that is a hallmark of its popular 5100-series\r\n                   phones. \r\n\r\n                   Although many of the 8290\'s features are available in other premium phone\r\n                   models, its design is like nothing you\'ve ever held. Weighing a mere 3.2 ounces\r\n                   and measuring 3.9 by 1.7 by 0.7 inches, the 8290 literally fits in the palm of\r\n                   your hand. It\'s also slightly smaller than its sister phone, the popular 8260. \r\n\r\n                   The side-mounted volume-control keys were easy to operate while on a call, and\r\n                   we hooked up a hands-free kit to the headphone jack so we could stow the\r\n                   phone in our pocket while having conversations. One caveat: the tiny power\r\n                   button, located on top of the phone, is almost flush with the casing and hard to\r\n                   find. You won\'t be likely to turn the phone on inadvertently, but at times it was a\r\n                   challenge to turn the phone on at all. Other than this quibble, the 8290 is a joy to\r\n                   use. Plus, the 8290 is shipped with a Jabra EarSet for hands-free use. \r\n\r\n                   Three buttons handle most of the menu navigation: a roller-bar navigation key\r\n                   lets you scroll through menu options, and two additional buttons let you select\r\n                   menu options as they appear. The right prompt button also provides one-touch\r\n                   access to your phone book. The top-level menu choices are: Messages (SMS\r\n                   and voice-mail alerts), Call Log, Profiles (so you can choose how your phone\r\n                   behaves in different environments), Settings (for calls, phone, and security),\r\n                   System (so you can select a service provider or opt for automatic selection),\r\n                   Games (Rotation, Memory, Snake, and Logic), Calculator, Calendar, and\r\n                   Keyguard Lock. The backlit, three-line display works well with the control keys,\r\n                   and we found it easy to locate menus and make selections. Despite the phone\'s\r\n                   small size, the keypad is well spaced, and we had no problems dialing with one\r\n                   hand. \r\n\r\n                   The Nokia 8290 has a full roster of call and messaging features. If offered by\r\n                   your service plan, it supports caller ID, call waiting, SMS, voice mail, numeric\r\n                   paging, multiparty calling, and e-mail. Three different call logs maintain the last\r\n                   10 dialed numbers, 10 most recently received calls, and 10 missed calls. PIM\r\n                   functions include a clock, currency converter, calculator, calendar with room for\r\n                   50 appointments and reminders, and a 250-entry phone book. There is no\r\n                   standard method of connecting the 8290 to a PC or other device. \r\n\r\n                   A few more cool things worth noting: the 8290 supports swappable faceplates\r\n                   and it has three-NAM capability, so you can route three different numbers to the\r\n                   phone. Its built-in vibrating alert guarantees you will get your calls without\r\n                   annoying the people sitting next to you. \r\n\r\n                   The 8290 offers four basic security features: An initial security code, keypad\r\n                   lock, call restriction modes, and a lock code that can activate or deactivate\r\n                   memory and menu options. One nice thing about the lock-code feature is you\r\n                   can store numbers in a secret unlocked location, which will allow you to make\r\n                   calls even when the phone is locked. \r\n\r\n                   The 8290\'s lithium-ion battery is rated to last for a maximum of 210 minutes of\r\n                   digital talk time and 192 hours of digital standby time. In our battery testing it\r\n                   came impressively close. We held an open call for just over three hours, and the\r\n                   phone lasted for nearly eight days in standby mode. \r\n\r\n                   The 8290 is one of the lightest, smallest, most stylish phones around, and it\r\n                   backs up its cool appearance with solid construction and functions. In fact, it\r\n                   one-ups its counterpart, the 8260, with its more compact design and\r\n                   voice-activated dialing feature. Unless you need a phone with a minibrowser,\r\n                   this unit is an excellent match for almost any personal or professional\r\n                   communications need.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050ZFG.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B000050ZFG.01.MZZZZZZZ.jpg' , NULL , NULL , 99.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (108 , 'Nokia 3390 Prepaid Phone with AOL (VoiceStream Wireless)' , 1 , 1 , 2 , 'B00005UL4Y' , NULL , 'VoiceStream Wireless has an amazing offer--a\r\n  prepaid Nokia 3390 outfitted with AOL Instant\r\n  Messenger and a bunch of other cool features.\r\n  You can call your friends, or opt to send them a\r\n  quick note while you\'re on the run. Airtime worth\r\n  $50 is included with purchase.' , 0 , 'This Nokia 3390 is a fun, shapely prepaid phone with several cool features,\r\n                   including picture messaging, changeable faceplates (front and back), and\r\n                   voice-activated dialing. \r\n\r\n                   Here\'s the tale of the tape: the 3390 measures 4.4 by 1.9 by 0.8 inches, and it\r\n                   weighs 4 ounces. This means the phone is slightly longer than a business card\r\n                   and weighs the same as today\'s ultracompact phones. It also has an internal\r\n                   antenna--which people either love or hate--though we never had trouble with call\r\n                   reception. To us, everything about this phone is executed correctly; the keypad\r\n                   is well-spaced, it has salient features (even though it can\'t access the Internet\r\n                   wirelessly), and it\'s inconspicuous while in use. \r\n\r\n                   Three buttons handle most of the menu navigation: a central oval-shaped key\r\n                   activates the main menu and lets you select options as they appear; the\r\n                   roller-bar navigation key scrolls through menu options; and the "C" (clear) button\r\n                   jumps back a step and erases text-entry mistakes. \r\n\r\n                   Menu choices are: Phone Book, Messages (SMS and voice-mail alerts), Call\r\n                   Log, Profiles (so you can choose how your phone behaves in different\r\n                   environments), Settings (for calls, phone, and security), Forwarding, Games,\r\n                   Calculator, Calendar, Composer (for DIY ring tones), and Keyguard Lock. With\r\n                   the backlit, five-line display (three lines of text, two lines of icons and indicators),\r\n                   we found it easy to navigate through menus and make selections. And here\'s a\r\n                   definite design improvement on the 8260: the 3390\'s power button, located on\r\n                   top of the phone, is raised a bit so it\'s easier to use (and find). \r\n\r\n                   Like other phones, the 3390 has a full roster of call and messaging features. If\r\n                   offered by your service plan, it supports caller ID, call waiting, SMS, voice mail,\r\n                   numeric paging, multiparty calling, and e-mail. Call logs maintain the last 10\r\n                   dialed numbers, 10 most recently received calls, and 10 missed calls. PIM\r\n                   functions include a clock, currency converter, calculator, calendar with room for\r\n                   50 appointments and reminders, and a 250-entry phonebook. \r\n\r\n                   But, as we said, the 3390 offers a couple of new features (at least for Nokia\r\n                   phones). We stored eight different voice-activated dialing numbers (a simple\r\n                   process), and logged on to VoiceStream Wireless\'s site from our PC so we\r\n                   could download additional ring tones. The 3390 also has eight preset images\r\n                   you can e-mail to your friends--but in order to take advantage of it both people\r\n                   need to have a 3390 that supports picture messaging. You can also download\r\n                   additional images from VoiceStream Wireless\'s site, provided your service plan\r\n                   supports this action. \r\n\r\n                   The front and back faceplates are separate, so you can have a two-tone phone\r\n                   if you desire. It was a minor challenge to remove the faceplate on the first try,\r\n                   but it was worth the effort. And while the phone\'s included games weren\'t enough\r\n                   to take us away from PlayStation 2, we enjoyed Space Impact (sort of\r\n                   Defender meets Space Invaders), one of the 3390\'s four new games. It also\r\n                   features Snake II, Bantumi, and Pairs I. \r\n\r\n                   The 3390 offers five basic security features: an initial phone lock, keypad lock,\r\n                   SIM card lock, call-restriction modes, fixed dialing (allows you to store secret\r\n                   numbers on the SIM card), and the ability to change access codes at any time. \r\n\r\n                   The NiMH battery is rated for up to 160 minutes of digital talk time and 7.5 days\r\n                   of digital standby time. In our tests, we got the phone to hold a call for just about\r\n                   three hours, and it lasted for a full seven days in standby mode. \r\n\r\n                   We highly recommend the 3390, and we don\'t want to give our sample phone\r\n                   back. It looks different from the rest of the herd and has the features we want\r\n                   and need on a daily basis--all for under $100.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UL4Y.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UL4Y.01.MZZZZZZZ.jpg' , NULL , NULL , 99.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (109 , 'Samsung N200 Phone (Sprint PCS)' , 1 , 1 , 2 , 'B00005K2LZ' , NULL , 'We\'re enamored with the new Samsung N-200,\r\n                                        and think it would suit just about anyone\'s needs.\r\n                                        It\'s highly stylized and outfitted with the right\r\n                                        features--including voice-activated dialing, an\r\n                                        organized minibrowser, and a 229-number\r\n                                        phone book.' , 0 , 'Communicate well into the 21st century with the Samsung N-200. This modern\r\n                   dual-mode marvel--an updated version of the bestselling SCH-3500 model--is\r\n                   equipped with a built-in mini-browser, PIM functions, and voice-activated dialing\r\n                   capabilities. The N-200 is smaller and lighter than its predecessor, and has a\r\n                   five-line display as well as a convenient minijoystick for menu navigation. Other\r\n                   standard features include a vibrating alert, multiple ringer options, and multiple\r\n                   language options.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005K2LZ.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005K2LZ.01.MZZZZZZZ.jpg' , NULL , NULL , 149.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 149.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 4 , 4 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (110 , 'Motorola V2397 Prepaid Phone (AT&T)' , 1 , 1 , 2 , 'B00005BAUT' , NULL , 'Our customers love the V2397, a prepaid phone\r\n  from AT&T Wireless. And with its swappable\r\n  phone-wrap covers, SMS capabilities, and\r\n  reasonable price tag, we can see why.' , 0 , 'Flexible prepaid service, swappable "phone wrap" fashion covers, two-way SMS\r\n                   capabilities, and a reasonable price are some of the highlights of the new\r\n                   Motorola V2397, a prepaid phone offered by AT&T Wireless. \r\n\r\n                   The V2397 measures 6.5 by 2.0 by 1.1 inches, and weighs in at 5.2 ounces.\r\n                   While relatively large, the phone is lightweight, easily portable, and it sports\r\n                   dual-band/dual-mode electronics. \r\n\r\n                   Motorola\'s characteristic smart-button navigation, commonly seen on the\r\n                   company\'s StarTAC phones, guides you through the V2397\'s menu options. The\r\n                   keypad design is less cluttered and confusing than StarTAC phones, however--a\r\n                   definite improvement. Although you still have to use the FCN (function) button to\r\n                   access menu options, all control keys (Function, Store, Clear, Recall) are well\r\n                   spaced. The raised, oval-shaped keypad buttons were quite responsive, and we\r\n                   rarely misdialed a call. The phone felt good to hold, and we could dial\r\n                   one-handed. The four-line screen (two lines of text, two lines of status icons) is\r\n                   backlit and easy to read. A standard 2.5-millimeter communication jack for\r\n                   hands-free devices is integrated into the phone. \r\n\r\n                   The V2397\'s handy call management features, including scratchpad memory,\r\n                   nine assignable ringer tones, one-touch speed-dial locations, multiple call timers,\r\n                   and any-key answer, help you organize your communications. You can store up\r\n                   to 99 numbers in the V2397\'s phone book, although it does not support multiple\r\n                   entries per contact. Entering phone numbers is easy. Just punch in the number\r\n                   and a unique descriptor, and assign it a memory location. The 30-incoming and\r\n                   20-outgoing call logs help you keep track of your conversations, and the\r\n                   incoming call log keeps track of missed calls to boot. The V2397 supports\r\n                   carrier-dependent features such as caller ID, call waiting, voice-mail alerts, and\r\n                   two-way SMS text messaging, which lets you send and receive alphanumeric\r\n                   messages with other devices. Unfortunately, there is no way to tether the V2397\r\n                   to a PC, so you can\'t use it as a digital modem, or import your computer\'s\r\n                   address book to the phone. Also, the V2397 is missing a minibrowser, PIM\r\n                   funtions, profile settings, and vibrating alert. \r\n\r\n                   To keep your V2397 secure, you can use a three-digit code to lock the whole\r\n                   phone or to restrict outgoing calls to one of 10 numbers stored in special\r\n                   memory locations. \r\n\r\n                   The V2397\'s NiMH battery is rated up to 100 minutes\' talk time and 110 hours\'\r\n                   standby time. In our testing, the V2397 held a call for 105 minutes, and it lasted\r\n                   for 112 hours in standby mode. \r\n\r\n                   A basic phone for everyday use, the Motorola V2397 scores high marks in\r\n                   visual design and reliability, although it lacks many desirable features. Still,\r\n                   interchangeable phone wraps, two-way text messaging, and a very reasonable\r\n                   price make the V2397 as a viable prepaid option.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BAUT.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005BAUT.01.MZZZZZZZ.jpg' , NULL , NULL , 99.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , 1 , '' , 1 , 3 , 3 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (111 , 'Churches' , 1 , 1 , 2 , '0060194383' , NULL , NULL , 0 , 'The physical dimensions alone would be enough to make Churches, Judith Dupre\'s sumptuous chronology of Christian art and architecture, one of the most  absorbing ways possible to learn about the world\'s most beautiful houses of worship. It is almost too big to fit in your lap, and each brilliantly colored page is  almost three times the width of a human head. In addition, Churches offers floor  plans, histories, and theological interpretations of almost 60 churches around the  world, from the Pantheon in Rome to La Sagrada Familia in Barcelona to the  Crystal Cathedral in Garden Grove, California. Interspersed with these chapters  are photographic essays on such topics as "Building a Gothic Cathedral" and  "Ancient Paths: Contemporary Labyrinths." All of the images and essays are  presented in a format accessible to the general reader. Those more broadly  informed about architecture will be drawn to the interview with Swiss-Italian  architect Mario Botta--his first in-depth interview published in English. In the end,  the book\'s most amazing accomplishment is to provide readers with sensations  that approximate both the grandeur and the intimacy of visiting the churches it  depicts. --Michael Joseph Gross' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060194383.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0060194383.01.MZZZZZZZ.jpg' , NULL , NULL , 40 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 28 , 30 , 0 , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (112 , 'Celebrate Your Creative Self : Over 25 Exercises to Unleash the Artist Within' , 1 , 1 , 2 , '1581801025' , NULL , NULL , 0 , 'Book Description \r\nArtists and creatives of all kinds who are looking for new ways to liberate their artistic imagination will love this book. Readers are invited to playfully explore various aspects of visual art, such as light, color, texture and design through a series of imaginative art projects. Artists will experiment hands-on with dozens of techniques and mediums in new and unconventional ways including: * Capturing whites with crayon and wax resist * Glazing and floating colors * Portraying the patterns of nature with sedimentation and precipitation * Loosening up with gesso painting and printing with plastic * Constructing a new piece of art from old work * Experimenting with three-dimensional assemblage * Creating a street map In addition, artists are prompted to challenge their imaginations by building new painting surfaces, creating their own personal symbols and more. Further inspiration can be found in a gallery of work by more than 30 contributing artists. Celebrate Your Creative Self is a fun, no-fail guide every artist should have. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1581801025.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/1581801025.01.LZZZZZZZ.jpg' , NULL , NULL , 28.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.26 , 37 , 0 , NULL , NULL , 1 , '' , 1 , 5 , 5 ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (113 , 'Exploring Southern California Beaches (FalconGuide)' , 1 , 1 , 2 , '1560446323' , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , 18.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/1560446323' , 2 , 10 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (114 , 'The Lord of the Rings (Collector\'s Edition)' , 1 , 1 , 2 , '0395193958' , NULL , NULL , 0 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0395193958.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0395193958.01.MZZZZZZZ.jpg' , NULL , NULL , 75 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 52.5 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0395193958' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (115 , 'Dark Journey (Star Wars: The New Jedi Order, Book 10)' , 2 , 1 , 2 , '0345428692' , NULL , NULL , 0 , 'About the Author \r\nA former music and history teacher, Elaine Cunningham has written more than a dozen fantasy novels and many short stories. She is best known for the Songs & Swords books, particularly Elfshadow, a mystery in a fantasy setting. She lives with her family in a coastal New England town.\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345428692.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0345428692.01.MZZZZZZZ.jpg' , NULL , NULL , 6.99 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 0 , 6.99 , NULL , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0345428692' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (116 , 'The Silmarillion' , 3 , 1 , 2 , '0345325818' , NULL , NULL , 0 , 'The Silmarillion is J.R.R. Tolkien\'s tragic, operatic history of the First Age of Middle-Earth, essential background material for serious readers of the classic Lord of the Rings saga. Tolkien\'s work sets the standard for fantasy, and this audio version of the "Bible of Middle-Earth" does The Silmarillion justice. Martin Shaw\'s reading is grave and resonant, conveying all the powerful events and emotions that shaped elven and human history long before Bilbo, Frodo, Gandalf and all the rest embarked on their quests. Beginning with the Music of the Ainur, The Silmarillion tells a tale of the Elder Days, when Elves and Men became estranged by the Dark Lord Morgoth\'s lust for the Silmarils, pure and powerful magic jewels. Even the love between a human warrior and the daughter of the Elven king cannot defeat Morgoth, but the War of Wrath finally brings down the Dark Lord. Peace reigns until the evil Sauron recovers the Rings of Power and sets the stage for the events told in the Lord of the Rings. This is epic fantasy at its finest, thrillingly read and gloriously unabridged. (Running time: 14 hours, 6 CDs) --This text refers to the Audio CD edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345325818.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0345325818.01.MZZZZZZZ.jpg' , NULL , NULL , 6.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 0 , NULL , NULL , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0345325818' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (117 , 'The Lord of the Rings (Boxed Set)' , 4 , 1 , 2 , '0395489326' , NULL , NULL , 0 , 'The three volumes that make up Tolkien\'s epic classic The Lord of the Rings are here presented in their standard cloth editions including large format fold-out maps and an extensive appendices. Set contains The Fellowship of the Ring, The Two Towers, and The Return of the King, with jackets and a box designed by celebrated illustrator Alan Lee. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0395489326.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0395489326.01.MZZZZZZZ.jpg' , NULL , NULL , 65 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 45.5 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0395489326' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (118 , 'Under Cover The Key To Living In God\'s Provision And Protection' , 1 , 1 , 2 , '0785269916' , NULL , NULL , 0 , NULL , 0 , 'This well loved writer effectively uses his personal mistakes to illustrate riveting truths about repentance and forgiveness. As he focuses on the true authority of God, he is careful to explain by example the important difference between submission and obedience. \r\nThe same struggle with divine authority is also represented through the lives of John the Baptist, the Apostle Paul, and other biblical figures. An especially helpful book for Christians who want to develop a serious pursuit of God. \r\n\r\n' , NULL , 'http://images.amazon.com/images/P/0785269916.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0785269916.01.MZZZZZZZ.jpg' , NULL , NULL , 14.99 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.99 , 20 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0785269916' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (119 , 'The Church of Irresistible Influence' , 2 , 1 , 2 , '0310239567' , NULL , NULL , 0 , 'An inspiring description and story showing how a church can become an irresistible influence on its neighborhood, community, and world by building bridges over troubled waters to a dying culture through showing the love of God in action. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0310239567.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0310239567.01.MZZZZZZZ.jpg' , NULL , NULL , 19.99 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 13.99 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0310239567' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (120 , 'God : A Biography' , 3 , 1 , 2 , '0679743685' , NULL , NULL , 0 , 'Is it possible to approach God not as an object of religious reverence, but as the protagonist of the world\'s greatest book -- as a character who possesses all the depths, contradictions, and ambiguities of a Hamlet? How does he depend on the other characters, and how does his relationship with them show his development? Miles provides a learned, original exegesis that will send readers back to the Bible in curious amazement. Winner of the 1996 Pulitzer Prize for biography. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0679743685.01.TZZZZZZZ.gif' , 'http://images.amazon.com/images/P/0679743685.01.MZZZZZZZ.gif' , NULL , NULL , 15 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12 , 20 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0679743685' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (121 , 'The Pleasures of God : Meditations on God\'s Delight in Being God' , 4 , 1 , 2 , '1576736652' , NULL , NULL , 0 , 'Beginning where the foundational truth of Desiring God left off, that "God is most glorified in us when we are most satisfied in Him," this expanded rerelease of another classic by John Piper will further explore a life-changing essential "We will be most satisfied in God when we know why God himself is most satisfied in God." Fully understanding the joy of God will draw the reader into an encounter with His overflowing, self-replenishing, all-encompassing grace(the source of living water that all Christians desire to drink.) The Pleasures of God will again put God at the center of Creation and leave the reader very satisfied in Him. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1576736652.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/1576736652.01.MZZZZZZZ.jpg' , NULL , NULL , 14.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.99 , 20 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/1576736652' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (122 , 'The Millionaires' , 1 , 1 , 2 , '0446527297' , NULL , NULL , 0 , 'What would you steal if you couldn\'t get caught? That\'s the tag line of Brad Meltzer\'s new thriller, which pits an ambitious young money manager against a corporate villain, whose intricate financial shenanigans accidentally put a huge chunk of dough right in front of a man who desperately needs it. Of course Oliver Caruso\'s conscience troubles him, but that doesn\'t keep him from letting his somewhat looser and less ethical brother convince him this is too good an opportunity to pass up. Meltzer\'s in interesting territory here, but in order to buy his premise, you have to believe that it\'s OK to steal if you have a good enough reason. This makes his protagonist, who narrates the novel, hard to root for and less than sympathetic. Despite this hollow ring, the book is nicely plotted and should please the author\'s enthusiastic fan club. --Jane Adams ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0446527297.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0446527297.01.MZZZZZZZ.jpg' , NULL , NULL , 25.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.57 , 40 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0446527297' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (123 , 'Blackwater Sound' , 2 , 1 , 2 , '0312203845' , NULL , NULL , 0 , NULL , 0 , 'A powerful Florida family, its high-tech fortune dwindling, is haunted by an elusive, enormous blue marlin that claimed the life of its eldest son, who was meant to restore the family\'s prominence. But the Braswells are tormented by even darker secrets, such as incest and treason, that drive this dark, atmospheric thriller to an explosive conclusion, which might have been pulled straight from recent headlines. James Hall pits Thorn, his series protagonist, against the Braswells and their deadly plans. Although an existentially morose antihero is a convention of the mystery genre, Hall manages to transcend it with a fascinating plot and a powerful narrative, resulting in a suspenseful and resonant novel that shows off his well-developed talents for character development, place, and pacing. The author of 11 previous mysteries (including Mean High Tide and Rough Draft), Hall gets better with every book, and this one continues the trend. --Jane Adams ' , NULL , 'http://images.amazon.com/images/P/0312203845.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0312203845.01.MZZZZZZZ.jpg' , NULL , NULL , 24.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0312203845' , NULL , NULL , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (124 , 'To Trust a Stranger' , 3 , 1 , 2 , '0671786539' , NULL , NULL , 0 , 'The usual ingredients bubble and boil in Robards\'s latest romantic suspense thriller. Julie Carlson, once a poor girl from the wrong side of the tracks but now the beautiful owner of a successful boutique in Charleston, S.C., seems to have it all. As the novel begins, however, a hit man circles her suburban mansion: Julie\'s rich husband, Sid, has hired thugs to kill her. Unaware of the danger she is in but convinced that Sid is cheating on her, Julie slips out of the house just in time and follows her husband to the red-light district, where she serendipitously and literally runs into private detective Mac McQuarry, dressed up in drag to spy on a client\'s husband. Julie isn\'t sure whether she should trust a man in a dress, but she has no one else to turn to, and soon she and Mac are working together to get the goods on Julie\'s crooked husband. As it happens, Mac holds a personal grudge against Sid, a prominent builder in Charleston, because Sid was involved in the disappearance of Mac\'s half-brother 15 years before, and then got Mac kicked off the police force when Mac tried to prove it. Robards\'s fans will enjoy the machinations before Julie and Mac get together, though cliches clutter every page ("The truth hit him like a hammer over the head: He had a galloping case of the hots for his newest client, who was not incidentally his oldest enemy\'s wife"). Of course, true love solves past mysteries, while hot kisses get as much play as life-threatening confrontations. A bodice ripper at heart, the novel is the equivalent of a box of junk candy. \r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0671786539.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0671786539.01.MZZZZZZZ.jpg' , NULL , NULL , 25 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.5 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0671786539' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (125 , 'Hearse of a Different Color' , 4 , 1 , 2 , '0786889632' , NULL , NULL , 0 , 'Tim Cockey\'s debut novel, The Hearse You Came In On, introduced readers to Hitchcock Sewell, the undertaker-turned-reluctant-sleuth, whose mordant irony and blissfully skewed perspective on the humdrum brought a remarkable vigor to a profession not usually known for its liveliness. The good news for Hitch fans is that Cockey\'s follow-up effort dishes up another heaping helping of sardonic wit: \r\nThe planet was one big marble of wretchedness. And I wasn\'t exactly being lifted aloft by bluebirds either. I was wheeling down the Baltimore- Washington Parkway in my unexciting car on the fourth record-breaking freezing cold day in a row, tuning in to what seemed to be the preexisting fact that I was going to be tracking down a cold-blooded murderer.\r\nSaid murderer has deposited a corpse on Hitch\'s doorstep--in the middle of a wake, no less. The unscheduled body is one Helen Waggoner, a single mother with a double life as a waitress and porn star. Hitch\'s girlfriend sees the unceremonious delivery as a scoop in the making. Bonnie Nash is a less-than- accurate TV weather woman who\'s got a bad case of occupational shame ("I\'m a pair of breasts that tells you what the weather is going to be tomorrow. Maybe."). She figures that solving a murder ought to earn her a network promotion. But it\'s not that easy. When Helen\'s sister also turns to Hitch for some moral and investigative support, the undertaker finds himself digging through the family closets and unearthing some distinctly unsavory skeletons. It turns out that a taste for the (ahem) silver screen is a Waggoner tradition, and that the sisters have a long--and not particularly affectionate--history. It\'s up to Hitch to put the pieces of the puzzle together before a hired killer with a peculiar signature takes him apart.\r\nCockey has a rare gift for sending up the hallowed conventions of mystery fiction with effortlessly wry turns of phrases: "I looked about to assess the scene. I\'m six-three, so I have a decent vantage point for assessing." His plot skills have sharpened since his last outing, and the narrative moves along briskly to a conclusion both tidy and ironic. Appropriately enough, though, in this Hearse, the ride is even more fun than the destination. --Kelly Flynn --This text refers to the Paperback edition. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0786889632.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0786889632.01.MZZZZZZZ.jpg' , NULL , NULL , 7.99 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 0 , 7.99 , NULL , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0786889632' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (126 , 'Beaches' , 1 , 1 , 2 , '0811826503' , NULL , NULL , 0 , 'The authors of The Beach: The History of Paradise on Earth, the best-selling history of everyone\'s favorite place, are back with a breathtaking visual companion. From moody, craggy coastlines to serene swathes of turquoise water and white sand, Beaches is an astounding photographic survey of the ineffable allure of paradise on earth. This spectacular collection of images from renowned photographers, including Robert Misrach, Joel Meyerowitz, and Art Wolff, stirs the spirit, capturing the mutable beauty of sand, sea, and sky. Throughout, concise and poetic pieces of historic and scientific lore unveil little-known facts and curiosities. With an astonishing range of vision, Beaches evokes the idiosyncratic beauty of the world\'s most stunning coastlines. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0811826503.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0811826503.01.MZZZZZZZ.jpg' , NULL , NULL , 24.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0811826503' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (127 , 'Beaches of Maui County (A Kolowalu Book)' , 2 , 1 , 2 , '0824812468' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0824812468.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0824812468.01.MZZZZZZZ.jpg' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.96 , 20 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0824812468' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (128 , 'Exploring Southern California Beaches (FalconGuide)' , 3 , 1 , 2 , '1560446323' , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , 18.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/1560446323' , 2 , 10 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (129 , 'Manhattan Unfurled' , 1 , 1 , 2 , '0375504915' , NULL , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New... ' , 0 , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New Yorks shoreline profilefrom Queens, Brooklyn, the Bronx, and New Jersey (which he reached by motorcycle)  and make two continuous and continuously enchanting pen-and-ink drawing of Manhattans skyline. \r\n\r\nManhattan Unfurled is published in an elegant slipcase, and the drawings fold out, accordion-style, with the West on one side and the East on the other. An introduction by distinguished New Yorker architecture critic Paul Goldberger, who first wrote bout Matteos project in The New Yorkers Talk of the Town, will accompany the drawing in a separate pamphlet. This book is both a wonderful New York City memento, perfect for gift giving, and an entirely unique work of art.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0375504915.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0375504915.01.MZZZZZZZ.jpg' , NULL , NULL , 29.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 20.96 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0375504915' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (130 , 'The Artist\'s Way Morning Pages Journal : A Companion Volume to the Artist\'s Way' , 2 , 1 , 2 , '0874778867' , NULL , NULL , 0 , 'The idea behind Julia Cameron\'s The Artist\'s Way is that by writing three pages, longhand and stream-of consciousness, first thing in the morning, you can overcome the obstacles that stop you from becoming your most creative self. This works partly because it forces you to create something (even if it is just a long list of gripes) every single day. It doesn\'t take much time. You\'re not even supposed to think. But the act itself gets you past all that self-defeating fretting about why you think you aren\'t a creative person. Cameron sees her morning pages as "a form of meditation," as "spiritual windshield wipers."\r\nWhile Cameron touts the morning pages as a way of life, she suggests you start out doing them as part of a "twelve-week program to recover your creativity." If you would like to keep your first twelve weeks of morning pages together in one tidy place, The Artist\'s Way Morning Pages Journal is a fine tool for doing so. Each nearly blank page features an inspiring quotation from The Artist\'s Way: "Leap, and the net will appear," says one; "Creativity lies not in the done but in doing," reminds another. We should mention that many of these little inspirations include references to God, which may be troublesome even for spiritual atheists. --Jane Steinberg \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0874778867.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0874778867.01.MZZZZZZZ.gif' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 11.96 , 20 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0874778867/' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (131 , 'Patience & Fortitude : A Roving Chronicle of Book People, Book Places, and Book Culture' , 3 , 1 , 2 , '0060196955' , NULL , NULL , 0 , 'A sequel of sorts to Basbanes\'s earlier A Gentle Madness (on the manic nature of bookselling and book-collecting), this copious volume takes its title from the formidable lions guarding the entrance to the main branch of the New York Public Library in Manhattan. Opening with the great libraries of the past, from Alexandria to Pergamum and Glastonbury, Basbanes, former literary editor of the Worcester Sunday Telegram, segues into such venerable active libraries as those at the Vatican, Wolfenbottel and the universities of Durham, Leiden and Oxford. He visits with shrewd, sometimes eccentric book dealers who happily recount tales of bygone bibliophiles, and illustrates a variety of collections, from illuminated medieval manuscripts to volumes more valuable for who owned them than for binding or content. "I absolutely insist on keeping the same crummy look," a bookshop owner tells him proudly. "Every time I make the place too neat, business goes down." But a pathos pervades the book, for despite the huge increase in readers and book buyers, one dealer observes "a radical dismantling of high culture well under way" since the 1930s. The collector in 1939 who bought a rare book about Native American languages "by selling bottles of his own blood" has no latter-day parallel. Basbanes closes with tales of crusty benefactors like Andrew Carnegie, and interviews with librarians faced with the dilemma of too many old books that no one now wants to read. Basbanes\'s fund of stories will delight readers who value books for more than just a good story, have a yen for second-hand books plucked from dusty shops or look to book catalogs for suspense and excitement. 32 pages of b&w photos not seen by PW. Agents, Glen Hartley and Lynn T. Chu. (Oct.)Forecast: This will undoubtedly garner much attention in the book pages, as did its predecessor, aided by a six-city author tour, a 15-city NPR campaign and print features.\r\n\r\nCopyright 2001 Cahners Business Information, Inc.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060196955.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/0060196955.01.MZZZZZZZ.jpg' , NULL , NULL , 35 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 24.5 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0060196955' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (132 , 'Extreme Beauty: The Body Transformed' , 4 , 1 , 2 , '0300091176' , NULL , NULL , 0 , 'From Publishers Weekly \r\nHigh-heeled shoes, push-up bras, Elizabethan ruffs and Japanese platform clogs are just a few examples of clothing that has pushed and pulled the human form into new shapes in the last few centuries. With color photos and illustrations, Extreme Beauty: The Body Transformed, which accompanies a Metropolitan Museum of Art exhibit of the same name, traces the role of fashion in manipulating the body to fit physical ideals. Harold Koda, curator of the Met\'s Costume Institute, focuses on extreme exaggerations of human form like the European 19th-century bustle, tiny corseted waists or the enormous-hipped dresses of the 18th-century French court, but also shows how today\'s designers quote and send up these iconic shapes. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0300091176.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0300091176.01.MZZZZZZZ.jpg' , NULL , NULL , 40 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 28 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0300091176' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (133 , 'Anthony Blunt: His Lives' , 5 , 1 , 2 , '0374105316' , NULL , NULL , 0 , 'From Publishers Weekly \r\nThis engaging and important biography examines the many masks of the infamous Anthony Blunt (1907-1983), the Cambridge art historian turned spy who worked simultaneously for British Intelligence and the Soviet Union during WWII. Why did he betray his country? Carter provides an exhaustive psychological study of Blunt\'s early life. His brutalizing public school (where he was unhappy and unpopular), Carter argues, "inadvertently fostered a questioning and subversive attitude and a profound distrust of authority." When the Depression hit England in the 1930s and the specter of fascism threatened Europe, communism became fashionable among left-leaning intellectuals like Blunt and his Cambridge friend Guy Burgess. Blunt\'s homosexuality, like Burgess\'s, also appears to have alienated him from the establishment. During WWII, Blunt was assigned to British intelligence, giving him easy access to military secrets, which he smuggled to the Soviets. After his Cambridge spy friends Burgess, Donald MacLean and Kim Philby defected to the Soviet Union after the war, British Intelligence began investigating Blunt. In 1964, he was granted immunity in exchange for his confession and full cooperation. British intelligence worked hard to keep "the Blunt affair" a secret. He wasn\'t publicly exposed until 1979, when Margaret Thatcher denounced him. The biggest challenge any Blunt biographer faces is Blunt himself, a man of almost legendary emotional detachment. Blunt revealed little about his personal life, yet Carter has managed to bring readers as close to this enigmatic man as humanly possible. Thoroughly researched and carefully crafted, this is sure to be the definitive biography. 16 pages of photos not seen by PW. (Jan.)Forecast: Blunt\'s story isn\'t quite the sensation here that it is in England; devotees of spy tales and contemporary British history will read this.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0374105316.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0374105316.01.MZZZZZZZ.jpg' , NULL , NULL , 30 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 21 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0374105316' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (134 , 'Awakening the Virgin' , 6 , 1 , 2 , '1555834566' , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1555834566.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , 'http://images.amazon.com/images/P/1555834566.01.MZZZZZZZ.jpg' , NULL , NULL , 13.95 , NULL , NULL , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.16 , 20 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/1555834566' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (135 , 'Churches' , 7 , 1 , 2 , '0060194383' , NULL , 'The physical dimensions alone would be enough to make Churches, Judith Dupre\'s sumptuous chronology of Christian art and architecture, one of the most absorbing ways possible to learn about the world\'s most beautiful houses of worship. It is almost too big to fit in your lap, and each brilliantly...' , 0 , 'The physical dimensions alone would be enough to make Churches, Judith Dupre\'s sumptuous chronology of Christian art and architecture, one of the most  absorbing ways possible to learn about the world\'s most beautiful houses of worship. It is almost too big to fit in your lap, and each brilliantly colored page is  almost three times the width of a human head. In addition, Churches offers floor  plans, histories, and theological interpretations of almost 60 churches around the  world, from the Pantheon in Rome to La Sagrada Familia in Barcelona to the  Crystal Cathedral in Garden Grove, California. Interspersed with these chapters  are photographic essays on such topics as "Building a Gothic Cathedral" and  "Ancient Paths: Contemporary Labyrinths." All of the images and essays are  presented in a format accessible to the general reader. Those more broadly  informed about architecture will be drawn to the interview with Swiss-Italian  architect Mario Botta--his first in-depth interview published in English. In the end,  the book\'s most amazing accomplishment is to provide readers with sensations  that approximate both the grandeur and the intimacy of visiting the churches it  depicts. --Michael Joseph Gross' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060194383.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/0060194383.01.MZZZZZZZ.jpg' , NULL , NULL , 40 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 28 , 30 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/0060194383/' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (136 , 'Celebrate Your Creative Self : Over 25 Exercises to Unleash the Artist Within' , 8 , 1 , 2 , '1581801025' , NULL , NULL , 0 , 'Book Description \r\nArtists and creatives of all kinds who are looking for new ways to liberate their artistic imagination will love this book. Readers are invited to playfully explore various aspects of visual art, such as light, color, texture and design through a series of imaginative art projects. Artists will experiment hands-on with dozens of techniques and mediums in new and unconventional ways including: * Capturing whites with crayon and wax resist * Glazing and floating colors * Portraying the patterns of nature with sedimentation and precipitation * Loosening up with gesso painting and printing with plastic * Constructing a new piece of art from old work * Experimenting with three-dimensional assemblage * Creating a street map In addition, artists are prompted to challenge their imaginations by building new painting surfaces, creating their own personal symbols and more. Further inspiration can be found in a gallery of work by more than 30 contributing artists. Celebrate Your Creative Self is a fun, no-fail guide every artist should have. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1581801025.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/1581801025.01.LZZZZZZZ.jpg' , NULL , NULL , 28.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.26 , 37 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/1581801025/' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (137 , 'Rock Star' , 1 , 1 , 2 , 'B00005TPMA' , NULL , 'Watch Mark Wahlberg and Jennifer Aniston live the highs and lows of a rock  & roll fantasy come true in Rock Star.  Black leather pants recommended.\r\n' , 0 , 'This movie is a must for your collection, especially if you\'re fan of BIG HAIR ROCK. I grew up with the type of music this film is based on. I thought Mark Wahlberg did an amazing job of capturing the essence of a Heavy Metal  frontman. He had the perfect swagger and look. Even if you aren\'t a huge fan of Metal, I\'m sure at one time you\'ve fantasized about being a rock star or some type of entertainer, right? I\'m sure you\'ll be able to relate to the story of a guy who sings for a tribute band of his heroes, eventually getting the call to front the ACTUAL band. Jennifer Aniston and the cast of real life rockers like guitarist Zakk Wylde and Third Eye Blind\'s Stephan Jenkins are all great too. Oh and by the way... the soundtrack CD is also excellent, with original music from the film\'s  band, Steel Dragon and classics from KISS, Bon Jovi and others. For a fun film  ride I enthusiastically recommend ROCK STAR! Enjoy!!!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.25TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005TPMA.01.MZZZZZZZ.jpg' , NULL , NULL , 19.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.95 , 25 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00005TPMA/' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (138 , 'The Curse of the Jade Scorpion (2001)' , 1 , 1 , 2 , 'B00003CY6A' , NULL , NULL , 0 , 'With The Curse of the Jade Scorpion, Woody Allen pays another visit to his idealized past, and his retro blend of humor and nostalgia will surely satisfy the filmmaker\'s most loyal fans. Like The Purple Rose of Cairo, Radio Days, and Sweet and Lowdown, The Curse of the Jade Scorpion is physically impeccable: its period-perfect costumes and sets capture 1940 New York with splendid authenticity and are further enhanced by the burnished glow of Zhao Fei\'s cinematography. And like those earlier films, Jade Scorpion mines comedic gold from its timeframe, molding it into a plot laced with expert zingers that could only spring from a rich awareness of comedic tradition. Add an appealing roster of costars (including Elizabeth Berkley and Charlize Theron) and you\'ve got vintage Woody that perks right along. The movie\'s also as trivial as it is engaging; hack off 30 minutes and it might have had the delirious precision of early Marx Brothers classics. Instead, Allen\'s goofy conceit--enemies falling in love by hypnotic suggestion--is stretched to absurdity when efficiency expert Betty Ann "Fitz" Fitzgerald (Helen Hunt) is hypnotically attracted to seasoned insurance investigator C.W. Briggs (Allen), despite their office enmity. Plus, a jewel-heist caper masterminded by the nightclub hypnotist\r\n(David Ogden Stiers) casts them both as suspects! Woody harvests a bumper crop of old-fashioned laughs from this predicament, and despite their conspicuous age difference and occasional awkward delivery, Hunt and Allen exchange volleys of dialogue like a seasoned comedy team. Dan Aykroyd is also good in a stodgy supporting role, but Jade Scorpion remains a mixed blessing--a welcomed throwback to comedy\'s yesteryear, from a master funnyman who\'s struggling to maintain relevance in the present. --Jeff Shannon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00003CY6A.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00003CY6A.01.MZZZZZZZ.jpg' , NULL , NULL , 32.99 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 26.49 , 20 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00003CY6A/' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (139 , 'Groundhog Day (Special Edition) (1993)' , 2 , 1 , 2 , 'B00005U8EM' , NULL , NULL , 0 , 'Bill Murray does warmth in his most consistently effective post-Stripes comedy,\r\n                  a romantic fantasy about a wacky weatherman forced to relive one strange day\r\n                  over and over again, until he gets it right. Snowed in during a road-trip expedition\r\n                  to watch the famous groundhog encounter his shadow, Murray falls into a time\r\n                  warp that is never explained but pays off so richly that it doesn\'t need to be. The\r\n                  elaborate loop-the-loop plot structure cooked up by screenwriter Danny Rubin is\r\n                  crystal-clear every step of the way, but it\'s Murray\'s world-class reactive timing\r\n                  that makes the jokes explode, and we end up looking forward to each new\r\n                  variation. He squeezes all the available juice out of every scene. Without forcing\r\n                  the issue, he makes us understand why this fly-away personality responds so\r\n                  intensely to the radiant sanity of the TV producer played by Andie MacDowell.\r\n                  The blissfully clueless Chris Elliott (Cabin Boy) is Murray\'s nudnik cameraman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005U8EM.01.MZZZZZZZ.jpg' , NULL , NULL , 24.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.71 , 25 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00005U8EM/' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (140 , 'Nothing in Common (1986)' , 3 , 1 , 2 , 'B00005UQ6M' , NULL , NULL , 0 , 'Interminably long, highly uneven comedy-drama about a perpetual adolescent\r\n                  who\'s forced to deal with his aging, unloving father when his mom leaves him flat.\r\n                  Some poignant, relevant conclusions about love and responsibility (and some\r\n                  funny shots at the advertising business) are undermined by overlength and\r\n                  meandering nature of film. Hanks is excellent; Gleason is abrasive (in his last film\r\n                  appearance). Later a TV series. Super 35.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UQ6M.01.TZZZZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005UQ6M.01.MZZZZZZZ.jpg' , NULL , NULL , 19.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.96 , 25 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00005UQ6M/' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (141 , 'Osmosis Jones (2001)' , 1 , 1 , 2 , 'B00005QAQH' , NULL , NULL , 0 , 'After the stiff attempts at realism in many recent features, it\'s a treat to see broad\r\n                  cartoon-style animation on the big screen in Osmosis Jones, a spoof of cop movies\r\n                  set inside the human body. The title character (voice by Chris Rock) is a\r\n                  street-smart white blood cell, working for Frank\'s immune system. He and Drix\r\n                  (David Hyde Pierce), an over-the-counter cold capsule, are reluctant partners\r\n                  fighting what appears to be a minor infection. Osmosis discovers Frank has really\r\n                  contracted a fatal virus, Thrax (Laurence Fishburne): he battles a corrupt body\r\n                  politic led by a venal mayor (William Shatner) to save Frank\'s life and win the\r\n                  affection of the mayor\'s aide, Leah (Brandy Norwood). Rock\'s motor-mouth\r\n                  delivery can get annoying, but it contrasts nicely with straight arrow Drix (imagine\r\n                  a fussy Buzz Lightyear). Excellent drawing and a powerful vocal performance make\r\n                  Thrax a genuinely frightening villain.\r\n\r\n                  Osmosis Jones is about two-thirds animation and one-third live action, which is\r\n                  why two-thirds of the film is entertaining and funny, and one-third is not. The life\r\n                  Osmosis and Drix save belongs to Frank, a slob played in live-action sequences by\r\n                  Bill Murray, who\'s undercut rather than supported by Chris Elliott and Molly\r\n                  Shannon. Shamelessly over-the-top performances make the human characters\r\n                  seem flatter than the two-dimensional cartoons. The live action was shot by the\r\n                  Farrelly brothers and features lots of gross-out gags about zits, flatulence, vomit,\r\n                  snot, etc. The audience endures these leaden segments, waiting to get back to the\r\n                  animation--and the real comedy. Suitable for ages 9 and up: profanity, violence,\r\n                  bodily function jokes. --Charles Solomon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QAQH.01.14TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005QAQH.01.MZZZZZZZ.jpg' , NULL , NULL , 24.98 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 21.49 , 14 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00005QAQH/' , 1 , 4 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (142 , 'The John Singleton Collection (Boyz N the Hood, Poetic Justice, Higher Learning)' , 2 , 1 , 2 , 'B00005JD5K' , NULL , NULL , 0 , 'Poetic Justice: BOYZ N THE HOOD writer-director Singleton suffers the\r\n                  sophomore jinx in this ambitious but fatally pretentious saga of a melancholy\r\n                  South Central L. A. beautician (Jackson), who has retreated from the world after\r\n                  her boyfriend\'s murder; mailman Shakur attempts to break through to her, with\r\n                  predictable results. Implausibly, the poetry this otherwise ordinary woman\r\n                  composes actually is the work of Maya Angelou (who appears onscreen as Aunt\r\n                  June). Jackson is OK in her screen debut.\r\n                  Higher Learning: Provocative drama of life at a big university where problems\r\n                  tend to break down along racial and sexual lines. Epps plays a young black\r\n                  athlete searching for direction and, sometimes blindly, raging at injustice.\r\n                  Fishburne is a political science professor who tries to help him see the world as\r\n                  it is. Credible, well-acted film goes awry when writer-director Singleton steers it\r\n                  toward melodrama, and foregoes student relations to focus on a group of\r\n                  extremist skinheads.\r\n                  Boyz N the Hood: Sober, thoughtful look at life in the black section of South\r\n                  Central L. A. A divorced father strives to raise his son with values--and steer him\r\n                  away from the ignorance and aimlessness that has led to an epidemic of\r\n                  senseless violence in the neighborhood. Impressive debut for 23-year-old\r\n                  writer-director Singleton; longish, and not always on-the-money, but overall quite\r\n                  potent and effective. Singleton has a bit part as a mailman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005JD5K.01.25TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005JD5K.01.MZZZZZZZ.jpg' , NULL , NULL , 44.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 33.71 , 25 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00005JD5K/' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (143 , 'Amazing Grace (1974)' , 3 , 1 , 2 , 'B00005R5W2' , NULL , NULL , 0 , 'A few laughs in Philadelphia-made comedy about an elderly busybody who disrupts corrupt Baltimore politics. Mabley\'s only starring film; cameos by Butterfly McQueen, unrecognizable Stepin Fetchit.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W2.01.10TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R5W2.01.MZZZZZZZ.jpg' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00005R5W2/' , 1 , 5 , NULL ) ;
INSERT INTO va_items (`item_id`,`item_name`,`item_order`,`item_type_id`,`manufacturer_id`,`manufacturer_code`,`features`,`short_description`,`full_desc_type`,`full_description`,`is_special_offer`,`special_offer`,`notes`,`small_image`,`big_image`,`specification`,`buying_price`,`price`,`weight`,`stock_level`,`use_stock_level`,`hide_out_of_stock`,`shipping_in_stock`,`shipping_out_stock`,`shipping_rule_id`,`shipping_cost`,`is_sales`,`sales_price`,`discount_percent`,`downloadable`,`download_period`,`download_path`,`is_showing`,`buy_link`,`votes`,`points`,`rating`) VALUES (144 , 'J.D.\'s Revenge (1976)' , 4 , 1 , 2 , 'B00005R5W1' , NULL , NULL , 0 , 'It\'s been branded with the "blaxploitation" label, but there is little that\'s exploitive in\r\n                  J.D.\'s Revenge, a film of well-drawn, articulate characters dragged into a\r\n                  supernatural showdown. Glynn Turman (Cooley High) is especially fine as the\r\n                  sensitive and quiet Ike, a determined student moonlighting as a cab driver, so\r\n                  wound up he\'s on the verge of cracking. Enter (literally) the ghost of J.D., a\r\n                  violent, vengeful gangster murdered in the opening moments. He could be Ike\'s\r\n                  own Mr. Hyde, a dapper, flamboyant ladykiller with a fiery temper and a straight\r\n                  razor who slowly smothers Ike\'s easygoing personality. Driven by flashes of\r\n                  memory, he sets his vengeful sights on fire-and-brimstone preacher Reverend\r\n                  Bliss (Louis Gossett Jr.), whose dark past is intricately tied up with J.D.\'s\r\n                  murder. Director Arthur Marks (Detroit 9000) sidesteps the usual spooky clich?s\r\n                  to stir up a modern New Orleans gumbo of ghost story, gangster tale, and\r\n                  character drama. J.D. is both devilish sadist and avenging angel, while the\r\n                  tortured Ike awakens from J.D.\'s violent rampages with a hole in his memory but\r\n                  a sick feeling from his imagined complicity in the crimes. The story gets wrapped\r\n                  up a little too neatly in the end, but the dark character shadings and the evocative\r\n                  mystery at the center of Ike\'s possession makes J.D.\'s Revenge an\r\n                  unexpectedly compelling supernatural thriller. --Sean Axmaker' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W1.01.10TRZZZZ.jpg' , 'http://images.amazon.com/images/P/B00005R5W1.01.MZZZZZZZ.jpg' , NULL , NULL , 14.95 , NULL , NULL , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , 0 , NULL , NULL , 1 , 'http://www.amazon.com/exec/obidos/ASIN/B00005R5W1/' , 1 , 4 , NULL ) ;


INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (4 , 0 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (4 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (5 , 0 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (5 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (6 , 0 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (6 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (7 , 5 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (8 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (9 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (10 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (11 , 8 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (12 , 8 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (13 , 1 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (13 , 8 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (16 , 9 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (17 , 9 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (18 , 9 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (19 , 9 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (22 , 10 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (24 , 10 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (25 , 10 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (27 , 10 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (28 , 11 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (29 , 11 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (30 , 11 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (31 , 12 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (32 , 11 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (33 , 12 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (34 , 12 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (35 , 14 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (36 , 12 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (37 , 14 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (38 , 14 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (39 , 15 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (40 , 14 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (41 , 15 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (42 , 15 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (43 , 16 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (44 , 16 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (45 , 16 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (46 , 16 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (47 , 19 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (48 , 18 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (49 , 19 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (50 , 22 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (51 , 25 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (52 , 25 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (53 , 25 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (54 , 26 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (56 , 4 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (57 , 26 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (58 , 26 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (59 , 4 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (60 , 27 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (61 , 4 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (62 , 27 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (63 , 4 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (64 , 27 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (65 , 4 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (66 , 28 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (67 , 28 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (68 , 28 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (69 , 30 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (70 , 29 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (71 , 30 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (72 , 29 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (73 , 30 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (74 , 29 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (75 , 29 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (76 , 29 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (77 , 34 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (78 , 36 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (79 , 34 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (80 , 36 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (81 , 34 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (82 , 36 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (83 , 37 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (84 , 37 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (85 , 37 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (86 , 37 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (87 , 37 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (88 , 37 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (89 , 37 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (90 , 38 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (91 , 38 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (92 , 41 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (93 , 38 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (94 , 41 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (95 , 39 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (96 , 41 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (97 , 41 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (98 , 41 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (99 , 39 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (100 , 39 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (101 , 41 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (102 , 39 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (103 , 41 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (104 , 44 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (105 , 44 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (106 , 44 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (107 , 44 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (108 , 44 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (109 , 44 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (110 , 44 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (111 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (112 , 2 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (113 , 48 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (114 , 49 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (115 , 49 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (116 , 49 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (117 , 49 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (118 , 50 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (119 , 50 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (120 , 50 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (121 , 50 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (122 , 51 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (123 , 51 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (124 , 51 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (125 , 51 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (126 , 52 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (127 , 52 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (128 , 52 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (129 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (130 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (131 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (132 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (133 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (134 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (135 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (136 , 53 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (137 , 54 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (138 , 55 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (139 , 55 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (140 , 55 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (141 , 56 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (142 , 56 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (143 , 56 ) ;
INSERT INTO va_items_categories (`item_id`,`category_id`) VALUES (144 , 56 ) ;


INSERT INTO va_layouts (`layout_id`,`layout_name`,`templates_dir`,`admin_templates_dir`) VALUES (1 , 'Default' , './templates/default' , '../templates/admin' ) ;
INSERT INTO va_layouts (`layout_id`,`layout_name`,`templates_dir`,`admin_templates_dir`) VALUES (2 , 'Curved' , './templates/curved' , '../templates/admin' ) ;
INSERT INTO va_layouts (`layout_id`,`layout_name`,`templates_dir`,`admin_templates_dir`) VALUES (3 , 'Silver' , './templates/silver' , '../templates/admin' ) ;


INSERT INTO va_manufacturers (`manufacturer_id`,`manufacturer_name`,`affiliate_code`) VALUES (2 , 'Amazon' , '/viartco-20/' ) ;


INSERT INTO va_news (`news_id`,`news_date`,`news_title`,`author`,`is_html`,`is_showing`,`show_on_index`,`preview_text`,`news_body`) VALUES (1 , '2004-11-07' , 'Mr. Incredible versus Shrek ' , NULL , 1 , 1 , 1 , 'NEW YORK (CNN/Money) - Movie buffs flocking to "The Incredibles" will see a story of an overweight ex-superhero living in suburbia and newly unemployed when he secretly returns to his crime-fighting life and uncovers a sinister plot' , 'But for producer Pixar Animation Studios, Mr. Incredible is battling darker forces, namely the rise of its chief nemesis, DreamWorks Animation. \r\n\r\nOn Friday, the same day "The Incredibles" arrived in theaters nationwide, DreamWorks counterattacked by releasing its most potent weapon -- "Shrek 2" -- on DVD. \r\n\r\nWhile the DVD didn\'t put much of a dent into the box office release -- "The Incredibles" took in $70.7 million this weekend according to preliminary figures -- the simultaneous arrival points to the growing rivalry between Pixar and DreamWorks. \r\n\r\nBoth studios have been on a tear lately. Pixar\'s stock hit what was at the time an all-time high of $82.28 a share last week, the same day that DreamWorks Animation began trading on the New York Stock Exchange after its $812 million initial public offering. \r\n\r\nThis past Friday, Pixar set an all-time intraday high of $85.10 on buzz about the new movie. \r\n\r\nDreamWorks (up $0.10 to $40.45, Research) shares soared their first day and were up 44 percent from their offering price in late trading Thursday. \r\n\r\nBattle of the egos?\r\nThis isn\'t the first time that DreamWorks has tried to one-up its chief rival with a same-day release. \r\n\r\nAnd McAlpine thinks the studio\'s motive is not about business -- it\'s personal. \r\n\r\n   \r\nShrek 2 could ring in more profits, but Mr. Incredible won\'t be far behind. \r\nDreamWorks Animation CEO Jeffrey Katzenberg was head of Disney\'s animation arm when he bolted in 1994, after being passed up for the job of president at Disney. \r\n\r\nKatzenberg, instead, teamed with Steven Spielberg and record industry guru David Geffen to form DreamWorks, with the idea of building the company into a full-fledged entertainment shop. \r\n\r\nWhile Katzenberg and crew focused on DreamWorks, Disney concentrated on its existing deal with Pixar: The two studios split production costs, and Disney distributes the films and retains exclusive rights to the library. \r\n\r\nThe venture has been lucrative for both, with their six smash hit films outperforming each one that came before it. "Finding Nemo," released in 2003, became the top-grossing animation movie ever and has, according to DVD Exclusive, sold more DVDs than any other film. \r\n\r\nNow comes "The Incredibles," the sixth film from the Disney-Pixar duo. \r\n\r\nIt\'s their first film to be rated PG (as opposed to G) and based on human characters. And the story about a family of ex-superheroes lured from suburban retirement back to fighting crime is expected to generate a stellar opening weekend. Some analysts forecast a three-day haul of more than $80 million. \r\n\r\n \r\nDreamWorks, meanwhile, has had a tougher time spinning gold from its computer animation films, with one notable exception -- Shrek. \r\n\r\nThe original 2001 movie about a green ogre who finds love while battling an evil lord generated a whopping $479 million in worldwide ticket sales. \r\n\r\nThis summer\'s "Shrek 2" edged aside "Finding Nemo" when it set new records for an animation film with a worldwide haul of $879 million at the box office. \r\n\r\nSomebody blinked\r\nWhile Friday\'s release of "Shrek 2" poses a bigger box office threat to Nemo\'s DVD record than it does to "The Incredibles," the timing isn\'t a coincidence. \r\n\r\n"It seems to me that Mr. Katzenberg is nudging (Pixar chief Steven Jobs) and Mr. Eisner," said McAlpine, noting that DreamWorks has at least twice before timed DVD releases to a Pixar-Disney box office debut. Michael Eisner, Disney\'s CEO, plans to step down in 2006. \r\n\r\nDavid Mantell, an analyst with Loop Capital Markets, agreed that DreamWorks is sending a message to its rivals. \r\n\r\nFrom a business standpoint, however, Mantell said the bigger threat to "The Incredibles" comes next week, when Warner Bros. releases "The Polar Express," its first major push into computer animation. Warner Bros., like CNN/Money, is owned by Time Warner (Research). \r\n\r\n \r\nThat said, the jab from DreamWorks is coming at an especially sensitive time for Disney (up $0.11 to $26.43, Research) and Pixar (up $3.59 to $84.45, Research). Their coproduction deal expires after next year\'s release of "Cars." \r\n\r\nEarlier this year, Jobs broke off negotiations, after the two sides could not agree on terms for a new deal, amid reports he didn\'t get along with Eisner. \r\n\r\nThe impasse leaves Pixar and Disney at a crossroads. Pixar has been scouting for a new distribution partner, one that would receive a far smaller slice of revenues than Disney pockets under the current deal. \r\n\r\nAnd Disney has been preparing for life without Pixar by beefing up its own animation division. But Disney\'s track record with non-Pixar animated films is less than stellar. \r\n\r\nFor that reason, some analysts think Disney needs Pixar and its creative know-how more than Pixar needs Disney. \r\n\r\nFriday\'s release of "Shrek 2" on DVD could be Katzenberg\'s way of reminding Eisner that "he made a mistake and should have brought (Katzenberg) in to run the company," said McAlpine. \r\n\r\nIf so, Katzenberg recently shied away from the ultimate battle of the studios. \r\n\r\n"Shark Tale," the latest DreamWorks animation about an underwater mafia of sharks, was originally scheduled for a Nov. 5 release. When Disney put "The Incredibles" on the same calendar, Katzenberg blinked. \r\n\r\n"Shark Tale" debuted Oct. 1.   \r\n' ) ;
INSERT INTO va_news (`news_id`,`news_date`,`news_title`,`author`,`is_html`,`is_showing`,`show_on_index`,`preview_text`,`news_body`) VALUES (2 , '2004-11-07' , 'Bosox \'curse\' contract: $1M plus' , NULL , 0 , 1 , 1 , 'NEW YORK (CNN/Money) - The document that "cursed" the Boston Red Sox for 86 years is about to become a $1 million-plus blessing for a Rhode Island homeless shelter. \r\n\r\n \r\n' , 'The original 1919 contract selling Babe Ruth to the New York Yankees for $100,000 is being auctioned by a Rhode Island philanthropist, Alan Shawn Feinstein, on the eBay auction site. As of 7:25 p.m. ET Sunday, bidding on the contract stood at $1,001,000. \r\n\r\nIn addition to the contract, the successful bidder will receive a 4-page feature story about the curse that kept the Red Sox from winning the World Series, and a letter from Hall of Famer Ty Cobb describing Ruth as baseball\'s greatest player. \r\n\r\n   \r\nBuy Red Sox Tickets\r\nRazorGator.com offers quality pricing, selection and service to sold-out and...\r\nwww.razorgator.com\r\n\r\nThe Curse is Over\r\nGo Red Sox. Buy commemorative t-shirts, bumper stickers, hats, and more.\r\nwww.cafepress.com\r\n\r\nReverse Boston\'s Curse\r\nHey Red Sox fans. Looking for a new and fun way to support the team? We have...\r\nwww.cursereverse.com\r\n\r\nBoston Red Sox Pins, Earrings, Key Chain\r\nRed Sox collector pins, pin sets, earrings, key chains and other...\r\nteampins.com \r\nSome 220 bids have been received in the auction, which ends at 12:08 p.m. ET Tuesday. \r\n\r\nAccording to the eBay page describing the auction, proceeds from the sale will go to the House of Hope, a homeless shelter in Warwick, R.I. \r\n\r\nThe 73-year-old Feinstein told the New York Times that he has raised another $2 million for charity by selling copies of the contract, which he bought in 1993 for $99,000, for $30. \r\n\r\nThe Feinstein Foundation\'s Web site says Feinstein, who made his fortune as a financial newsletter publisher, wants to name the shelter for a late Sister of Mercy nun, Fran Conway, who was a die-hard Sox fan. \r\n\r\nThe item description says that right after Feinstein donated the contract for the auction last month, the Red Sox won the eight straight games that gave them their first World Series title since 1918. That, of course, was the year before Red Sox owner Harry Frazee sold Ruth to the Yankees, which some fans believe led to Boston\'s baseball curse. \r\n\r\n \r\n"Maybe all the good that came from the sale of these contracts made the gods smile," Feinstein told the Times. "From good comes good. Maybe someday, these kids will tell their grandkids, \'We helped break the jinx on the Red Sox.\'"   \r\n' ) ;
INSERT INTO va_news (`news_id`,`news_date`,`news_title`,`author`,`is_html`,`is_showing`,`show_on_index`,`preview_text`,`news_body`) VALUES (3 , '2004-11-08' , 'Iraqi minister berates Annan' , NULL , 0 , 1 , 1 , 'FALLUJA, Iraq (CNN) -- Iraq\'s interim defense minister Hazem Sha\'alan has lashed out at U.N. Secretary-General Kofi Annan and leaders of other Arab countries during a pep talk for Iraqi troops before an expected assault on the insurgent-held city of Falluja' , 'FALLUJA, Iraq (CNN) -- Iraq\'s interim defense minister Hazem Sha\'alan has lashed out at U.N. Secretary-General Kofi Annan and leaders of other Arab countries during a pep talk for Iraqi troops before an expected assault on the insurgent-held city of Falluja.\r\n\r\nAnnan warned in a letter dated October 31 to the United States, Britain and Iraq that such an assault would have a "negative impact" on the prospects for elections, now scheduled for January.\r\n\r\nBut Sha\'alan said on Sunday that Annan did nothing to help Iraqis under the rule of ousted leader Saddam Hussein.\r\n\r\n"Where was Kofi Annan when Saddam was slaughtering the Iraqis like sheep?" Sha\'alan said.\r\n\r\n"Where were the calls we hear from Arab and Islamic countries when Saddam was messing up the country?"\r\n\r\nWith thousands of U.S. troops poised to launch a major assault on Falluja, which has been under insurgent control for months, Sha\'alan told the Iraqi troops set to participate in the offensive that they were "the defenders of democracy" who would rescue a city held hostage.\r\n\r\n"Those who call not to fight the criminals, we say to them, \'You are the criminals.\' They are the criminals," he said.\r\n\r\n"How could you shake hands with Saddam Hussein before? You were a slave to Saddam Hussein, and today you try your best to restore dictatorship and crime, but under a new umbrella -- that is the umbrella of Islam."\r\n\r\nThe troops crowded in to hear him, raising their rifles into the air and cheering, dancing and singing at the end.\r\n\r\nSha\'alan predicted the insurgents, who have been in effective control of Falluja for months, would "run away like rats" when attacked.\r\n\r\n"We will chase them from house to house, from room to room," he said.\r\n\r\nThe U.S. military censored the report of Sha\'alan\'s remarks before allowing it to be sent to media participating in the pool.\r\n\r\nIraqi special forces backed by U.S. Marines seized Falluja\'s main hospital late Sunday, but it remains unclear when the main assault into the city will begin.\r\n\r\n\r\n' ) ;


INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (1 , 'New Order Placed' , 0 ) ;
INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (2 , 'CC Info Added' , 0 ) ;
INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (3 , 'Confirmed by User' , 0 ) ;
INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (4 , 'Paid' , 1 ) ;
INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (5 , 'Goods shipped' , 1 ) ;
INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (6 , 'Pending' , 0 ) ;
INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (7 , 'Closed' , 2 ) ;
INSERT INTO va_order_statuses (`status_id`,`status_name`,`download_activation`) VALUES (8 , 'Declined' , 0 ) ;








INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'categories' , 'categories_columns' , NULL , '3' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'categories' , 'categories_position' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'categories' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'categories' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'categories' , 'products_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'categories' , 'products_per_page' , NULL , '20' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'categories_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'category_description_block' , 4 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'detailed_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'login_block' , 3 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'search_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'detailed' , 'top_products_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'details_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'details' , 'right_column_width' , NULL , '5%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'categories_block' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'categories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'categories_subs' , NULL , '6' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'categories_type' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'events_block' , 3 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'login_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'news_block' , 2 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'offers_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'products_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'products_per_page' , NULL , '5' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'right_column_width' , NULL , '10%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'search_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'index' , 'top_products_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'categories_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'category_description_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'products_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'products_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'products_per_page' , NULL , '20' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (1 , 'products' , 'search_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'categories_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'category_description_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'details_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'details' , 'search_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'categories_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'categories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'categories_subs' , NULL , '3' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'categories_type' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'events_block' , 3 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'login_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'news_block' , 2 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'offers_block' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'products_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'products_per_page' , NULL , '5' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'search_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'index' , 'top_products_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'categories_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'category_description_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'products_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'products_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'products_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (2 , 'products' , 'search_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'details_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'right_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'details' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'categories_block' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'categories_columns' , NULL , '3' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'categories_type' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'left_column_width' , NULL , '20%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'middle_column_width' , NULL , '80%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'offers_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'products_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'products_per_page' , NULL , '5' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'search_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'index' , 'top_products_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'categories_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'categories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'category_description_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'products_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'products_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'products_per_page' , NULL , '5' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'search_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (`layout_id`,`page_name`,`setting_name`,`setting_order`,`setting_value`) VALUES (3 , 'products' , 'top_products_block' , 3 , 'left' ) ;


INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (1 , 'home' , 'Home' , 'index.php' , 1 , 1 , 0 , 1 , 1 , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (2 , 'products' , 'Products' , 'products.php' , 2 , 1 , 0 , 1 , 1 , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (3 , 'basket' , 'Basket' , 'basket.php' , 3 , 1 , 0 , 1 , 1 , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (4 , 'admin' , 'Administration' , 'admin/admin.php' , 11 , 1 , 0 , 1 , 1 , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (5 , 'registration' , 'Registration' , 'user_profile.php' , 1 , 1 , 0 , 1 , 1 , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (6 , 'events' , 'Events' , 'events.php' , 5 , 1 , 0 , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (7 , 'help' , 'How to Shop' , NULL , 8 , 1 , 0 , 1 , NULL , NULL , '<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="5">\r\n\t<b>&nbsp;How to Shop at Our Online Store</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nShopping online with us is\r\na lot like shopping at a retail store you browse our catalogue of products for the items you\'d\r\nlike, put them in a shopping basket, and complete your purchase at the check-out\r\narea. The only difference is, we\'re open 24 hours a day - seven days a week,\r\n...and you don\'t have to put on shoes and leave the comfort of your home to shop!\r\n\r\n<p align="justify">\r\n\r\nSo read on and find out how you can enjoy the shopping experience with Our Online Store.\r\n</td></tr></table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="4">\r\n\t<b>&nbsp;Step 1. &nbsp;Make Your Product Selections</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nThe first thing to do is browse our shop for the items you\'d like. \r\nAs you browse you\'ll see \'Add/Buy\' link.\r\nOnce you\'ve found the\tfirst product you\'d like, simply add it to your online \r\nshopping basket by clicking on the \'Add/Buy\' link.\r\n\r\n<p align="justify">\r\n\r\nJust like in a retail store, the shopping basket is a holding place \r\nfor your items until you are ready to purchase them. You can view the\r\ncontents of your basket at any time by clicking on the \'View Basket\' link on your\r\nshopping page. And, just like a retail store, you can always remove items from your \r\nbasket and put them back on the shelves.\r\n\r\n</td></tr></table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="4">\r\n\t<b>&nbsp;Step 2.&nbsp;Proceed to the Check Out</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n   \r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nOnce you\'ve decided upon your selection and \r\nchecked your basket, you proceed to the Ordering Stage by clicking "Check Out". \r\nAt this point you must decide whether you want to register with us or just place your order without registration. \r\nRegistration means that you don\'t need to complete your details again if you order from us in the future. \r\nThis action takes you to page where we need some extra details to complete the order.\r\nYou enter your personal information, your name and address so we know where to send the goods.\r\n\r\n<!-- \r\n<p align="justify"> \r\nShipping in the US is $7 per order. \r\nBuyers outside of the US will be charged at cost and will be advised of the shipping and packing charges by email.&nbsp;&nbsp;\r\n-->\r\n</td></tr></table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="4">\r\n\t<b>&nbsp;Step 3.&nbsp;Submit your Order</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nAt this point you must decide upon the payment method.&nbsp;&nbsp;You can pay online by entering your credit card information.&nbsp;&nbsp;Alternatively you can print out the form and fax it to us, <b>or</b> you can submit the form without credit card details and call us later with this information.<P>\r\n\r\nWe appreciate that ordering online the first time can be a little confusing so if you have any problems or are unsure of any aspects of the ordering process please contact us and we\'ll try to help you out.<P>\r\n\r\n<!-- \r\nIf you submit your order by e-mail, you\'ll get an immediate acknowledgement \r\nin your electronic mailbox to let you know that we\'ve received the order.\r\nIf you choose fax or mail we\'ll either fax back, send an acknowledgment in \r\nthe mail, telephone you or send an e-mail.\r\n<P>\r\n-->\r\n\r\n</td></tr></table>' ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (8 , 'about' , 'About Us' , NULL , 9 , 1 , 0 , 1 , 1 , NULL , '<b>Contact Us</b>\r\n<p>\r\nWondering when your order will arrive? Need to change something about an order you\'ve placed? You can review and revise your order so that it\'s just the way you want it by visiting Your Account.\r\n<p>\r\nIf you were unable to find your answer using our Web site\'s self-service features, click one of the links to the left to contact our customer service department. We\'ll be happy to assist you. Please note: \r\n<p>\r\nFor security reasons, we can only modify orders or send account information when the request comes from the e-mail address that is associated with your Amazon.com account. \r\nWe can only read and respond to messages in English. \r\n<p>\r\n<b>Not Receiving Replies?</b>\r\n<p>\r\nIf you have used our forms to contact us in the past but have not received a reply, your ISP or e-mail client may be blocking e-mail from Amazon.com. If you suspect this is happening, please consult the help section of your e-mail program to see how to relax or remove the settings that filter or block mail. Once you\'ve established that you should be able to receive mail from us, please contact us again with your question.\r\n<p>\r\nWant to check if your ISP or e-mail client is blocking mail from Amazon.com? Try subscribing for a Special Occasion Reminder. If you don\'t receive it on the date you specify, you will know that messages from Amazon.com are being blocked or deleted automatically.\r\n \r\n' ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (11 , 'faq' , 'FAQ' , 'faq.php' , 7 , 1 , 0 , 1 , 1 , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (13 , 'forum' , 'Forum' , 'forum.php' , 6 , 1 , 0 , 0 , 1 , NULL , NULL ) ;
INSERT INTO va_pages (`page_id`,`page_code`,`page_title`,`page_url`,`page_order`,`is_showing`,`link_in_footer`,`is_html`,`page_type`,`page_path`,`page_body`) VALUES (14 , 'support' , 'Support' , 'support.php' , 10 , 1 , 0 , 0 , 1 , NULL , NULL ) ;


INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (1 , 1 , 'order_id' , 'VARIABLE' , 'order_id' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (2 , 1 , 'vc' , 'VARIABLE' , 'vc' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (8 , 2 , 'PARTNER' , 'CONSTANT' , 'wfb' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (9 , 2 , 'TYPE' , 'CONSTANT' , 'S' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (10 , 2 , 'LOGIN' , 'CONSTANT' , '!Your customer login!' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (11 , 2 , 'DESCRIPTION' , 'VARIABLE' , 'description' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (12 , 2 , 'AMOUNT' , 'VARIABLE' , 'order_total' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (13 , 2 , 'INVOICE' , 'VARIABLE' , 'order_id' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (14 , 3 , 'x_Login' , 'CONSTANT' , '!Your customer login!' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (15 , 3 , 'x_Version' , 'CONSTANT' , '3.0' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (16 , 3 , 'x_Amount' , 'VARIABLE' , 'order_total' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (17 , 3 , 'x_Description' , 'VARIABLE' , 'description' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (18 , 3 , 'x_First_Name' , 'VARIABLE' , 'first_name' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (19 , 3 , 'x_Last_Name' , 'VARIABLE' , 'last_name' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (20 , 3 , 'x_Address' , 'VARIABLE' , 'address_1' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (21 , 3 , 'x_City' , 'VARIABLE' , 'city' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (22 , 3 , 'x_State' , 'VARIABLE' , 'state' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (23 , 3 , 'x_Zip' , 'VARIABLE' , 'zip' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (25 , 3 , 'x_Country' , 'VARIABLE' , 'country' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (26 , 3 , 'x_Phone' , 'VARIABLE' , 'phone' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (27 , 3 , 'x_Fax' , 'VARIABLE' , 'fax' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (28 , 4 , 'instId' , 'CONSTANT' , '!Your installation ID!' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (29 , 4 , 'cartId' , 'VARIABLE' , 'order_id' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (30 , 4 , 'amount' , 'VARIABLE' , 'order_total' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (31 , 4 , 'currency' , 'CONSTANT' , 'USD' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (32 , 4 , 'desc' , 'VARIABLE' , 'description' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (33 , 4 , 'testMode' , 'CONSTANT' , '100' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (34 , 4 , 'email' , 'VARIABLE' , 'email' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (35 , 4 , 'name' , 'VARIABLE' , 'name' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (36 , 4 , 'address' , 'VARIABLE' , 'address' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (37 , 4 , 'postcode' , 'VARIABLE' , 'zip' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (38 , 4 , 'country' , 'VARIABLE' , 'country_code' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (39 , 4 , 'tel' , 'VARIABLE' , 'phone' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (40 , 5 , 'sid' , 'CONSTANT' , '!Your vendor number!' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (41 , 5 , 'total' , 'VARIABLE' , 'order_total' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (42 , 5 , 'cart_order_id' , 'VARIABLE' , 'order_id' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (43 , 5 , 'card_holder_name' , 'VARIABLE' , 'name' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (44 , 5 , 'street_address' , 'VARIABLE' , 'address1' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (45 , 5 , 'city' , 'VARIABLE' , 'city' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (46 , 5 , 'state' , 'VARIABLE' , 'state' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (47 , 5 , 'zip' , 'VARIABLE' , 'zip' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (48 , 5 , 'country' , 'VARIABLE' , 'country' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (49 , 5 , 'email' , 'VARIABLE' , 'email' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (50 , 5 , 'phone' , 'VARIABLE' , 'phone' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (51 , 6 , 'business' , 'CONSTANT' , 'your.paypal@email.address' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (52 , 6 , 'item_name' , 'VARIABLE' , 'basket' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (53 , 6 , 'amount' , 'VARIABLE' , 'order_total' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (54 , 6 , 'cmd' , 'CONSTANT' , '_xclick' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (55 , 6 , 'email' , 'VARIABLE' , 'email' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (56 , 6 , 'last_name' , 'VARIABLE' , 'last_name' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (57 , 6 , 'address1' , 'VARIABLE' , 'address1' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (58 , 6 , 'country' , 'VARIABLE' , 'country_code' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (59 , 6 , 'first_name' , 'VARIABLE' , 'first_name' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (60 , 6 , 'city' , 'VARIABLE' , 'city' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (61 , 6 , 'zip' , 'VARIABLE' , 'zip' ) ;
INSERT INTO va_payment_parameters (`parameter_id`,`payment_id`,`parameter_name`,`parameter_type`,`parameter_source`) VALUES (62 , 6 , 'state' , 'VARIABLE' , 'state_code' ) ;


INSERT INTO va_payment_systems (`payment_id`,`payment_name`,`payment_url`,`submit_method`) VALUES (1 , 'Personal' , 'credit_card_info.php' , 'GET' ) ;
INSERT INTO va_payment_systems (`payment_id`,`payment_name`,`payment_url`,`submit_method`) VALUES (2 , 'VeriSign' , 'https://payflowlink.verisign.com/payflowlink.cfm' , 'GET' ) ;
INSERT INTO va_payment_systems (`payment_id`,`payment_name`,`payment_url`,`submit_method`) VALUES (3 , 'Authorize.Net' , 'https://secure.authorize.net/gateway/transact.dll' , 'POST' ) ;
INSERT INTO va_payment_systems (`payment_id`,`payment_name`,`payment_url`,`submit_method`) VALUES (4 , 'WorldPay' , 'https://select.worldpay.com/wcc/purchase' , 'POST' ) ;
INSERT INTO va_payment_systems (`payment_id`,`payment_name`,`payment_url`,`submit_method`) VALUES (5 , '2CheckOut' , 'https://www2.2checkout.com/2co/buyer/purchase' , 'GET' ) ;
INSERT INTO va_payment_systems (`payment_id`,`payment_name`,`payment_url`,`submit_method`) VALUES (6 , 'Paypal' , 'https://www.paypal.com/cgi-bin/webscr' , 'POST' ) ;



INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (1 , 1 , 1 , '23/05/2003' , 'Fixed bug when FAQ articles has some redundant spaces in HTML \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (2 , 1 , 1 , '23/05/2003' , 'Fixed bug when News articles maintenance didn\'t allow entering large title containing HTML tags' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (3 , 1 , 2 , '10/01/2003' , 'Added Postgre SQL and ODBC support ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (4 , 1 , 2 , '10/01/2003' , 'Added search box to Sales Orders maintenance ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (5 , 1 , 2 , '10/01/2003' , 'Added \'Page sources\' options for Web pages maintenance \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (6 , 1 , 2 , '10/01/2003' , 'Added \'Remember me\' option to Login page ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (7 , 1 , 2 , '10/01/2003' , 'Added search box to \'Countries maintenance\' ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (8 , 1 , 1 , '10/01/2003' , 'Fixed bug when countries listbox wasn\'t sorted by \'Country Order\' ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (9 , 1 , 1 , '10/01/2003' , 'Fixed typo in Web pages section of Administration \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (10 , 1 , 1 , '10/01/2003' , 'Fixed bug when two Administrators could not access Administration simultaneously ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (11 , 1 , 1 , '10/01/2003' , 'Fixed bug when Final Checkout page sent two Administrator notifications instead of one \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (12 , 1 , 2 , '23/01/2003' , 'Added Forum system \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (13 , 1 , 2 , '24/01/2003' , 'Added Customizable Layouts support' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (14 , 1 , 2 , '24/01/2003' , 'Added \'Downloadable\' products support \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (15 , 1 , 2 , '25/01/2003' , 'Added ability to assign one product to multiple categories ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (16 , 1 , 2 , '25/01/2003' , 'Added ability to reassign cases within Support System (only Enterprise Edition) ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (17 , 1 , 2 , '25/01/2003' , 'Added customizable payment systems support ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (18 , 1 , 2 , '26/01/2003' , 'Added ability to submit POST payment systems parameters ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (19 , 1 , 2 , '26/01/2003' , 'Added option that allows hiding Reviews section at Product details page ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (20 , 1 , 2 , '27/01/2003' , 'Added custom tags support to email notifications ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (21 , 1 , 2 , '27/01/2003' , 'Added \'free shipping\' rules to Shipping settings ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (22 , 1 , 1 , '28/01/2003' , 'Fixed bug when footer menu didn\'t hide when there were no menu items ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (23 , 1 , 1 , '28/01/2003' , 'Fixed bug when sorting order wasn\'t preserved in \'Countries\' maintenance ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (24 , 1 , 1 , '28/01/2003' , 'Fixed bug with complex date formats masks processing ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (25 , 1 , 1 , '28/01/2003' , 'Fixed bug when product description had illegal characters ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (26 , 1 , 1 , '28/01/2003' , 'Fixed bug when sending emails from some domains took more time then from others ' , 1 ) ;
INSERT INTO va_release_changes (`change_id`,`release_id`,`change_type_id`,`change_date`,`change_desc`,`is_showing`) VALUES (27 , 1 , 1 , '29/01/2003' , 'Fixed bug when some phone numbers were not considered to be valid during user registration ' , 1 ) ;


INSERT INTO va_release_types (`type_id`,`type_name`) VALUES (1 , 'Upgrade' ) ;
INSERT INTO va_release_types (`type_id`,`type_name`) VALUES (2 , 'Update' ) ;
INSERT INTO va_release_types (`type_id`,`type_name`) VALUES (3 , 'New Version' ) ;


INSERT INTO va_releases (`release_id`,`item_id`,`release_type_id`,`release_date`,`release_title`,`version`,`release_desc`,`download_type`,`path_to_file`,`is_showing`,`show_on_index`) VALUES (1 , 1 , 1 , '24/12/2003' , 'New Upgrade for C2S' , '2.0.1.11' , NULL , 1 , '/etc/c2s/c2s.tgz' , 0 , 0 ) ;




INSERT INTO va_shipping_rules (`shipping_rule_id`,`shipping_rule_desc`) VALUES (1 , 'Can ship anywhere' ) ;
INSERT INTO va_shipping_rules (`shipping_rule_id`,`shipping_rule_desc`) VALUES (2 , 'Can ship only within USA' ) ;
INSERT INTO va_shipping_rules (`shipping_rule_id`,`shipping_rule_desc`) VALUES (3 , 'Can ship only within United Kingdom' ) ;


INSERT INTO va_shipping_times (`shipping_time_id`,`shipping_time_desc`) VALUES (1 , 'Usually ships in 2 to 3 days' ) ;
INSERT INTO va_shipping_times (`shipping_time_id`,`shipping_time_desc`) VALUES (2 , 'Usually ships in 24 hours' ) ;






INSERT INTO va_states (`state_code`,`state_name`) VALUES ('AK' , 'Alaska' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('AL' , 'Alabama' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('AR' , 'Arkansas' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('AZ' , 'Arizona' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('CA' , 'California' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('CO' , 'Colorado' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('CT' , 'Connecticut' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('DC' , 'District of Columbia' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('DE' , 'Delaware' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('FL' , 'Florida' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('GA' , 'Georgia' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('HI' , 'Hawaii' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('IA' , 'Iowa' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('ID' , 'Idaho' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('IL' , 'Illinois' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('IN' , 'Indiana' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('KS' , 'Kansas' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('KY' , 'Kentucky' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('LA' , 'Louisiana' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('MA' , 'Massachusetts' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('MD' , 'Maryland' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('ME' , 'Maine' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('MI' , 'Michigan' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('MN' , 'Minnesota' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('MO' , 'Missouri' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('MS' , 'Mississippi' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('MT' , 'Montana' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('NC' , 'North Carolina' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('ND' , 'North Dakota' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('NE' , 'Nebraska' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('NG' , 'New England' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('NH' , 'New Hampshire' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('NJ' , 'New Jersey' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('NV' , 'Nevada' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('NY' , 'New York' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('OH' , 'Ohio' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('OK' , 'Oklahoma' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('OR' , 'Oregon' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('PA' , 'Pennsylvania' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('RI' , 'Rhode Island' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('SC' , 'South Carolina' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('SD' , 'South Dakota' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('TN' , 'Tennessee' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('TX' , 'Texas' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('UT' , 'Utah' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('VA' , 'Virginia' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('VT' , 'Vermont' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('WA' , 'Washington' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('WI' , 'Wisconsin' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('WV' , 'West Virginia' ) ;
INSERT INTO va_states (`state_code`,`state_name`) VALUES ('WY' , 'Wyoming' ) ;






INSERT INTO va_support_priorities (`priority_id`,`priority_name`) VALUES (1 , 'High' ) ;
INSERT INTO va_support_priorities (`priority_id`,`priority_name`) VALUES (2 , 'Normal' ) ;
INSERT INTO va_support_priorities (`priority_id`,`priority_name`) VALUES (3 , 'Low' ) ;


INSERT INTO va_support_products (`product_id`,`product_name`,`show_for_user`) VALUES (1 , 'The Lord of the Rings' , 1 ) ;


INSERT INTO va_support_statuses (`status_id`,`status_name`,`show_for_user`) VALUES (1 , 'New' , 1 ) ;
INSERT INTO va_support_statuses (`status_id`,`status_name`,`show_for_user`) VALUES (2 , 'Proposed Solution' , 0 ) ;
INSERT INTO va_support_statuses (`status_id`,`status_name`,`show_for_user`) VALUES (3 , 'Awaiting Response' , 1 ) ;
INSERT INTO va_support_statuses (`status_id`,`status_name`,`show_for_user`) VALUES (4 , 'Request More Information' , 1 ) ;
INSERT INTO va_support_statuses (`status_id`,`status_name`,`show_for_user`) VALUES (5 , 'Investigating' , 0 ) ;
INSERT INTO va_support_statuses (`status_id`,`status_name`,`show_for_user`) VALUES (6 , 'Closed' , 1 ) ;


INSERT INTO va_support_types (`type_id`,`type_name`,`show_for_user`) VALUES (1 , 'Bug/Issue' , 1 ) ;
INSERT INTO va_support_types (`type_id`,`type_name`,`show_for_user`) VALUES (2 , 'Question' , 1 ) ;
INSERT INTO va_support_types (`type_id`,`type_name`,`show_for_user`) VALUES (3 , 'Wish/Request' , 1 ) ;
INSERT INTO va_support_types (`type_id`,`type_name`,`show_for_user`) VALUES (4 , 'Other' , 1 ) ;


INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (1 , 'VAT' , 'AT' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (2 , 'VAT' , 'BE' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (3 , 'VAT' , 'CY' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (4 , 'VAT' , 'CZ' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (5 , 'VAT' , 'DK' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (6 , 'VAT' , 'EE' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (7 , 'VAT' , 'FI' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (8 , 'VAT' , 'FR' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (9 , 'VAT' , 'DE' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (10 , 'VAT' , 'GR' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (11 , 'VAT' , 'HU' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (12 , 'VAT' , 'IE' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (13 , 'VAT' , 'IT' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (14 , 'VAT' , 'LV' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (15 , 'VAT' , 'LT' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (16 , 'VAT' , 'LU' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (17 , 'VAT' , 'MT' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (18 , 'VAT' , 'MC' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (19 , 'VAT' , 'AN' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (20 , 'VAT' , 'NL' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (21 , 'VAT' , 'PL' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (22 , 'VAT' , 'PT' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (23 , 'VAT' , 'SK' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (24 , 'VAT' , 'SI' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (25 , 'VAT' , 'ES' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (26 , 'VAT' , 'SE' , 17.5 ) ;
INSERT INTO va_tax_rates (`tax_id`,`tax_name`,`country_code`,`tax_percent`) VALUES (27 , 'VAT' , 'GB' , 17.5 ) ;


INSERT INTO va_users (`user_id`,`login`,`password`,`security_question`,`security_answer`,`name`,`first_name`,`last_name`,`company_name`,`email`,`address1`,`address2`,`city`,`province`,`state_code`,`zip`,`country_code`,`phone`,`daytime_phone`,`evening_phone`,`cell_phone`,`fax`,`delivery_name`,`delivery_first_name`,`delivery_last_name`,`delivery_company_name`,`delivery_email`,`delivery_address1`,`delivery_address2`,`delivery_city`,`delivery_province`,`delivery_state_code`,`delivery_zip`,`delivery_country_code`,`delivery_phone`,`delivery_daytime_phone`,`delivery_evening_phone`,`delivery_cell_phone`,`delivery_fax`,`registration_date`,`modified_date`) VALUES (1 , 'joy' , 'joy' , '' , '' , 'joy' , '' , '' , NULL , 'jnothing@yahoo.com' , '5-th Avenue' , NULL , 'New York' , NULL , 'NY' , '95000' , 'US' , NULL , '1234567890' , '1234567890' , NULL , NULL , 'joy' , NULL , NULL , NULL , NULL , '5-th Avenue' , NULL , 'New York' , NULL , 'NY' , '95000' , 'US' , NULL , NULL , NULL , NULL , NULL , '2004-06-22 20:03:44' , '2004-06-22 20:03:44' ) ;

